/******************************************************************************
 * Copyright (c) 2010-2012, XIONLOGIC LIMITED                                 *
 * Copyright (c) 2010-2012, Niroshan Mahasinghe                               *
 * All rights reserved.                                                       *
 *                                                                            *
 * Redistribution and use in source and binary forms, with or without         *
 * modification, are permitted provided that the following conditions         *
 * are met:                                                                   *
 *                                                                            *
 *  o  Redistributions of source code must retain the above copyright         *
 *     notice, this list of conditions and the following disclaimer.          *
 *                                                                            *
 *  o  Redistributions in binary form must reproduce the above copyright      *
 *     notice, this list of conditions and the following disclaimer in        *
 *     the documentation and/or other materials provided with the             *
 *     distribution.                                                          *
 *                                                                            *
 *  o  Neither the name of XIONLOGIC LIMITED nor the names of its             *
 *     contributors may be used to endorse or promote products                *
 *     derived from this software without specific prior                      *
 *     written permission.                                                    *
 *                                                                            *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS        *
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED  *
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR *
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR          *
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,      *
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,        *
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR         *
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF     *
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING       *
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS         *
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.               *
 *****************************************************************************/

/*****************************************************************************
 *  Original Author(s):
 *      Niroshan Mahasinghe, nmahasinghe@xionlogic.com
 *****************************************************************************/
/** \file
 * \ingroup ModMiscIpDspFftR22Sdc
 * TFM stage-0 twiddle-factor ROM for 4096-point radix-2<sup>2</sup> SDF FFT
 * processors.
 * This file implements the TFM stage-0 twiddle-factor ROM for 4096-point
 * radix-2<sup>2</sup> SDF FFT processors.
 */

/***************************************************************************
 * Include files
 ***************************************************************************/
`include "system.vh"

/***************************************************************************
 * Modules
 ***************************************************************************/
/** \addtogroup ModMiscIpDspFftR22Sdc
 * @{
 */

/** TFM stage-0 twiddle-factor ROM for 4096-point radix-2<sup>2</sup> SDF FFT 
 * processors.
 * This module implements the stage-0 twiddle-factor ROM for 4096-point radix-2<sup>2</sup>
 * SDF FFT processors. It outputs the twiddle-factor, W<sup>nk</sup> for a given
 * \a nk one cycle later.
 *
 * \param[in]  clk      System clock.
 * \param[in]  rst_n    Active low asynchronous reset line.
 * \param[in]  addr     Twiddle-factor ROM address (i.e. \a nk) to read.
 * \param[in]  addr_vld Indicates that the read address is valid.
 * \param[out] tf_re    Twiddle-factor output (real part).
 * \param[out] tf_im    Twiddle-factor output (imaginary part).
 */
module fft_r22sdf_rom_4096_s0 (
    input  wire               clk,
    input  wire               rst_n,
    input  wire        [11:0] addr,
    input  wire               addr_vld,
    output wire signed [ 9:0] tf_re,
    output wire signed [ 9:0] tf_im
  );

  reg  [19:0] dout;

  assign tf_re = dout[19:10];
  assign tf_im = dout[ 9: 0];

  initial
    begin
     `ifndef USE_RESET
      dout = 20'd0;
     `endif
    end

  always @ (posedge clk or negedge rst_n)
    begin
      if (!rst_n)
        begin
         `ifdef USE_RESET
          dout <= 20'd0;
         `endif
        end
      else if (addr_vld)
        begin
          case (addr)
            12'h000: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h001: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h002: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h003: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h004: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h005: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h006: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h007: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h008: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h009: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h00A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h00B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h00C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h00D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h00E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h00F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h010: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h011: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h012: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h013: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h014: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h015: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h016: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h017: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h018: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h019: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h01A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h01B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h01C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h01D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h01E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h01F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h020: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h021: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h022: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h023: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h024: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h025: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h026: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h027: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h028: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h029: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h02A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h02B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h02C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h02D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h02E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h02F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h030: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h031: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h032: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h033: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h034: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h035: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h036: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h037: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h038: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h039: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h03A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h03B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h03C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h03D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h03E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h03F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h040: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h041: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h042: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h043: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h044: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h045: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h046: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h047: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h048: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h049: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h04A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h04B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h04C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h04D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h04E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h04F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h050: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h051: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h052: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h053: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h054: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h055: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h056: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h057: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h058: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h059: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h05A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h05B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h05C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h05D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h05E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h05F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h060: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h061: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h062: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h063: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h064: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h065: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h066: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h067: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h068: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h069: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h06A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h06B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h06C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h06D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h06E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h06F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h070: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h071: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h072: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h073: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h074: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h075: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h076: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h077: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h078: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h079: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h07A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h07B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h07C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h07D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h07E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h07F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h080: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h081: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h082: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h083: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h084: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h085: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h086: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h087: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h088: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h089: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h08A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h08B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h08C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h08D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h08E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h08F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h090: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h091: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h092: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h093: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h094: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h095: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h096: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h097: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h098: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h099: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h09A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h09B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h09C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h09D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h09E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h09F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0A0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0A1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0A2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0A3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0A4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0A5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0A6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0A7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0A8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0A9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0AA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0AB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0AC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0AD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0AE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0AF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0B0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0B1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0B2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0B3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0B4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0B5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0B6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0B7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0B8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0B9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0BA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0BB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0BC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0BD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0BE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0BF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0C0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0C1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0C2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0C3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0C4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0C5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0C6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0C7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0C8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0C9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0CA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0CB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0CC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0CD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0CE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0CF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0D0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0D1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0D2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0D3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0D4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0D5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0D6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0D7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0D8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0D9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0DA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0DB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0DC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0DD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0DE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0DF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0E0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0E1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0E2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0E3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0E4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0E5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0E6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0E7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0E8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0E9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0EA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0EB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0EC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0ED: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0EE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0EF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0F0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0F1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0F2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0F3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0F4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0F5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0F6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0F7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0F8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0F9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0FA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0FB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0FC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0FD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0FE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h0FF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h100: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h101: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h102: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h103: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h104: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h105: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h106: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h107: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h108: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h109: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h10A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h10B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h10C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h10D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h10E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h10F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h110: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h111: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h112: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h113: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h114: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h115: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h116: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h117: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h118: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h119: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h11A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h11B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h11C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h11D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h11E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h11F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h120: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h121: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h122: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h123: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h124: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h125: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h126: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h127: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h128: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h129: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h12A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h12B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h12C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h12D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h12E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h12F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h130: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h131: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h132: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h133: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h134: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h135: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h136: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h137: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h138: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h139: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h13A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h13B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h13C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h13D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h13E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h13F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h140: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h141: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h142: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h143: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h144: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h145: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h146: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h147: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h148: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h149: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h14A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h14B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h14C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h14D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h14E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h14F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h150: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h151: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h152: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h153: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h154: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h155: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h156: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h157: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h158: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h159: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h15A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h15B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h15C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h15D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h15E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h15F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h160: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h161: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h162: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h163: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h164: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h165: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h166: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h167: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h168: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h169: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h16A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h16B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h16C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h16D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h16E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h16F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h170: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h171: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h172: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h173: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h174: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h175: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h176: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h177: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h178: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h179: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h17A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h17B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h17C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h17D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h17E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h17F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h180: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h181: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h182: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h183: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h184: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h185: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h186: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h187: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h188: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h189: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h18A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h18B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h18C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h18D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h18E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h18F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h190: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h191: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h192: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h193: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h194: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h195: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h196: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h197: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h198: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h199: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h19A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h19B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h19C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h19D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h19E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h19F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1A0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1A1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1A2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1A3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1A4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1A5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1A6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1A7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1A8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1A9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1AA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1AB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1AC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1AD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1AE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1AF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1B0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1B1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1B2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1B3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1B4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1B5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1B6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1B7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1B8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1B9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1BA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1BB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1BC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1BD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1BE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1BF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1C0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1C1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1C2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1C3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1C4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1C5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1C6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1C7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1C8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1C9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1CA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1CB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1CC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1CD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1CE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1CF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1D0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1D1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1D2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1D3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1D4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1D5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1D6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1D7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1D8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1D9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1DA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1DB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1DC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1DD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1DE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1DF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1E0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1E1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1E2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1E3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1E4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1E5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1E6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1E7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1E8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1E9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1EA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1EB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1EC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1ED: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1EE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1EF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1F0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1F1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1F2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1F3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1F4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1F5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1F6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1F7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1F8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1F9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1FA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1FB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1FC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1FD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1FE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h1FF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h200: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h201: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h202: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h203: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h204: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h205: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h206: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h207: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h208: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h209: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h20A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h20B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h20C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h20D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h20E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h20F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h210: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h211: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h212: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h213: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h214: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h215: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h216: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h217: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h218: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h219: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h21A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h21B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h21C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h21D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h21E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h21F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h220: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h221: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h222: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h223: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h224: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h225: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h226: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h227: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h228: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h229: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h22A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h22B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h22C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h22D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h22E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h22F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h230: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h231: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h232: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h233: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h234: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h235: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h236: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h237: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h238: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h239: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h23A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h23B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h23C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h23D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h23E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h23F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h240: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h241: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h242: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h243: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h244: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h245: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h246: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h247: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h248: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h249: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h24A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h24B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h24C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h24D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h24E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h24F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h250: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h251: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h252: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h253: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h254: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h255: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h256: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h257: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h258: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h259: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h25A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h25B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h25C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h25D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h25E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h25F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h260: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h261: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h262: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h263: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h264: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h265: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h266: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h267: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h268: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h269: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h26A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h26B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h26C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h26D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h26E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h26F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h270: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h271: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h272: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h273: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h274: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h275: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h276: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h277: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h278: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h279: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h27A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h27B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h27C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h27D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h27E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h27F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h280: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h281: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h282: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h283: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h284: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h285: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h286: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h287: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h288: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h289: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h28A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h28B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h28C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h28D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h28E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h28F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h290: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h291: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h292: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h293: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h294: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h295: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h296: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h297: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h298: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h299: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h29A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h29B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h29C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h29D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h29E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h29F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2A0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2A1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2A2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2A3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2A4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2A5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2A6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2A7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2A8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2A9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2AA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2AB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2AC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2AD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2AE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2AF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2B0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2B1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2B2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2B3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2B4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2B5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2B6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2B7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2B8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2B9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2BA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2BB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2BC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2BD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2BE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2BF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2C0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2C1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2C2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2C3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2C4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2C5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2C6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2C7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2C8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2C9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2CA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2CB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2CC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2CD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2CE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2CF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2D0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2D1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2D2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2D3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2D4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2D5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2D6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2D7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2D8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2D9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2DA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2DB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2DC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2DD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2DE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2DF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2E0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2E1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2E2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2E3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2E4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2E5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2E6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2E7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2E8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2E9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2EA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2EB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2EC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2ED: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2EE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2EF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2F0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2F1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2F2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2F3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2F4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2F5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2F6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2F7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2F8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2F9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2FA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2FB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2FC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2FD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2FE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h2FF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h300: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h301: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h302: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h303: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h304: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h305: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h306: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h307: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h308: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h309: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h30A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h30B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h30C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h30D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h30E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h30F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h310: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h311: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h312: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h313: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h314: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h315: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h316: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h317: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h318: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h319: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h31A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h31B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h31C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h31D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h31E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h31F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h320: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h321: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h322: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h323: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h324: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h325: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h326: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h327: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h328: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h329: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h32A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h32B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h32C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h32D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h32E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h32F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h330: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h331: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h332: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h333: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h334: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h335: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h336: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h337: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h338: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h339: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h33A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h33B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h33C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h33D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h33E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h33F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h340: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h341: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h342: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h343: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h344: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h345: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h346: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h347: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h348: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h349: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h34A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h34B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h34C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h34D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h34E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h34F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h350: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h351: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h352: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h353: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h354: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h355: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h356: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h357: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h358: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h359: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h35A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h35B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h35C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h35D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h35E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h35F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h360: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h361: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h362: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h363: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h364: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h365: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h366: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h367: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h368: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h369: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h36A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h36B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h36C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h36D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h36E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h36F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h370: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h371: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h372: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h373: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h374: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h375: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h376: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h377: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h378: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h379: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h37A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h37B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h37C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h37D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h37E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h37F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h380: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h381: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h382: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h383: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h384: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h385: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h386: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h387: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h388: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h389: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h38A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h38B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h38C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h38D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h38E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h38F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h390: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h391: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h392: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h393: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h394: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h395: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h396: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h397: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h398: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h399: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h39A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h39B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h39C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h39D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h39E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h39F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3A0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3A1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3A2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3A3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3A4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3A5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3A6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3A7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3A8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3A9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3AA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3AB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3AC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3AD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3AE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3AF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3B0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3B1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3B2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3B3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3B4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3B5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3B6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3B7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3B8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3B9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3BA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3BB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3BC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3BD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3BE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3BF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3C0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3C1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3C2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3C3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3C4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3C5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3C6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3C7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3C8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3C9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3CA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3CB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3CC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3CD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3CE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3CF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3D0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3D1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3D2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3D3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3D4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3D5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3D6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3D7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3D8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3D9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3DA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3DB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3DC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3DD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3DE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3DF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3E0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3E1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3E2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3E3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3E4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3E5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3E6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3E7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3E8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3E9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3EA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3EB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3EC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3ED: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3EE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3EF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3F0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3F1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3F2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3F3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3F4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3F5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3F6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3F7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3F8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3F9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3FA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3FB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3FC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3FD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3FE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h3FF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h400: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h401: dout <= { 10'sd511   , -10'sd2     }; /* W[   2] =  0.9980  -0.0039i */
            12'h402: dout <= { 10'sd511   , -10'sd3     }; /* W[   4] =  0.9980  -0.0059i */
            12'h403: dout <= { 10'sd511   , -10'sd5     }; /* W[   6] =  0.9980  -0.0098i */
            12'h404: dout <= { 10'sd511   , -10'sd6     }; /* W[   8] =  0.9980  -0.0117i */
            12'h405: dout <= { 10'sd511   , -10'sd8     }; /* W[  10] =  0.9980  -0.0156i */
            12'h406: dout <= { 10'sd511   , -10'sd9     }; /* W[  12] =  0.9980  -0.0176i */
            12'h407: dout <= { 10'sd511   , -10'sd11    }; /* W[  14] =  0.9980  -0.0215i */
            12'h408: dout <= { 10'sd511   , -10'sd13    }; /* W[  16] =  0.9980  -0.0254i */
            12'h409: dout <= { 10'sd511   , -10'sd14    }; /* W[  18] =  0.9980  -0.0273i */
            12'h40A: dout <= { 10'sd511   , -10'sd16    }; /* W[  20] =  0.9980  -0.0312i */
            12'h40B: dout <= { 10'sd511   , -10'sd17    }; /* W[  22] =  0.9980  -0.0332i */
            12'h40C: dout <= { 10'sd511   , -10'sd19    }; /* W[  24] =  0.9980  -0.0371i */
            12'h40D: dout <= { 10'sd511   , -10'sd20    }; /* W[  26] =  0.9980  -0.0391i */
            12'h40E: dout <= { 10'sd511   , -10'sd22    }; /* W[  28] =  0.9980  -0.0430i */
            12'h40F: dout <= { 10'sd511   , -10'sd24    }; /* W[  30] =  0.9980  -0.0469i */
            12'h410: dout <= { 10'sd511   , -10'sd25    }; /* W[  32] =  0.9980  -0.0488i */
            12'h411: dout <= { 10'sd511   , -10'sd27    }; /* W[  34] =  0.9980  -0.0527i */
            12'h412: dout <= { 10'sd511   , -10'sd28    }; /* W[  36] =  0.9980  -0.0547i */
            12'h413: dout <= { 10'sd511   , -10'sd30    }; /* W[  38] =  0.9980  -0.0586i */
            12'h414: dout <= { 10'sd511   , -10'sd31    }; /* W[  40] =  0.9980  -0.0605i */
            12'h415: dout <= { 10'sd511   , -10'sd33    }; /* W[  42] =  0.9980  -0.0645i */
            12'h416: dout <= { 10'sd511   , -10'sd35    }; /* W[  44] =  0.9980  -0.0684i */
            12'h417: dout <= { 10'sd511   , -10'sd36    }; /* W[  46] =  0.9980  -0.0703i */
            12'h418: dout <= { 10'sd511   , -10'sd38    }; /* W[  48] =  0.9980  -0.0742i */
            12'h419: dout <= { 10'sd510   , -10'sd39    }; /* W[  50] =  0.9961  -0.0762i */
            12'h41A: dout <= { 10'sd510   , -10'sd41    }; /* W[  52] =  0.9961  -0.0801i */
            12'h41B: dout <= { 10'sd510   , -10'sd42    }; /* W[  54] =  0.9961  -0.0820i */
            12'h41C: dout <= { 10'sd510   , -10'sd44    }; /* W[  56] =  0.9961  -0.0859i */
            12'h41D: dout <= { 10'sd510   , -10'sd45    }; /* W[  58] =  0.9961  -0.0879i */
            12'h41E: dout <= { 10'sd510   , -10'sd47    }; /* W[  60] =  0.9961  -0.0918i */
            12'h41F: dout <= { 10'sd510   , -10'sd49    }; /* W[  62] =  0.9961  -0.0957i */
            12'h420: dout <= { 10'sd510   , -10'sd50    }; /* W[  64] =  0.9961  -0.0977i */
            12'h421: dout <= { 10'sd509   , -10'sd52    }; /* W[  66] =  0.9941  -0.1016i */
            12'h422: dout <= { 10'sd509   , -10'sd53    }; /* W[  68] =  0.9941  -0.1035i */
            12'h423: dout <= { 10'sd509   , -10'sd55    }; /* W[  70] =  0.9941  -0.1074i */
            12'h424: dout <= { 10'sd509   , -10'sd56    }; /* W[  72] =  0.9941  -0.1094i */
            12'h425: dout <= { 10'sd509   , -10'sd58    }; /* W[  74] =  0.9941  -0.1133i */
            12'h426: dout <= { 10'sd509   , -10'sd60    }; /* W[  76] =  0.9941  -0.1172i */
            12'h427: dout <= { 10'sd508   , -10'sd61    }; /* W[  78] =  0.9922  -0.1191i */
            12'h428: dout <= { 10'sd508   , -10'sd63    }; /* W[  80] =  0.9922  -0.1230i */
            12'h429: dout <= { 10'sd508   , -10'sd64    }; /* W[  82] =  0.9922  -0.1250i */
            12'h42A: dout <= { 10'sd508   , -10'sd66    }; /* W[  84] =  0.9922  -0.1289i */
            12'h42B: dout <= { 10'sd508   , -10'sd67    }; /* W[  86] =  0.9922  -0.1309i */
            12'h42C: dout <= { 10'sd507   , -10'sd69    }; /* W[  88] =  0.9902  -0.1348i */
            12'h42D: dout <= { 10'sd507   , -10'sd70    }; /* W[  90] =  0.9902  -0.1367i */
            12'h42E: dout <= { 10'sd507   , -10'sd72    }; /* W[  92] =  0.9902  -0.1406i */
            12'h42F: dout <= { 10'sd507   , -10'sd74    }; /* W[  94] =  0.9902  -0.1445i */
            12'h430: dout <= { 10'sd506   , -10'sd75    }; /* W[  96] =  0.9883  -0.1465i */
            12'h431: dout <= { 10'sd506   , -10'sd77    }; /* W[  98] =  0.9883  -0.1504i */
            12'h432: dout <= { 10'sd506   , -10'sd78    }; /* W[ 100] =  0.9883  -0.1523i */
            12'h433: dout <= { 10'sd506   , -10'sd80    }; /* W[ 102] =  0.9883  -0.1562i */
            12'h434: dout <= { 10'sd505   , -10'sd81    }; /* W[ 104] =  0.9863  -0.1582i */
            12'h435: dout <= { 10'sd505   , -10'sd83    }; /* W[ 106] =  0.9863  -0.1621i */
            12'h436: dout <= { 10'sd505   , -10'sd84    }; /* W[ 108] =  0.9863  -0.1641i */
            12'h437: dout <= { 10'sd505   , -10'sd86    }; /* W[ 110] =  0.9863  -0.1680i */
            12'h438: dout <= { 10'sd504   , -10'sd88    }; /* W[ 112] =  0.9844  -0.1719i */
            12'h439: dout <= { 10'sd504   , -10'sd89    }; /* W[ 114] =  0.9844  -0.1738i */
            12'h43A: dout <= { 10'sd504   , -10'sd91    }; /* W[ 116] =  0.9844  -0.1777i */
            12'h43B: dout <= { 10'sd504   , -10'sd92    }; /* W[ 118] =  0.9844  -0.1797i */
            12'h43C: dout <= { 10'sd503   , -10'sd94    }; /* W[ 120] =  0.9824  -0.1836i */
            12'h43D: dout <= { 10'sd503   , -10'sd95    }; /* W[ 122] =  0.9824  -0.1855i */
            12'h43E: dout <= { 10'sd503   , -10'sd97    }; /* W[ 124] =  0.9824  -0.1895i */
            12'h43F: dout <= { 10'sd502   , -10'sd98    }; /* W[ 126] =  0.9805  -0.1914i */
            12'h440: dout <= { 10'sd502   , -10'sd100   }; /* W[ 128] =  0.9805  -0.1953i */
            12'h441: dout <= { 10'sd502   , -10'sd101   }; /* W[ 130] =  0.9805  -0.1973i */
            12'h442: dout <= { 10'sd502   , -10'sd103   }; /* W[ 132] =  0.9805  -0.2012i */
            12'h443: dout <= { 10'sd501   , -10'sd105   }; /* W[ 134] =  0.9785  -0.2051i */
            12'h444: dout <= { 10'sd501   , -10'sd106   }; /* W[ 136] =  0.9785  -0.2070i */
            12'h445: dout <= { 10'sd501   , -10'sd108   }; /* W[ 138] =  0.9785  -0.2109i */
            12'h446: dout <= { 10'sd500   , -10'sd109   }; /* W[ 140] =  0.9766  -0.2129i */
            12'h447: dout <= { 10'sd500   , -10'sd111   }; /* W[ 142] =  0.9766  -0.2168i */
            12'h448: dout <= { 10'sd500   , -10'sd112   }; /* W[ 144] =  0.9766  -0.2188i */
            12'h449: dout <= { 10'sd499   , -10'sd114   }; /* W[ 146] =  0.9746  -0.2227i */
            12'h44A: dout <= { 10'sd499   , -10'sd115   }; /* W[ 148] =  0.9746  -0.2246i */
            12'h44B: dout <= { 10'sd499   , -10'sd117   }; /* W[ 150] =  0.9746  -0.2285i */
            12'h44C: dout <= { 10'sd498   , -10'sd118   }; /* W[ 152] =  0.9727  -0.2305i */
            12'h44D: dout <= { 10'sd498   , -10'sd120   }; /* W[ 154] =  0.9727  -0.2344i */
            12'h44E: dout <= { 10'sd497   , -10'sd121   }; /* W[ 156] =  0.9707  -0.2363i */
            12'h44F: dout <= { 10'sd497   , -10'sd123   }; /* W[ 158] =  0.9707  -0.2402i */
            12'h450: dout <= { 10'sd497   , -10'sd124   }; /* W[ 160] =  0.9707  -0.2422i */
            12'h451: dout <= { 10'sd496   , -10'sd126   }; /* W[ 162] =  0.9688  -0.2461i */
            12'h452: dout <= { 10'sd496   , -10'sd127   }; /* W[ 164] =  0.9688  -0.2480i */
            12'h453: dout <= { 10'sd495   , -10'sd129   }; /* W[ 166] =  0.9668  -0.2520i */
            12'h454: dout <= { 10'sd495   , -10'sd130   }; /* W[ 168] =  0.9668  -0.2539i */
            12'h455: dout <= { 10'sd495   , -10'sd132   }; /* W[ 170] =  0.9668  -0.2578i */
            12'h456: dout <= { 10'sd494   , -10'sd134   }; /* W[ 172] =  0.9648  -0.2617i */
            12'h457: dout <= { 10'sd494   , -10'sd135   }; /* W[ 174] =  0.9648  -0.2637i */
            12'h458: dout <= { 10'sd493   , -10'sd137   }; /* W[ 176] =  0.9629  -0.2676i */
            12'h459: dout <= { 10'sd493   , -10'sd138   }; /* W[ 178] =  0.9629  -0.2695i */
            12'h45A: dout <= { 10'sd493   , -10'sd140   }; /* W[ 180] =  0.9629  -0.2734i */
            12'h45B: dout <= { 10'sd492   , -10'sd141   }; /* W[ 182] =  0.9609  -0.2754i */
            12'h45C: dout <= { 10'sd492   , -10'sd143   }; /* W[ 184] =  0.9609  -0.2793i */
            12'h45D: dout <= { 10'sd491   , -10'sd144   }; /* W[ 186] =  0.9590  -0.2812i */
            12'h45E: dout <= { 10'sd491   , -10'sd146   }; /* W[ 188] =  0.9590  -0.2852i */
            12'h45F: dout <= { 10'sd490   , -10'sd147   }; /* W[ 190] =  0.9570  -0.2871i */
            12'h460: dout <= { 10'sd490   , -10'sd149   }; /* W[ 192] =  0.9570  -0.2910i */
            12'h461: dout <= { 10'sd489   , -10'sd150   }; /* W[ 194] =  0.9551  -0.2930i */
            12'h462: dout <= { 10'sd489   , -10'sd152   }; /* W[ 196] =  0.9551  -0.2969i */
            12'h463: dout <= { 10'sd489   , -10'sd153   }; /* W[ 198] =  0.9551  -0.2988i */
            12'h464: dout <= { 10'sd488   , -10'sd155   }; /* W[ 200] =  0.9531  -0.3027i */
            12'h465: dout <= { 10'sd488   , -10'sd156   }; /* W[ 202] =  0.9531  -0.3047i */
            12'h466: dout <= { 10'sd487   , -10'sd158   }; /* W[ 204] =  0.9512  -0.3086i */
            12'h467: dout <= { 10'sd487   , -10'sd159   }; /* W[ 206] =  0.9512  -0.3105i */
            12'h468: dout <= { 10'sd486   , -10'sd161   }; /* W[ 208] =  0.9492  -0.3145i */
            12'h469: dout <= { 10'sd486   , -10'sd162   }; /* W[ 210] =  0.9492  -0.3164i */
            12'h46A: dout <= { 10'sd485   , -10'sd164   }; /* W[ 212] =  0.9473  -0.3203i */
            12'h46B: dout <= { 10'sd485   , -10'sd165   }; /* W[ 214] =  0.9473  -0.3223i */
            12'h46C: dout <= { 10'sd484   , -10'sd167   }; /* W[ 216] =  0.9453  -0.3262i */
            12'h46D: dout <= { 10'sd484   , -10'sd168   }; /* W[ 218] =  0.9453  -0.3281i */
            12'h46E: dout <= { 10'sd483   , -10'sd170   }; /* W[ 220] =  0.9434  -0.3320i */
            12'h46F: dout <= { 10'sd483   , -10'sd171   }; /* W[ 222] =  0.9434  -0.3340i */
            12'h470: dout <= { 10'sd482   , -10'sd172   }; /* W[ 224] =  0.9414  -0.3359i */
            12'h471: dout <= { 10'sd482   , -10'sd174   }; /* W[ 226] =  0.9414  -0.3398i */
            12'h472: dout <= { 10'sd481   , -10'sd175   }; /* W[ 228] =  0.9395  -0.3418i */
            12'h473: dout <= { 10'sd480   , -10'sd177   }; /* W[ 230] =  0.9375  -0.3457i */
            12'h474: dout <= { 10'sd480   , -10'sd178   }; /* W[ 232] =  0.9375  -0.3477i */
            12'h475: dout <= { 10'sd479   , -10'sd180   }; /* W[ 234] =  0.9355  -0.3516i */
            12'h476: dout <= { 10'sd479   , -10'sd181   }; /* W[ 236] =  0.9355  -0.3535i */
            12'h477: dout <= { 10'sd478   , -10'sd183   }; /* W[ 238] =  0.9336  -0.3574i */
            12'h478: dout <= { 10'sd478   , -10'sd184   }; /* W[ 240] =  0.9336  -0.3594i */
            12'h479: dout <= { 10'sd477   , -10'sd186   }; /* W[ 242] =  0.9316  -0.3633i */
            12'h47A: dout <= { 10'sd477   , -10'sd187   }; /* W[ 244] =  0.9316  -0.3652i */
            12'h47B: dout <= { 10'sd476   , -10'sd189   }; /* W[ 246] =  0.9297  -0.3691i */
            12'h47C: dout <= { 10'sd475   , -10'sd190   }; /* W[ 248] =  0.9277  -0.3711i */
            12'h47D: dout <= { 10'sd475   , -10'sd192   }; /* W[ 250] =  0.9277  -0.3750i */
            12'h47E: dout <= { 10'sd474   , -10'sd193   }; /* W[ 252] =  0.9258  -0.3770i */
            12'h47F: dout <= { 10'sd474   , -10'sd194   }; /* W[ 254] =  0.9258  -0.3789i */
            12'h480: dout <= { 10'sd473   , -10'sd196   }; /* W[ 256] =  0.9238  -0.3828i */
            12'h481: dout <= { 10'sd472   , -10'sd197   }; /* W[ 258] =  0.9219  -0.3848i */
            12'h482: dout <= { 10'sd472   , -10'sd199   }; /* W[ 260] =  0.9219  -0.3887i */
            12'h483: dout <= { 10'sd471   , -10'sd200   }; /* W[ 262] =  0.9199  -0.3906i */
            12'h484: dout <= { 10'sd471   , -10'sd202   }; /* W[ 264] =  0.9199  -0.3945i */
            12'h485: dout <= { 10'sd470   , -10'sd203   }; /* W[ 266] =  0.9180  -0.3965i */
            12'h486: dout <= { 10'sd469   , -10'sd205   }; /* W[ 268] =  0.9160  -0.4004i */
            12'h487: dout <= { 10'sd469   , -10'sd206   }; /* W[ 270] =  0.9160  -0.4023i */
            12'h488: dout <= { 10'sd468   , -10'sd207   }; /* W[ 272] =  0.9141  -0.4043i */
            12'h489: dout <= { 10'sd467   , -10'sd209   }; /* W[ 274] =  0.9121  -0.4082i */
            12'h48A: dout <= { 10'sd467   , -10'sd210   }; /* W[ 276] =  0.9121  -0.4102i */
            12'h48B: dout <= { 10'sd466   , -10'sd212   }; /* W[ 278] =  0.9102  -0.4141i */
            12'h48C: dout <= { 10'sd465   , -10'sd213   }; /* W[ 280] =  0.9082  -0.4160i */
            12'h48D: dout <= { 10'sd465   , -10'sd215   }; /* W[ 282] =  0.9082  -0.4199i */
            12'h48E: dout <= { 10'sd464   , -10'sd216   }; /* W[ 284] =  0.9062  -0.4219i */
            12'h48F: dout <= { 10'sd464   , -10'sd217   }; /* W[ 286] =  0.9062  -0.4238i */
            12'h490: dout <= { 10'sd463   , -10'sd219   }; /* W[ 288] =  0.9043  -0.4277i */
            12'h491: dout <= { 10'sd462   , -10'sd220   }; /* W[ 290] =  0.9023  -0.4297i */
            12'h492: dout <= { 10'sd461   , -10'sd222   }; /* W[ 292] =  0.9004  -0.4336i */
            12'h493: dout <= { 10'sd461   , -10'sd223   }; /* W[ 294] =  0.9004  -0.4355i */
            12'h494: dout <= { 10'sd460   , -10'sd225   }; /* W[ 296] =  0.8984  -0.4395i */
            12'h495: dout <= { 10'sd459   , -10'sd226   }; /* W[ 298] =  0.8965  -0.4414i */
            12'h496: dout <= { 10'sd459   , -10'sd227   }; /* W[ 300] =  0.8965  -0.4434i */
            12'h497: dout <= { 10'sd458   , -10'sd229   }; /* W[ 302] =  0.8945  -0.4473i */
            12'h498: dout <= { 10'sd457   , -10'sd230   }; /* W[ 304] =  0.8926  -0.4492i */
            12'h499: dout <= { 10'sd457   , -10'sd232   }; /* W[ 306] =  0.8926  -0.4531i */
            12'h49A: dout <= { 10'sd456   , -10'sd233   }; /* W[ 308] =  0.8906  -0.4551i */
            12'h49B: dout <= { 10'sd455   , -10'sd234   }; /* W[ 310] =  0.8887  -0.4570i */
            12'h49C: dout <= { 10'sd454   , -10'sd236   }; /* W[ 312] =  0.8867  -0.4609i */
            12'h49D: dout <= { 10'sd454   , -10'sd237   }; /* W[ 314] =  0.8867  -0.4629i */
            12'h49E: dout <= { 10'sd453   , -10'sd239   }; /* W[ 316] =  0.8848  -0.4668i */
            12'h49F: dout <= { 10'sd452   , -10'sd240   }; /* W[ 318] =  0.8828  -0.4688i */
            12'h4A0: dout <= { 10'sd452   , -10'sd241   }; /* W[ 320] =  0.8828  -0.4707i */
            12'h4A1: dout <= { 10'sd451   , -10'sd243   }; /* W[ 322] =  0.8809  -0.4746i */
            12'h4A2: dout <= { 10'sd450   , -10'sd244   }; /* W[ 324] =  0.8789  -0.4766i */
            12'h4A3: dout <= { 10'sd449   , -10'sd246   }; /* W[ 326] =  0.8770  -0.4805i */
            12'h4A4: dout <= { 10'sd449   , -10'sd247   }; /* W[ 328] =  0.8770  -0.4824i */
            12'h4A5: dout <= { 10'sd448   , -10'sd248   }; /* W[ 330] =  0.8750  -0.4844i */
            12'h4A6: dout <= { 10'sd447   , -10'sd250   }; /* W[ 332] =  0.8730  -0.4883i */
            12'h4A7: dout <= { 10'sd446   , -10'sd251   }; /* W[ 334] =  0.8711  -0.4902i */
            12'h4A8: dout <= { 10'sd445   , -10'sd252   }; /* W[ 336] =  0.8691  -0.4922i */
            12'h4A9: dout <= { 10'sd445   , -10'sd254   }; /* W[ 338] =  0.8691  -0.4961i */
            12'h4AA: dout <= { 10'sd444   , -10'sd255   }; /* W[ 340] =  0.8672  -0.4980i */
            12'h4AB: dout <= { 10'sd443   , -10'sd256   }; /* W[ 342] =  0.8652  -0.5000i */
            12'h4AC: dout <= { 10'sd442   , -10'sd258   }; /* W[ 344] =  0.8633  -0.5039i */
            12'h4AD: dout <= { 10'sd442   , -10'sd259   }; /* W[ 346] =  0.8633  -0.5059i */
            12'h4AE: dout <= { 10'sd441   , -10'sd261   }; /* W[ 348] =  0.8613  -0.5098i */
            12'h4AF: dout <= { 10'sd440   , -10'sd262   }; /* W[ 350] =  0.8594  -0.5117i */
            12'h4B0: dout <= { 10'sd439   , -10'sd263   }; /* W[ 352] =  0.8574  -0.5137i */
            12'h4B1: dout <= { 10'sd438   , -10'sd265   }; /* W[ 354] =  0.8555  -0.5176i */
            12'h4B2: dout <= { 10'sd438   , -10'sd266   }; /* W[ 356] =  0.8555  -0.5195i */
            12'h4B3: dout <= { 10'sd437   , -10'sd267   }; /* W[ 358] =  0.8535  -0.5215i */
            12'h4B4: dout <= { 10'sd436   , -10'sd269   }; /* W[ 360] =  0.8516  -0.5254i */
            12'h4B5: dout <= { 10'sd435   , -10'sd270   }; /* W[ 362] =  0.8496  -0.5273i */
            12'h4B6: dout <= { 10'sd434   , -10'sd271   }; /* W[ 364] =  0.8477  -0.5293i */
            12'h4B7: dout <= { 10'sd433   , -10'sd273   }; /* W[ 366] =  0.8457  -0.5332i */
            12'h4B8: dout <= { 10'sd433   , -10'sd274   }; /* W[ 368] =  0.8457  -0.5352i */
            12'h4B9: dout <= { 10'sd432   , -10'sd275   }; /* W[ 370] =  0.8438  -0.5371i */
            12'h4BA: dout <= { 10'sd431   , -10'sd277   }; /* W[ 372] =  0.8418  -0.5410i */
            12'h4BB: dout <= { 10'sd430   , -10'sd278   }; /* W[ 374] =  0.8398  -0.5430i */
            12'h4BC: dout <= { 10'sd429   , -10'sd279   }; /* W[ 376] =  0.8379  -0.5449i */
            12'h4BD: dout <= { 10'sd428   , -10'sd281   }; /* W[ 378] =  0.8359  -0.5488i */
            12'h4BE: dout <= { 10'sd427   , -10'sd282   }; /* W[ 380] =  0.8340  -0.5508i */
            12'h4BF: dout <= { 10'sd427   , -10'sd283   }; /* W[ 382] =  0.8340  -0.5527i */
            12'h4C0: dout <= { 10'sd426   , -10'sd284   }; /* W[ 384] =  0.8320  -0.5547i */
            12'h4C1: dout <= { 10'sd425   , -10'sd286   }; /* W[ 386] =  0.8301  -0.5586i */
            12'h4C2: dout <= { 10'sd424   , -10'sd287   }; /* W[ 388] =  0.8281  -0.5605i */
            12'h4C3: dout <= { 10'sd423   , -10'sd288   }; /* W[ 390] =  0.8262  -0.5625i */
            12'h4C4: dout <= { 10'sd422   , -10'sd290   }; /* W[ 392] =  0.8242  -0.5664i */
            12'h4C5: dout <= { 10'sd421   , -10'sd291   }; /* W[ 394] =  0.8223  -0.5684i */
            12'h4C6: dout <= { 10'sd420   , -10'sd292   }; /* W[ 396] =  0.8203  -0.5703i */
            12'h4C7: dout <= { 10'sd420   , -10'sd294   }; /* W[ 398] =  0.8203  -0.5742i */
            12'h4C8: dout <= { 10'sd419   , -10'sd295   }; /* W[ 400] =  0.8184  -0.5762i */
            12'h4C9: dout <= { 10'sd418   , -10'sd296   }; /* W[ 402] =  0.8164  -0.5781i */
            12'h4CA: dout <= { 10'sd417   , -10'sd297   }; /* W[ 404] =  0.8145  -0.5801i */
            12'h4CB: dout <= { 10'sd416   , -10'sd299   }; /* W[ 406] =  0.8125  -0.5840i */
            12'h4CC: dout <= { 10'sd415   , -10'sd300   }; /* W[ 408] =  0.8105  -0.5859i */
            12'h4CD: dout <= { 10'sd414   , -10'sd301   }; /* W[ 410] =  0.8086  -0.5879i */
            12'h4CE: dout <= { 10'sd413   , -10'sd302   }; /* W[ 412] =  0.8066  -0.5898i */
            12'h4CF: dout <= { 10'sd412   , -10'sd304   }; /* W[ 414] =  0.8047  -0.5938i */
            12'h4D0: dout <= { 10'sd411   , -10'sd305   }; /* W[ 416] =  0.8027  -0.5957i */
            12'h4D1: dout <= { 10'sd410   , -10'sd306   }; /* W[ 418] =  0.8008  -0.5977i */
            12'h4D2: dout <= { 10'sd409   , -10'sd308   }; /* W[ 420] =  0.7988  -0.6016i */
            12'h4D3: dout <= { 10'sd408   , -10'sd309   }; /* W[ 422] =  0.7969  -0.6035i */
            12'h4D4: dout <= { 10'sd407   , -10'sd310   }; /* W[ 424] =  0.7949  -0.6055i */
            12'h4D5: dout <= { 10'sd407   , -10'sd311   }; /* W[ 426] =  0.7949  -0.6074i */
            12'h4D6: dout <= { 10'sd406   , -10'sd313   }; /* W[ 428] =  0.7930  -0.6113i */
            12'h4D7: dout <= { 10'sd405   , -10'sd314   }; /* W[ 430] =  0.7910  -0.6133i */
            12'h4D8: dout <= { 10'sd404   , -10'sd315   }; /* W[ 432] =  0.7891  -0.6152i */
            12'h4D9: dout <= { 10'sd403   , -10'sd316   }; /* W[ 434] =  0.7871  -0.6172i */
            12'h4DA: dout <= { 10'sd402   , -10'sd317   }; /* W[ 436] =  0.7852  -0.6191i */
            12'h4DB: dout <= { 10'sd401   , -10'sd319   }; /* W[ 438] =  0.7832  -0.6230i */
            12'h4DC: dout <= { 10'sd400   , -10'sd320   }; /* W[ 440] =  0.7812  -0.6250i */
            12'h4DD: dout <= { 10'sd399   , -10'sd321   }; /* W[ 442] =  0.7793  -0.6270i */
            12'h4DE: dout <= { 10'sd398   , -10'sd322   }; /* W[ 444] =  0.7773  -0.6289i */
            12'h4DF: dout <= { 10'sd397   , -10'sd324   }; /* W[ 446] =  0.7754  -0.6328i */
            12'h4E0: dout <= { 10'sd396   , -10'sd325   }; /* W[ 448] =  0.7734  -0.6348i */
            12'h4E1: dout <= { 10'sd395   , -10'sd326   }; /* W[ 450] =  0.7715  -0.6367i */
            12'h4E2: dout <= { 10'sd394   , -10'sd327   }; /* W[ 452] =  0.7695  -0.6387i */
            12'h4E3: dout <= { 10'sd393   , -10'sd328   }; /* W[ 454] =  0.7676  -0.6406i */
            12'h4E4: dout <= { 10'sd392   , -10'sd330   }; /* W[ 456] =  0.7656  -0.6445i */
            12'h4E5: dout <= { 10'sd391   , -10'sd331   }; /* W[ 458] =  0.7637  -0.6465i */
            12'h4E6: dout <= { 10'sd390   , -10'sd332   }; /* W[ 460] =  0.7617  -0.6484i */
            12'h4E7: dout <= { 10'sd389   , -10'sd333   }; /* W[ 462] =  0.7598  -0.6504i */
            12'h4E8: dout <= { 10'sd388   , -10'sd334   }; /* W[ 464] =  0.7578  -0.6523i */
            12'h4E9: dout <= { 10'sd387   , -10'sd336   }; /* W[ 466] =  0.7559  -0.6562i */
            12'h4EA: dout <= { 10'sd386   , -10'sd337   }; /* W[ 468] =  0.7539  -0.6582i */
            12'h4EB: dout <= { 10'sd385   , -10'sd338   }; /* W[ 470] =  0.7520  -0.6602i */
            12'h4EC: dout <= { 10'sd384   , -10'sd339   }; /* W[ 472] =  0.7500  -0.6621i */
            12'h4ED: dout <= { 10'sd383   , -10'sd340   }; /* W[ 474] =  0.7480  -0.6641i */
            12'h4EE: dout <= { 10'sd381   , -10'sd342   }; /* W[ 476] =  0.7441  -0.6680i */
            12'h4EF: dout <= { 10'sd380   , -10'sd343   }; /* W[ 478] =  0.7422  -0.6699i */
            12'h4F0: dout <= { 10'sd379   , -10'sd344   }; /* W[ 480] =  0.7402  -0.6719i */
            12'h4F1: dout <= { 10'sd378   , -10'sd345   }; /* W[ 482] =  0.7383  -0.6738i */
            12'h4F2: dout <= { 10'sd377   , -10'sd346   }; /* W[ 484] =  0.7363  -0.6758i */
            12'h4F3: dout <= { 10'sd376   , -10'sd347   }; /* W[ 486] =  0.7344  -0.6777i */
            12'h4F4: dout <= { 10'sd375   , -10'sd348   }; /* W[ 488] =  0.7324  -0.6797i */
            12'h4F5: dout <= { 10'sd374   , -10'sd350   }; /* W[ 490] =  0.7305  -0.6836i */
            12'h4F6: dout <= { 10'sd373   , -10'sd351   }; /* W[ 492] =  0.7285  -0.6855i */
            12'h4F7: dout <= { 10'sd372   , -10'sd352   }; /* W[ 494] =  0.7266  -0.6875i */
            12'h4F8: dout <= { 10'sd371   , -10'sd353   }; /* W[ 496] =  0.7246  -0.6895i */
            12'h4F9: dout <= { 10'sd370   , -10'sd354   }; /* W[ 498] =  0.7227  -0.6914i */
            12'h4FA: dout <= { 10'sd369   , -10'sd355   }; /* W[ 500] =  0.7207  -0.6934i */
            12'h4FB: dout <= { 10'sd368   , -10'sd356   }; /* W[ 502] =  0.7188  -0.6953i */
            12'h4FC: dout <= { 10'sd366   , -10'sd358   }; /* W[ 504] =  0.7148  -0.6992i */
            12'h4FD: dout <= { 10'sd365   , -10'sd359   }; /* W[ 506] =  0.7129  -0.7012i */
            12'h4FE: dout <= { 10'sd364   , -10'sd360   }; /* W[ 508] =  0.7109  -0.7031i */
            12'h4FF: dout <= { 10'sd363   , -10'sd361   }; /* W[ 510] =  0.7090  -0.7051i */
            12'h500: dout <= { 10'sd362   , -10'sd362   }; /* W[ 512] =  0.7070  -0.7070i */
            12'h501: dout <= { 10'sd361   , -10'sd363   }; /* W[ 514] =  0.7051  -0.7090i */
            12'h502: dout <= { 10'sd360   , -10'sd364   }; /* W[ 516] =  0.7031  -0.7109i */
            12'h503: dout <= { 10'sd359   , -10'sd365   }; /* W[ 518] =  0.7012  -0.7129i */
            12'h504: dout <= { 10'sd358   , -10'sd366   }; /* W[ 520] =  0.6992  -0.7148i */
            12'h505: dout <= { 10'sd356   , -10'sd368   }; /* W[ 522] =  0.6953  -0.7188i */
            12'h506: dout <= { 10'sd355   , -10'sd369   }; /* W[ 524] =  0.6934  -0.7207i */
            12'h507: dout <= { 10'sd354   , -10'sd370   }; /* W[ 526] =  0.6914  -0.7227i */
            12'h508: dout <= { 10'sd353   , -10'sd371   }; /* W[ 528] =  0.6895  -0.7246i */
            12'h509: dout <= { 10'sd352   , -10'sd372   }; /* W[ 530] =  0.6875  -0.7266i */
            12'h50A: dout <= { 10'sd351   , -10'sd373   }; /* W[ 532] =  0.6855  -0.7285i */
            12'h50B: dout <= { 10'sd350   , -10'sd374   }; /* W[ 534] =  0.6836  -0.7305i */
            12'h50C: dout <= { 10'sd348   , -10'sd375   }; /* W[ 536] =  0.6797  -0.7324i */
            12'h50D: dout <= { 10'sd347   , -10'sd376   }; /* W[ 538] =  0.6777  -0.7344i */
            12'h50E: dout <= { 10'sd346   , -10'sd377   }; /* W[ 540] =  0.6758  -0.7363i */
            12'h50F: dout <= { 10'sd345   , -10'sd378   }; /* W[ 542] =  0.6738  -0.7383i */
            12'h510: dout <= { 10'sd344   , -10'sd379   }; /* W[ 544] =  0.6719  -0.7402i */
            12'h511: dout <= { 10'sd343   , -10'sd380   }; /* W[ 546] =  0.6699  -0.7422i */
            12'h512: dout <= { 10'sd342   , -10'sd381   }; /* W[ 548] =  0.6680  -0.7441i */
            12'h513: dout <= { 10'sd340   , -10'sd383   }; /* W[ 550] =  0.6641  -0.7480i */
            12'h514: dout <= { 10'sd339   , -10'sd384   }; /* W[ 552] =  0.6621  -0.7500i */
            12'h515: dout <= { 10'sd338   , -10'sd385   }; /* W[ 554] =  0.6602  -0.7520i */
            12'h516: dout <= { 10'sd337   , -10'sd386   }; /* W[ 556] =  0.6582  -0.7539i */
            12'h517: dout <= { 10'sd336   , -10'sd387   }; /* W[ 558] =  0.6562  -0.7559i */
            12'h518: dout <= { 10'sd334   , -10'sd388   }; /* W[ 560] =  0.6523  -0.7578i */
            12'h519: dout <= { 10'sd333   , -10'sd389   }; /* W[ 562] =  0.6504  -0.7598i */
            12'h51A: dout <= { 10'sd332   , -10'sd390   }; /* W[ 564] =  0.6484  -0.7617i */
            12'h51B: dout <= { 10'sd331   , -10'sd391   }; /* W[ 566] =  0.6465  -0.7637i */
            12'h51C: dout <= { 10'sd330   , -10'sd392   }; /* W[ 568] =  0.6445  -0.7656i */
            12'h51D: dout <= { 10'sd328   , -10'sd393   }; /* W[ 570] =  0.6406  -0.7676i */
            12'h51E: dout <= { 10'sd327   , -10'sd394   }; /* W[ 572] =  0.6387  -0.7695i */
            12'h51F: dout <= { 10'sd326   , -10'sd395   }; /* W[ 574] =  0.6367  -0.7715i */
            12'h520: dout <= { 10'sd325   , -10'sd396   }; /* W[ 576] =  0.6348  -0.7734i */
            12'h521: dout <= { 10'sd324   , -10'sd397   }; /* W[ 578] =  0.6328  -0.7754i */
            12'h522: dout <= { 10'sd322   , -10'sd398   }; /* W[ 580] =  0.6289  -0.7773i */
            12'h523: dout <= { 10'sd321   , -10'sd399   }; /* W[ 582] =  0.6270  -0.7793i */
            12'h524: dout <= { 10'sd320   , -10'sd400   }; /* W[ 584] =  0.6250  -0.7812i */
            12'h525: dout <= { 10'sd319   , -10'sd401   }; /* W[ 586] =  0.6230  -0.7832i */
            12'h526: dout <= { 10'sd317   , -10'sd402   }; /* W[ 588] =  0.6191  -0.7852i */
            12'h527: dout <= { 10'sd316   , -10'sd403   }; /* W[ 590] =  0.6172  -0.7871i */
            12'h528: dout <= { 10'sd315   , -10'sd404   }; /* W[ 592] =  0.6152  -0.7891i */
            12'h529: dout <= { 10'sd314   , -10'sd405   }; /* W[ 594] =  0.6133  -0.7910i */
            12'h52A: dout <= { 10'sd313   , -10'sd406   }; /* W[ 596] =  0.6113  -0.7930i */
            12'h52B: dout <= { 10'sd311   , -10'sd407   }; /* W[ 598] =  0.6074  -0.7949i */
            12'h52C: dout <= { 10'sd310   , -10'sd407   }; /* W[ 600] =  0.6055  -0.7949i */
            12'h52D: dout <= { 10'sd309   , -10'sd408   }; /* W[ 602] =  0.6035  -0.7969i */
            12'h52E: dout <= { 10'sd308   , -10'sd409   }; /* W[ 604] =  0.6016  -0.7988i */
            12'h52F: dout <= { 10'sd306   , -10'sd410   }; /* W[ 606] =  0.5977  -0.8008i */
            12'h530: dout <= { 10'sd305   , -10'sd411   }; /* W[ 608] =  0.5957  -0.8027i */
            12'h531: dout <= { 10'sd304   , -10'sd412   }; /* W[ 610] =  0.5938  -0.8047i */
            12'h532: dout <= { 10'sd302   , -10'sd413   }; /* W[ 612] =  0.5898  -0.8066i */
            12'h533: dout <= { 10'sd301   , -10'sd414   }; /* W[ 614] =  0.5879  -0.8086i */
            12'h534: dout <= { 10'sd300   , -10'sd415   }; /* W[ 616] =  0.5859  -0.8105i */
            12'h535: dout <= { 10'sd299   , -10'sd416   }; /* W[ 618] =  0.5840  -0.8125i */
            12'h536: dout <= { 10'sd297   , -10'sd417   }; /* W[ 620] =  0.5801  -0.8145i */
            12'h537: dout <= { 10'sd296   , -10'sd418   }; /* W[ 622] =  0.5781  -0.8164i */
            12'h538: dout <= { 10'sd295   , -10'sd419   }; /* W[ 624] =  0.5762  -0.8184i */
            12'h539: dout <= { 10'sd294   , -10'sd420   }; /* W[ 626] =  0.5742  -0.8203i */
            12'h53A: dout <= { 10'sd292   , -10'sd420   }; /* W[ 628] =  0.5703  -0.8203i */
            12'h53B: dout <= { 10'sd291   , -10'sd421   }; /* W[ 630] =  0.5684  -0.8223i */
            12'h53C: dout <= { 10'sd290   , -10'sd422   }; /* W[ 632] =  0.5664  -0.8242i */
            12'h53D: dout <= { 10'sd288   , -10'sd423   }; /* W[ 634] =  0.5625  -0.8262i */
            12'h53E: dout <= { 10'sd287   , -10'sd424   }; /* W[ 636] =  0.5605  -0.8281i */
            12'h53F: dout <= { 10'sd286   , -10'sd425   }; /* W[ 638] =  0.5586  -0.8301i */
            12'h540: dout <= { 10'sd284   , -10'sd426   }; /* W[ 640] =  0.5547  -0.8320i */
            12'h541: dout <= { 10'sd283   , -10'sd427   }; /* W[ 642] =  0.5527  -0.8340i */
            12'h542: dout <= { 10'sd282   , -10'sd427   }; /* W[ 644] =  0.5508  -0.8340i */
            12'h543: dout <= { 10'sd281   , -10'sd428   }; /* W[ 646] =  0.5488  -0.8359i */
            12'h544: dout <= { 10'sd279   , -10'sd429   }; /* W[ 648] =  0.5449  -0.8379i */
            12'h545: dout <= { 10'sd278   , -10'sd430   }; /* W[ 650] =  0.5430  -0.8398i */
            12'h546: dout <= { 10'sd277   , -10'sd431   }; /* W[ 652] =  0.5410  -0.8418i */
            12'h547: dout <= { 10'sd275   , -10'sd432   }; /* W[ 654] =  0.5371  -0.8438i */
            12'h548: dout <= { 10'sd274   , -10'sd433   }; /* W[ 656] =  0.5352  -0.8457i */
            12'h549: dout <= { 10'sd273   , -10'sd433   }; /* W[ 658] =  0.5332  -0.8457i */
            12'h54A: dout <= { 10'sd271   , -10'sd434   }; /* W[ 660] =  0.5293  -0.8477i */
            12'h54B: dout <= { 10'sd270   , -10'sd435   }; /* W[ 662] =  0.5273  -0.8496i */
            12'h54C: dout <= { 10'sd269   , -10'sd436   }; /* W[ 664] =  0.5254  -0.8516i */
            12'h54D: dout <= { 10'sd267   , -10'sd437   }; /* W[ 666] =  0.5215  -0.8535i */
            12'h54E: dout <= { 10'sd266   , -10'sd438   }; /* W[ 668] =  0.5195  -0.8555i */
            12'h54F: dout <= { 10'sd265   , -10'sd438   }; /* W[ 670] =  0.5176  -0.8555i */
            12'h550: dout <= { 10'sd263   , -10'sd439   }; /* W[ 672] =  0.5137  -0.8574i */
            12'h551: dout <= { 10'sd262   , -10'sd440   }; /* W[ 674] =  0.5117  -0.8594i */
            12'h552: dout <= { 10'sd261   , -10'sd441   }; /* W[ 676] =  0.5098  -0.8613i */
            12'h553: dout <= { 10'sd259   , -10'sd442   }; /* W[ 678] =  0.5059  -0.8633i */
            12'h554: dout <= { 10'sd258   , -10'sd442   }; /* W[ 680] =  0.5039  -0.8633i */
            12'h555: dout <= { 10'sd256   , -10'sd443   }; /* W[ 682] =  0.5000  -0.8652i */
            12'h556: dout <= { 10'sd255   , -10'sd444   }; /* W[ 684] =  0.4980  -0.8672i */
            12'h557: dout <= { 10'sd254   , -10'sd445   }; /* W[ 686] =  0.4961  -0.8691i */
            12'h558: dout <= { 10'sd252   , -10'sd445   }; /* W[ 688] =  0.4922  -0.8691i */
            12'h559: dout <= { 10'sd251   , -10'sd446   }; /* W[ 690] =  0.4902  -0.8711i */
            12'h55A: dout <= { 10'sd250   , -10'sd447   }; /* W[ 692] =  0.4883  -0.8730i */
            12'h55B: dout <= { 10'sd248   , -10'sd448   }; /* W[ 694] =  0.4844  -0.8750i */
            12'h55C: dout <= { 10'sd247   , -10'sd449   }; /* W[ 696] =  0.4824  -0.8770i */
            12'h55D: dout <= { 10'sd246   , -10'sd449   }; /* W[ 698] =  0.4805  -0.8770i */
            12'h55E: dout <= { 10'sd244   , -10'sd450   }; /* W[ 700] =  0.4766  -0.8789i */
            12'h55F: dout <= { 10'sd243   , -10'sd451   }; /* W[ 702] =  0.4746  -0.8809i */
            12'h560: dout <= { 10'sd241   , -10'sd452   }; /* W[ 704] =  0.4707  -0.8828i */
            12'h561: dout <= { 10'sd240   , -10'sd452   }; /* W[ 706] =  0.4688  -0.8828i */
            12'h562: dout <= { 10'sd239   , -10'sd453   }; /* W[ 708] =  0.4668  -0.8848i */
            12'h563: dout <= { 10'sd237   , -10'sd454   }; /* W[ 710] =  0.4629  -0.8867i */
            12'h564: dout <= { 10'sd236   , -10'sd454   }; /* W[ 712] =  0.4609  -0.8867i */
            12'h565: dout <= { 10'sd234   , -10'sd455   }; /* W[ 714] =  0.4570  -0.8887i */
            12'h566: dout <= { 10'sd233   , -10'sd456   }; /* W[ 716] =  0.4551  -0.8906i */
            12'h567: dout <= { 10'sd232   , -10'sd457   }; /* W[ 718] =  0.4531  -0.8926i */
            12'h568: dout <= { 10'sd230   , -10'sd457   }; /* W[ 720] =  0.4492  -0.8926i */
            12'h569: dout <= { 10'sd229   , -10'sd458   }; /* W[ 722] =  0.4473  -0.8945i */
            12'h56A: dout <= { 10'sd227   , -10'sd459   }; /* W[ 724] =  0.4434  -0.8965i */
            12'h56B: dout <= { 10'sd226   , -10'sd459   }; /* W[ 726] =  0.4414  -0.8965i */
            12'h56C: dout <= { 10'sd225   , -10'sd460   }; /* W[ 728] =  0.4395  -0.8984i */
            12'h56D: dout <= { 10'sd223   , -10'sd461   }; /* W[ 730] =  0.4355  -0.9004i */
            12'h56E: dout <= { 10'sd222   , -10'sd461   }; /* W[ 732] =  0.4336  -0.9004i */
            12'h56F: dout <= { 10'sd220   , -10'sd462   }; /* W[ 734] =  0.4297  -0.9023i */
            12'h570: dout <= { 10'sd219   , -10'sd463   }; /* W[ 736] =  0.4277  -0.9043i */
            12'h571: dout <= { 10'sd217   , -10'sd464   }; /* W[ 738] =  0.4238  -0.9062i */
            12'h572: dout <= { 10'sd216   , -10'sd464   }; /* W[ 740] =  0.4219  -0.9062i */
            12'h573: dout <= { 10'sd215   , -10'sd465   }; /* W[ 742] =  0.4199  -0.9082i */
            12'h574: dout <= { 10'sd213   , -10'sd465   }; /* W[ 744] =  0.4160  -0.9082i */
            12'h575: dout <= { 10'sd212   , -10'sd466   }; /* W[ 746] =  0.4141  -0.9102i */
            12'h576: dout <= { 10'sd210   , -10'sd467   }; /* W[ 748] =  0.4102  -0.9121i */
            12'h577: dout <= { 10'sd209   , -10'sd467   }; /* W[ 750] =  0.4082  -0.9121i */
            12'h578: dout <= { 10'sd207   , -10'sd468   }; /* W[ 752] =  0.4043  -0.9141i */
            12'h579: dout <= { 10'sd206   , -10'sd469   }; /* W[ 754] =  0.4023  -0.9160i */
            12'h57A: dout <= { 10'sd205   , -10'sd469   }; /* W[ 756] =  0.4004  -0.9160i */
            12'h57B: dout <= { 10'sd203   , -10'sd470   }; /* W[ 758] =  0.3965  -0.9180i */
            12'h57C: dout <= { 10'sd202   , -10'sd471   }; /* W[ 760] =  0.3945  -0.9199i */
            12'h57D: dout <= { 10'sd200   , -10'sd471   }; /* W[ 762] =  0.3906  -0.9199i */
            12'h57E: dout <= { 10'sd199   , -10'sd472   }; /* W[ 764] =  0.3887  -0.9219i */
            12'h57F: dout <= { 10'sd197   , -10'sd472   }; /* W[ 766] =  0.3848  -0.9219i */
            12'h580: dout <= { 10'sd196   , -10'sd473   }; /* W[ 768] =  0.3828  -0.9238i */
            12'h581: dout <= { 10'sd194   , -10'sd474   }; /* W[ 770] =  0.3789  -0.9258i */
            12'h582: dout <= { 10'sd193   , -10'sd474   }; /* W[ 772] =  0.3770  -0.9258i */
            12'h583: dout <= { 10'sd192   , -10'sd475   }; /* W[ 774] =  0.3750  -0.9277i */
            12'h584: dout <= { 10'sd190   , -10'sd475   }; /* W[ 776] =  0.3711  -0.9277i */
            12'h585: dout <= { 10'sd189   , -10'sd476   }; /* W[ 778] =  0.3691  -0.9297i */
            12'h586: dout <= { 10'sd187   , -10'sd477   }; /* W[ 780] =  0.3652  -0.9316i */
            12'h587: dout <= { 10'sd186   , -10'sd477   }; /* W[ 782] =  0.3633  -0.9316i */
            12'h588: dout <= { 10'sd184   , -10'sd478   }; /* W[ 784] =  0.3594  -0.9336i */
            12'h589: dout <= { 10'sd183   , -10'sd478   }; /* W[ 786] =  0.3574  -0.9336i */
            12'h58A: dout <= { 10'sd181   , -10'sd479   }; /* W[ 788] =  0.3535  -0.9355i */
            12'h58B: dout <= { 10'sd180   , -10'sd479   }; /* W[ 790] =  0.3516  -0.9355i */
            12'h58C: dout <= { 10'sd178   , -10'sd480   }; /* W[ 792] =  0.3477  -0.9375i */
            12'h58D: dout <= { 10'sd177   , -10'sd480   }; /* W[ 794] =  0.3457  -0.9375i */
            12'h58E: dout <= { 10'sd175   , -10'sd481   }; /* W[ 796] =  0.3418  -0.9395i */
            12'h58F: dout <= { 10'sd174   , -10'sd482   }; /* W[ 798] =  0.3398  -0.9414i */
            12'h590: dout <= { 10'sd172   , -10'sd482   }; /* W[ 800] =  0.3359  -0.9414i */
            12'h591: dout <= { 10'sd171   , -10'sd483   }; /* W[ 802] =  0.3340  -0.9434i */
            12'h592: dout <= { 10'sd170   , -10'sd483   }; /* W[ 804] =  0.3320  -0.9434i */
            12'h593: dout <= { 10'sd168   , -10'sd484   }; /* W[ 806] =  0.3281  -0.9453i */
            12'h594: dout <= { 10'sd167   , -10'sd484   }; /* W[ 808] =  0.3262  -0.9453i */
            12'h595: dout <= { 10'sd165   , -10'sd485   }; /* W[ 810] =  0.3223  -0.9473i */
            12'h596: dout <= { 10'sd164   , -10'sd485   }; /* W[ 812] =  0.3203  -0.9473i */
            12'h597: dout <= { 10'sd162   , -10'sd486   }; /* W[ 814] =  0.3164  -0.9492i */
            12'h598: dout <= { 10'sd161   , -10'sd486   }; /* W[ 816] =  0.3145  -0.9492i */
            12'h599: dout <= { 10'sd159   , -10'sd487   }; /* W[ 818] =  0.3105  -0.9512i */
            12'h59A: dout <= { 10'sd158   , -10'sd487   }; /* W[ 820] =  0.3086  -0.9512i */
            12'h59B: dout <= { 10'sd156   , -10'sd488   }; /* W[ 822] =  0.3047  -0.9531i */
            12'h59C: dout <= { 10'sd155   , -10'sd488   }; /* W[ 824] =  0.3027  -0.9531i */
            12'h59D: dout <= { 10'sd153   , -10'sd489   }; /* W[ 826] =  0.2988  -0.9551i */
            12'h59E: dout <= { 10'sd152   , -10'sd489   }; /* W[ 828] =  0.2969  -0.9551i */
            12'h59F: dout <= { 10'sd150   , -10'sd489   }; /* W[ 830] =  0.2930  -0.9551i */
            12'h5A0: dout <= { 10'sd149   , -10'sd490   }; /* W[ 832] =  0.2910  -0.9570i */
            12'h5A1: dout <= { 10'sd147   , -10'sd490   }; /* W[ 834] =  0.2871  -0.9570i */
            12'h5A2: dout <= { 10'sd146   , -10'sd491   }; /* W[ 836] =  0.2852  -0.9590i */
            12'h5A3: dout <= { 10'sd144   , -10'sd491   }; /* W[ 838] =  0.2812  -0.9590i */
            12'h5A4: dout <= { 10'sd143   , -10'sd492   }; /* W[ 840] =  0.2793  -0.9609i */
            12'h5A5: dout <= { 10'sd141   , -10'sd492   }; /* W[ 842] =  0.2754  -0.9609i */
            12'h5A6: dout <= { 10'sd140   , -10'sd493   }; /* W[ 844] =  0.2734  -0.9629i */
            12'h5A7: dout <= { 10'sd138   , -10'sd493   }; /* W[ 846] =  0.2695  -0.9629i */
            12'h5A8: dout <= { 10'sd137   , -10'sd493   }; /* W[ 848] =  0.2676  -0.9629i */
            12'h5A9: dout <= { 10'sd135   , -10'sd494   }; /* W[ 850] =  0.2637  -0.9648i */
            12'h5AA: dout <= { 10'sd134   , -10'sd494   }; /* W[ 852] =  0.2617  -0.9648i */
            12'h5AB: dout <= { 10'sd132   , -10'sd495   }; /* W[ 854] =  0.2578  -0.9668i */
            12'h5AC: dout <= { 10'sd130   , -10'sd495   }; /* W[ 856] =  0.2539  -0.9668i */
            12'h5AD: dout <= { 10'sd129   , -10'sd495   }; /* W[ 858] =  0.2520  -0.9668i */
            12'h5AE: dout <= { 10'sd127   , -10'sd496   }; /* W[ 860] =  0.2480  -0.9688i */
            12'h5AF: dout <= { 10'sd126   , -10'sd496   }; /* W[ 862] =  0.2461  -0.9688i */
            12'h5B0: dout <= { 10'sd124   , -10'sd497   }; /* W[ 864] =  0.2422  -0.9707i */
            12'h5B1: dout <= { 10'sd123   , -10'sd497   }; /* W[ 866] =  0.2402  -0.9707i */
            12'h5B2: dout <= { 10'sd121   , -10'sd497   }; /* W[ 868] =  0.2363  -0.9707i */
            12'h5B3: dout <= { 10'sd120   , -10'sd498   }; /* W[ 870] =  0.2344  -0.9727i */
            12'h5B4: dout <= { 10'sd118   , -10'sd498   }; /* W[ 872] =  0.2305  -0.9727i */
            12'h5B5: dout <= { 10'sd117   , -10'sd499   }; /* W[ 874] =  0.2285  -0.9746i */
            12'h5B6: dout <= { 10'sd115   , -10'sd499   }; /* W[ 876] =  0.2246  -0.9746i */
            12'h5B7: dout <= { 10'sd114   , -10'sd499   }; /* W[ 878] =  0.2227  -0.9746i */
            12'h5B8: dout <= { 10'sd112   , -10'sd500   }; /* W[ 880] =  0.2188  -0.9766i */
            12'h5B9: dout <= { 10'sd111   , -10'sd500   }; /* W[ 882] =  0.2168  -0.9766i */
            12'h5BA: dout <= { 10'sd109   , -10'sd500   }; /* W[ 884] =  0.2129  -0.9766i */
            12'h5BB: dout <= { 10'sd108   , -10'sd501   }; /* W[ 886] =  0.2109  -0.9785i */
            12'h5BC: dout <= { 10'sd106   , -10'sd501   }; /* W[ 888] =  0.2070  -0.9785i */
            12'h5BD: dout <= { 10'sd105   , -10'sd501   }; /* W[ 890] =  0.2051  -0.9785i */
            12'h5BE: dout <= { 10'sd103   , -10'sd502   }; /* W[ 892] =  0.2012  -0.9805i */
            12'h5BF: dout <= { 10'sd101   , -10'sd502   }; /* W[ 894] =  0.1973  -0.9805i */
            12'h5C0: dout <= { 10'sd100   , -10'sd502   }; /* W[ 896] =  0.1953  -0.9805i */
            12'h5C1: dout <= { 10'sd98    , -10'sd502   }; /* W[ 898] =  0.1914  -0.9805i */
            12'h5C2: dout <= { 10'sd97    , -10'sd503   }; /* W[ 900] =  0.1895  -0.9824i */
            12'h5C3: dout <= { 10'sd95    , -10'sd503   }; /* W[ 902] =  0.1855  -0.9824i */
            12'h5C4: dout <= { 10'sd94    , -10'sd503   }; /* W[ 904] =  0.1836  -0.9824i */
            12'h5C5: dout <= { 10'sd92    , -10'sd504   }; /* W[ 906] =  0.1797  -0.9844i */
            12'h5C6: dout <= { 10'sd91    , -10'sd504   }; /* W[ 908] =  0.1777  -0.9844i */
            12'h5C7: dout <= { 10'sd89    , -10'sd504   }; /* W[ 910] =  0.1738  -0.9844i */
            12'h5C8: dout <= { 10'sd88    , -10'sd504   }; /* W[ 912] =  0.1719  -0.9844i */
            12'h5C9: dout <= { 10'sd86    , -10'sd505   }; /* W[ 914] =  0.1680  -0.9863i */
            12'h5CA: dout <= { 10'sd84    , -10'sd505   }; /* W[ 916] =  0.1641  -0.9863i */
            12'h5CB: dout <= { 10'sd83    , -10'sd505   }; /* W[ 918] =  0.1621  -0.9863i */
            12'h5CC: dout <= { 10'sd81    , -10'sd505   }; /* W[ 920] =  0.1582  -0.9863i */
            12'h5CD: dout <= { 10'sd80    , -10'sd506   }; /* W[ 922] =  0.1562  -0.9883i */
            12'h5CE: dout <= { 10'sd78    , -10'sd506   }; /* W[ 924] =  0.1523  -0.9883i */
            12'h5CF: dout <= { 10'sd77    , -10'sd506   }; /* W[ 926] =  0.1504  -0.9883i */
            12'h5D0: dout <= { 10'sd75    , -10'sd506   }; /* W[ 928] =  0.1465  -0.9883i */
            12'h5D1: dout <= { 10'sd74    , -10'sd507   }; /* W[ 930] =  0.1445  -0.9902i */
            12'h5D2: dout <= { 10'sd72    , -10'sd507   }; /* W[ 932] =  0.1406  -0.9902i */
            12'h5D3: dout <= { 10'sd70    , -10'sd507   }; /* W[ 934] =  0.1367  -0.9902i */
            12'h5D4: dout <= { 10'sd69    , -10'sd507   }; /* W[ 936] =  0.1348  -0.9902i */
            12'h5D5: dout <= { 10'sd67    , -10'sd508   }; /* W[ 938] =  0.1309  -0.9922i */
            12'h5D6: dout <= { 10'sd66    , -10'sd508   }; /* W[ 940] =  0.1289  -0.9922i */
            12'h5D7: dout <= { 10'sd64    , -10'sd508   }; /* W[ 942] =  0.1250  -0.9922i */
            12'h5D8: dout <= { 10'sd63    , -10'sd508   }; /* W[ 944] =  0.1230  -0.9922i */
            12'h5D9: dout <= { 10'sd61    , -10'sd508   }; /* W[ 946] =  0.1191  -0.9922i */
            12'h5DA: dout <= { 10'sd60    , -10'sd509   }; /* W[ 948] =  0.1172  -0.9941i */
            12'h5DB: dout <= { 10'sd58    , -10'sd509   }; /* W[ 950] =  0.1133  -0.9941i */
            12'h5DC: dout <= { 10'sd56    , -10'sd509   }; /* W[ 952] =  0.1094  -0.9941i */
            12'h5DD: dout <= { 10'sd55    , -10'sd509   }; /* W[ 954] =  0.1074  -0.9941i */
            12'h5DE: dout <= { 10'sd53    , -10'sd509   }; /* W[ 956] =  0.1035  -0.9941i */
            12'h5DF: dout <= { 10'sd52    , -10'sd509   }; /* W[ 958] =  0.1016  -0.9941i */
            12'h5E0: dout <= { 10'sd50    , -10'sd510   }; /* W[ 960] =  0.0977  -0.9961i */
            12'h5E1: dout <= { 10'sd49    , -10'sd510   }; /* W[ 962] =  0.0957  -0.9961i */
            12'h5E2: dout <= { 10'sd47    , -10'sd510   }; /* W[ 964] =  0.0918  -0.9961i */
            12'h5E3: dout <= { 10'sd45    , -10'sd510   }; /* W[ 966] =  0.0879  -0.9961i */
            12'h5E4: dout <= { 10'sd44    , -10'sd510   }; /* W[ 968] =  0.0859  -0.9961i */
            12'h5E5: dout <= { 10'sd42    , -10'sd510   }; /* W[ 970] =  0.0820  -0.9961i */
            12'h5E6: dout <= { 10'sd41    , -10'sd510   }; /* W[ 972] =  0.0801  -0.9961i */
            12'h5E7: dout <= { 10'sd39    , -10'sd510   }; /* W[ 974] =  0.0762  -0.9961i */
            12'h5E8: dout <= { 10'sd38    , -10'sd511   }; /* W[ 976] =  0.0742  -0.9980i */
            12'h5E9: dout <= { 10'sd36    , -10'sd511   }; /* W[ 978] =  0.0703  -0.9980i */
            12'h5EA: dout <= { 10'sd35    , -10'sd511   }; /* W[ 980] =  0.0684  -0.9980i */
            12'h5EB: dout <= { 10'sd33    , -10'sd511   }; /* W[ 982] =  0.0645  -0.9980i */
            12'h5EC: dout <= { 10'sd31    , -10'sd511   }; /* W[ 984] =  0.0605  -0.9980i */
            12'h5ED: dout <= { 10'sd30    , -10'sd511   }; /* W[ 986] =  0.0586  -0.9980i */
            12'h5EE: dout <= { 10'sd28    , -10'sd511   }; /* W[ 988] =  0.0547  -0.9980i */
            12'h5EF: dout <= { 10'sd27    , -10'sd511   }; /* W[ 990] =  0.0527  -0.9980i */
            12'h5F0: dout <= { 10'sd25    , -10'sd511   }; /* W[ 992] =  0.0488  -0.9980i */
            12'h5F1: dout <= { 10'sd24    , -10'sd511   }; /* W[ 994] =  0.0469  -0.9980i */
            12'h5F2: dout <= { 10'sd22    , -10'sd512   }; /* W[ 996] =  0.0430  -1.0000i */
            12'h5F3: dout <= { 10'sd20    , -10'sd512   }; /* W[ 998] =  0.0391  -1.0000i */
            12'h5F4: dout <= { 10'sd19    , -10'sd512   }; /* W[1000] =  0.0371  -1.0000i */
            12'h5F5: dout <= { 10'sd17    , -10'sd512   }; /* W[1002] =  0.0332  -1.0000i */
            12'h5F6: dout <= { 10'sd16    , -10'sd512   }; /* W[1004] =  0.0312  -1.0000i */
            12'h5F7: dout <= { 10'sd14    , -10'sd512   }; /* W[1006] =  0.0273  -1.0000i */
            12'h5F8: dout <= { 10'sd13    , -10'sd512   }; /* W[1008] =  0.0254  -1.0000i */
            12'h5F9: dout <= { 10'sd11    , -10'sd512   }; /* W[1010] =  0.0215  -1.0000i */
            12'h5FA: dout <= { 10'sd9     , -10'sd512   }; /* W[1012] =  0.0176  -1.0000i */
            12'h5FB: dout <= { 10'sd8     , -10'sd512   }; /* W[1014] =  0.0156  -1.0000i */
            12'h5FC: dout <= { 10'sd6     , -10'sd512   }; /* W[1016] =  0.0117  -1.0000i */
            12'h5FD: dout <= { 10'sd5     , -10'sd512   }; /* W[1018] =  0.0098  -1.0000i */
            12'h5FE: dout <= { 10'sd3     , -10'sd512   }; /* W[1020] =  0.0059  -1.0000i */
            12'h5FF: dout <= { 10'sd2     , -10'sd512   }; /* W[1022] =  0.0039  -1.0000i */
            12'h600: dout <= { 10'sd0     , -10'sd512   }; /* W[1024] =  0.0000  -1.0000i */
            12'h601: dout <= {-10'sd2     , -10'sd512   }; /* W[1026] = -0.0039  -1.0000i */
            12'h602: dout <= {-10'sd3     , -10'sd512   }; /* W[1028] = -0.0059  -1.0000i */
            12'h603: dout <= {-10'sd5     , -10'sd512   }; /* W[1030] = -0.0098  -1.0000i */
            12'h604: dout <= {-10'sd6     , -10'sd512   }; /* W[1032] = -0.0117  -1.0000i */
            12'h605: dout <= {-10'sd8     , -10'sd512   }; /* W[1034] = -0.0156  -1.0000i */
            12'h606: dout <= {-10'sd9     , -10'sd512   }; /* W[1036] = -0.0176  -1.0000i */
            12'h607: dout <= {-10'sd11    , -10'sd512   }; /* W[1038] = -0.0215  -1.0000i */
            12'h608: dout <= {-10'sd13    , -10'sd512   }; /* W[1040] = -0.0254  -1.0000i */
            12'h609: dout <= {-10'sd14    , -10'sd512   }; /* W[1042] = -0.0273  -1.0000i */
            12'h60A: dout <= {-10'sd16    , -10'sd512   }; /* W[1044] = -0.0312  -1.0000i */
            12'h60B: dout <= {-10'sd17    , -10'sd512   }; /* W[1046] = -0.0332  -1.0000i */
            12'h60C: dout <= {-10'sd19    , -10'sd512   }; /* W[1048] = -0.0371  -1.0000i */
            12'h60D: dout <= {-10'sd20    , -10'sd512   }; /* W[1050] = -0.0391  -1.0000i */
            12'h60E: dout <= {-10'sd22    , -10'sd512   }; /* W[1052] = -0.0430  -1.0000i */
            12'h60F: dout <= {-10'sd24    , -10'sd511   }; /* W[1054] = -0.0469  -0.9980i */
            12'h610: dout <= {-10'sd25    , -10'sd511   }; /* W[1056] = -0.0488  -0.9980i */
            12'h611: dout <= {-10'sd27    , -10'sd511   }; /* W[1058] = -0.0527  -0.9980i */
            12'h612: dout <= {-10'sd28    , -10'sd511   }; /* W[1060] = -0.0547  -0.9980i */
            12'h613: dout <= {-10'sd30    , -10'sd511   }; /* W[1062] = -0.0586  -0.9980i */
            12'h614: dout <= {-10'sd31    , -10'sd511   }; /* W[1064] = -0.0605  -0.9980i */
            12'h615: dout <= {-10'sd33    , -10'sd511   }; /* W[1066] = -0.0645  -0.9980i */
            12'h616: dout <= {-10'sd35    , -10'sd511   }; /* W[1068] = -0.0684  -0.9980i */
            12'h617: dout <= {-10'sd36    , -10'sd511   }; /* W[1070] = -0.0703  -0.9980i */
            12'h618: dout <= {-10'sd38    , -10'sd511   }; /* W[1072] = -0.0742  -0.9980i */
            12'h619: dout <= {-10'sd39    , -10'sd510   }; /* W[1074] = -0.0762  -0.9961i */
            12'h61A: dout <= {-10'sd41    , -10'sd510   }; /* W[1076] = -0.0801  -0.9961i */
            12'h61B: dout <= {-10'sd42    , -10'sd510   }; /* W[1078] = -0.0820  -0.9961i */
            12'h61C: dout <= {-10'sd44    , -10'sd510   }; /* W[1080] = -0.0859  -0.9961i */
            12'h61D: dout <= {-10'sd45    , -10'sd510   }; /* W[1082] = -0.0879  -0.9961i */
            12'h61E: dout <= {-10'sd47    , -10'sd510   }; /* W[1084] = -0.0918  -0.9961i */
            12'h61F: dout <= {-10'sd49    , -10'sd510   }; /* W[1086] = -0.0957  -0.9961i */
            12'h620: dout <= {-10'sd50    , -10'sd510   }; /* W[1088] = -0.0977  -0.9961i */
            12'h621: dout <= {-10'sd52    , -10'sd509   }; /* W[1090] = -0.1016  -0.9941i */
            12'h622: dout <= {-10'sd53    , -10'sd509   }; /* W[1092] = -0.1035  -0.9941i */
            12'h623: dout <= {-10'sd55    , -10'sd509   }; /* W[1094] = -0.1074  -0.9941i */
            12'h624: dout <= {-10'sd56    , -10'sd509   }; /* W[1096] = -0.1094  -0.9941i */
            12'h625: dout <= {-10'sd58    , -10'sd509   }; /* W[1098] = -0.1133  -0.9941i */
            12'h626: dout <= {-10'sd60    , -10'sd509   }; /* W[1100] = -0.1172  -0.9941i */
            12'h627: dout <= {-10'sd61    , -10'sd508   }; /* W[1102] = -0.1191  -0.9922i */
            12'h628: dout <= {-10'sd63    , -10'sd508   }; /* W[1104] = -0.1230  -0.9922i */
            12'h629: dout <= {-10'sd64    , -10'sd508   }; /* W[1106] = -0.1250  -0.9922i */
            12'h62A: dout <= {-10'sd66    , -10'sd508   }; /* W[1108] = -0.1289  -0.9922i */
            12'h62B: dout <= {-10'sd67    , -10'sd508   }; /* W[1110] = -0.1309  -0.9922i */
            12'h62C: dout <= {-10'sd69    , -10'sd507   }; /* W[1112] = -0.1348  -0.9902i */
            12'h62D: dout <= {-10'sd70    , -10'sd507   }; /* W[1114] = -0.1367  -0.9902i */
            12'h62E: dout <= {-10'sd72    , -10'sd507   }; /* W[1116] = -0.1406  -0.9902i */
            12'h62F: dout <= {-10'sd74    , -10'sd507   }; /* W[1118] = -0.1445  -0.9902i */
            12'h630: dout <= {-10'sd75    , -10'sd506   }; /* W[1120] = -0.1465  -0.9883i */
            12'h631: dout <= {-10'sd77    , -10'sd506   }; /* W[1122] = -0.1504  -0.9883i */
            12'h632: dout <= {-10'sd78    , -10'sd506   }; /* W[1124] = -0.1523  -0.9883i */
            12'h633: dout <= {-10'sd80    , -10'sd506   }; /* W[1126] = -0.1562  -0.9883i */
            12'h634: dout <= {-10'sd81    , -10'sd505   }; /* W[1128] = -0.1582  -0.9863i */
            12'h635: dout <= {-10'sd83    , -10'sd505   }; /* W[1130] = -0.1621  -0.9863i */
            12'h636: dout <= {-10'sd84    , -10'sd505   }; /* W[1132] = -0.1641  -0.9863i */
            12'h637: dout <= {-10'sd86    , -10'sd505   }; /* W[1134] = -0.1680  -0.9863i */
            12'h638: dout <= {-10'sd88    , -10'sd504   }; /* W[1136] = -0.1719  -0.9844i */
            12'h639: dout <= {-10'sd89    , -10'sd504   }; /* W[1138] = -0.1738  -0.9844i */
            12'h63A: dout <= {-10'sd91    , -10'sd504   }; /* W[1140] = -0.1777  -0.9844i */
            12'h63B: dout <= {-10'sd92    , -10'sd504   }; /* W[1142] = -0.1797  -0.9844i */
            12'h63C: dout <= {-10'sd94    , -10'sd503   }; /* W[1144] = -0.1836  -0.9824i */
            12'h63D: dout <= {-10'sd95    , -10'sd503   }; /* W[1146] = -0.1855  -0.9824i */
            12'h63E: dout <= {-10'sd97    , -10'sd503   }; /* W[1148] = -0.1895  -0.9824i */
            12'h63F: dout <= {-10'sd98    , -10'sd502   }; /* W[1150] = -0.1914  -0.9805i */
            12'h640: dout <= {-10'sd100   , -10'sd502   }; /* W[1152] = -0.1953  -0.9805i */
            12'h641: dout <= {-10'sd101   , -10'sd502   }; /* W[1154] = -0.1973  -0.9805i */
            12'h642: dout <= {-10'sd103   , -10'sd502   }; /* W[1156] = -0.2012  -0.9805i */
            12'h643: dout <= {-10'sd105   , -10'sd501   }; /* W[1158] = -0.2051  -0.9785i */
            12'h644: dout <= {-10'sd106   , -10'sd501   }; /* W[1160] = -0.2070  -0.9785i */
            12'h645: dout <= {-10'sd108   , -10'sd501   }; /* W[1162] = -0.2109  -0.9785i */
            12'h646: dout <= {-10'sd109   , -10'sd500   }; /* W[1164] = -0.2129  -0.9766i */
            12'h647: dout <= {-10'sd111   , -10'sd500   }; /* W[1166] = -0.2168  -0.9766i */
            12'h648: dout <= {-10'sd112   , -10'sd500   }; /* W[1168] = -0.2188  -0.9766i */
            12'h649: dout <= {-10'sd114   , -10'sd499   }; /* W[1170] = -0.2227  -0.9746i */
            12'h64A: dout <= {-10'sd115   , -10'sd499   }; /* W[1172] = -0.2246  -0.9746i */
            12'h64B: dout <= {-10'sd117   , -10'sd499   }; /* W[1174] = -0.2285  -0.9746i */
            12'h64C: dout <= {-10'sd118   , -10'sd498   }; /* W[1176] = -0.2305  -0.9727i */
            12'h64D: dout <= {-10'sd120   , -10'sd498   }; /* W[1178] = -0.2344  -0.9727i */
            12'h64E: dout <= {-10'sd121   , -10'sd497   }; /* W[1180] = -0.2363  -0.9707i */
            12'h64F: dout <= {-10'sd123   , -10'sd497   }; /* W[1182] = -0.2402  -0.9707i */
            12'h650: dout <= {-10'sd124   , -10'sd497   }; /* W[1184] = -0.2422  -0.9707i */
            12'h651: dout <= {-10'sd126   , -10'sd496   }; /* W[1186] = -0.2461  -0.9688i */
            12'h652: dout <= {-10'sd127   , -10'sd496   }; /* W[1188] = -0.2480  -0.9688i */
            12'h653: dout <= {-10'sd129   , -10'sd495   }; /* W[1190] = -0.2520  -0.9668i */
            12'h654: dout <= {-10'sd130   , -10'sd495   }; /* W[1192] = -0.2539  -0.9668i */
            12'h655: dout <= {-10'sd132   , -10'sd495   }; /* W[1194] = -0.2578  -0.9668i */
            12'h656: dout <= {-10'sd134   , -10'sd494   }; /* W[1196] = -0.2617  -0.9648i */
            12'h657: dout <= {-10'sd135   , -10'sd494   }; /* W[1198] = -0.2637  -0.9648i */
            12'h658: dout <= {-10'sd137   , -10'sd493   }; /* W[1200] = -0.2676  -0.9629i */
            12'h659: dout <= {-10'sd138   , -10'sd493   }; /* W[1202] = -0.2695  -0.9629i */
            12'h65A: dout <= {-10'sd140   , -10'sd493   }; /* W[1204] = -0.2734  -0.9629i */
            12'h65B: dout <= {-10'sd141   , -10'sd492   }; /* W[1206] = -0.2754  -0.9609i */
            12'h65C: dout <= {-10'sd143   , -10'sd492   }; /* W[1208] = -0.2793  -0.9609i */
            12'h65D: dout <= {-10'sd144   , -10'sd491   }; /* W[1210] = -0.2812  -0.9590i */
            12'h65E: dout <= {-10'sd146   , -10'sd491   }; /* W[1212] = -0.2852  -0.9590i */
            12'h65F: dout <= {-10'sd147   , -10'sd490   }; /* W[1214] = -0.2871  -0.9570i */
            12'h660: dout <= {-10'sd149   , -10'sd490   }; /* W[1216] = -0.2910  -0.9570i */
            12'h661: dout <= {-10'sd150   , -10'sd489   }; /* W[1218] = -0.2930  -0.9551i */
            12'h662: dout <= {-10'sd152   , -10'sd489   }; /* W[1220] = -0.2969  -0.9551i */
            12'h663: dout <= {-10'sd153   , -10'sd489   }; /* W[1222] = -0.2988  -0.9551i */
            12'h664: dout <= {-10'sd155   , -10'sd488   }; /* W[1224] = -0.3027  -0.9531i */
            12'h665: dout <= {-10'sd156   , -10'sd488   }; /* W[1226] = -0.3047  -0.9531i */
            12'h666: dout <= {-10'sd158   , -10'sd487   }; /* W[1228] = -0.3086  -0.9512i */
            12'h667: dout <= {-10'sd159   , -10'sd487   }; /* W[1230] = -0.3105  -0.9512i */
            12'h668: dout <= {-10'sd161   , -10'sd486   }; /* W[1232] = -0.3145  -0.9492i */
            12'h669: dout <= {-10'sd162   , -10'sd486   }; /* W[1234] = -0.3164  -0.9492i */
            12'h66A: dout <= {-10'sd164   , -10'sd485   }; /* W[1236] = -0.3203  -0.9473i */
            12'h66B: dout <= {-10'sd165   , -10'sd485   }; /* W[1238] = -0.3223  -0.9473i */
            12'h66C: dout <= {-10'sd167   , -10'sd484   }; /* W[1240] = -0.3262  -0.9453i */
            12'h66D: dout <= {-10'sd168   , -10'sd484   }; /* W[1242] = -0.3281  -0.9453i */
            12'h66E: dout <= {-10'sd170   , -10'sd483   }; /* W[1244] = -0.3320  -0.9434i */
            12'h66F: dout <= {-10'sd171   , -10'sd483   }; /* W[1246] = -0.3340  -0.9434i */
            12'h670: dout <= {-10'sd172   , -10'sd482   }; /* W[1248] = -0.3359  -0.9414i */
            12'h671: dout <= {-10'sd174   , -10'sd482   }; /* W[1250] = -0.3398  -0.9414i */
            12'h672: dout <= {-10'sd175   , -10'sd481   }; /* W[1252] = -0.3418  -0.9395i */
            12'h673: dout <= {-10'sd177   , -10'sd480   }; /* W[1254] = -0.3457  -0.9375i */
            12'h674: dout <= {-10'sd178   , -10'sd480   }; /* W[1256] = -0.3477  -0.9375i */
            12'h675: dout <= {-10'sd180   , -10'sd479   }; /* W[1258] = -0.3516  -0.9355i */
            12'h676: dout <= {-10'sd181   , -10'sd479   }; /* W[1260] = -0.3535  -0.9355i */
            12'h677: dout <= {-10'sd183   , -10'sd478   }; /* W[1262] = -0.3574  -0.9336i */
            12'h678: dout <= {-10'sd184   , -10'sd478   }; /* W[1264] = -0.3594  -0.9336i */
            12'h679: dout <= {-10'sd186   , -10'sd477   }; /* W[1266] = -0.3633  -0.9316i */
            12'h67A: dout <= {-10'sd187   , -10'sd477   }; /* W[1268] = -0.3652  -0.9316i */
            12'h67B: dout <= {-10'sd189   , -10'sd476   }; /* W[1270] = -0.3691  -0.9297i */
            12'h67C: dout <= {-10'sd190   , -10'sd475   }; /* W[1272] = -0.3711  -0.9277i */
            12'h67D: dout <= {-10'sd192   , -10'sd475   }; /* W[1274] = -0.3750  -0.9277i */
            12'h67E: dout <= {-10'sd193   , -10'sd474   }; /* W[1276] = -0.3770  -0.9258i */
            12'h67F: dout <= {-10'sd194   , -10'sd474   }; /* W[1278] = -0.3789  -0.9258i */
            12'h680: dout <= {-10'sd196   , -10'sd473   }; /* W[1280] = -0.3828  -0.9238i */
            12'h681: dout <= {-10'sd197   , -10'sd472   }; /* W[1282] = -0.3848  -0.9219i */
            12'h682: dout <= {-10'sd199   , -10'sd472   }; /* W[1284] = -0.3887  -0.9219i */
            12'h683: dout <= {-10'sd200   , -10'sd471   }; /* W[1286] = -0.3906  -0.9199i */
            12'h684: dout <= {-10'sd202   , -10'sd471   }; /* W[1288] = -0.3945  -0.9199i */
            12'h685: dout <= {-10'sd203   , -10'sd470   }; /* W[1290] = -0.3965  -0.9180i */
            12'h686: dout <= {-10'sd205   , -10'sd469   }; /* W[1292] = -0.4004  -0.9160i */
            12'h687: dout <= {-10'sd206   , -10'sd469   }; /* W[1294] = -0.4023  -0.9160i */
            12'h688: dout <= {-10'sd207   , -10'sd468   }; /* W[1296] = -0.4043  -0.9141i */
            12'h689: dout <= {-10'sd209   , -10'sd467   }; /* W[1298] = -0.4082  -0.9121i */
            12'h68A: dout <= {-10'sd210   , -10'sd467   }; /* W[1300] = -0.4102  -0.9121i */
            12'h68B: dout <= {-10'sd212   , -10'sd466   }; /* W[1302] = -0.4141  -0.9102i */
            12'h68C: dout <= {-10'sd213   , -10'sd465   }; /* W[1304] = -0.4160  -0.9082i */
            12'h68D: dout <= {-10'sd215   , -10'sd465   }; /* W[1306] = -0.4199  -0.9082i */
            12'h68E: dout <= {-10'sd216   , -10'sd464   }; /* W[1308] = -0.4219  -0.9062i */
            12'h68F: dout <= {-10'sd217   , -10'sd464   }; /* W[1310] = -0.4238  -0.9062i */
            12'h690: dout <= {-10'sd219   , -10'sd463   }; /* W[1312] = -0.4277  -0.9043i */
            12'h691: dout <= {-10'sd220   , -10'sd462   }; /* W[1314] = -0.4297  -0.9023i */
            12'h692: dout <= {-10'sd222   , -10'sd461   }; /* W[1316] = -0.4336  -0.9004i */
            12'h693: dout <= {-10'sd223   , -10'sd461   }; /* W[1318] = -0.4355  -0.9004i */
            12'h694: dout <= {-10'sd225   , -10'sd460   }; /* W[1320] = -0.4395  -0.8984i */
            12'h695: dout <= {-10'sd226   , -10'sd459   }; /* W[1322] = -0.4414  -0.8965i */
            12'h696: dout <= {-10'sd227   , -10'sd459   }; /* W[1324] = -0.4434  -0.8965i */
            12'h697: dout <= {-10'sd229   , -10'sd458   }; /* W[1326] = -0.4473  -0.8945i */
            12'h698: dout <= {-10'sd230   , -10'sd457   }; /* W[1328] = -0.4492  -0.8926i */
            12'h699: dout <= {-10'sd232   , -10'sd457   }; /* W[1330] = -0.4531  -0.8926i */
            12'h69A: dout <= {-10'sd233   , -10'sd456   }; /* W[1332] = -0.4551  -0.8906i */
            12'h69B: dout <= {-10'sd234   , -10'sd455   }; /* W[1334] = -0.4570  -0.8887i */
            12'h69C: dout <= {-10'sd236   , -10'sd454   }; /* W[1336] = -0.4609  -0.8867i */
            12'h69D: dout <= {-10'sd237   , -10'sd454   }; /* W[1338] = -0.4629  -0.8867i */
            12'h69E: dout <= {-10'sd239   , -10'sd453   }; /* W[1340] = -0.4668  -0.8848i */
            12'h69F: dout <= {-10'sd240   , -10'sd452   }; /* W[1342] = -0.4688  -0.8828i */
            12'h6A0: dout <= {-10'sd241   , -10'sd452   }; /* W[1344] = -0.4707  -0.8828i */
            12'h6A1: dout <= {-10'sd243   , -10'sd451   }; /* W[1346] = -0.4746  -0.8809i */
            12'h6A2: dout <= {-10'sd244   , -10'sd450   }; /* W[1348] = -0.4766  -0.8789i */
            12'h6A3: dout <= {-10'sd246   , -10'sd449   }; /* W[1350] = -0.4805  -0.8770i */
            12'h6A4: dout <= {-10'sd247   , -10'sd449   }; /* W[1352] = -0.4824  -0.8770i */
            12'h6A5: dout <= {-10'sd248   , -10'sd448   }; /* W[1354] = -0.4844  -0.8750i */
            12'h6A6: dout <= {-10'sd250   , -10'sd447   }; /* W[1356] = -0.4883  -0.8730i */
            12'h6A7: dout <= {-10'sd251   , -10'sd446   }; /* W[1358] = -0.4902  -0.8711i */
            12'h6A8: dout <= {-10'sd252   , -10'sd445   }; /* W[1360] = -0.4922  -0.8691i */
            12'h6A9: dout <= {-10'sd254   , -10'sd445   }; /* W[1362] = -0.4961  -0.8691i */
            12'h6AA: dout <= {-10'sd255   , -10'sd444   }; /* W[1364] = -0.4980  -0.8672i */
            12'h6AB: dout <= {-10'sd256   , -10'sd443   }; /* W[1366] = -0.5000  -0.8652i */
            12'h6AC: dout <= {-10'sd258   , -10'sd442   }; /* W[1368] = -0.5039  -0.8633i */
            12'h6AD: dout <= {-10'sd259   , -10'sd442   }; /* W[1370] = -0.5059  -0.8633i */
            12'h6AE: dout <= {-10'sd261   , -10'sd441   }; /* W[1372] = -0.5098  -0.8613i */
            12'h6AF: dout <= {-10'sd262   , -10'sd440   }; /* W[1374] = -0.5117  -0.8594i */
            12'h6B0: dout <= {-10'sd263   , -10'sd439   }; /* W[1376] = -0.5137  -0.8574i */
            12'h6B1: dout <= {-10'sd265   , -10'sd438   }; /* W[1378] = -0.5176  -0.8555i */
            12'h6B2: dout <= {-10'sd266   , -10'sd438   }; /* W[1380] = -0.5195  -0.8555i */
            12'h6B3: dout <= {-10'sd267   , -10'sd437   }; /* W[1382] = -0.5215  -0.8535i */
            12'h6B4: dout <= {-10'sd269   , -10'sd436   }; /* W[1384] = -0.5254  -0.8516i */
            12'h6B5: dout <= {-10'sd270   , -10'sd435   }; /* W[1386] = -0.5273  -0.8496i */
            12'h6B6: dout <= {-10'sd271   , -10'sd434   }; /* W[1388] = -0.5293  -0.8477i */
            12'h6B7: dout <= {-10'sd273   , -10'sd433   }; /* W[1390] = -0.5332  -0.8457i */
            12'h6B8: dout <= {-10'sd274   , -10'sd433   }; /* W[1392] = -0.5352  -0.8457i */
            12'h6B9: dout <= {-10'sd275   , -10'sd432   }; /* W[1394] = -0.5371  -0.8438i */
            12'h6BA: dout <= {-10'sd277   , -10'sd431   }; /* W[1396] = -0.5410  -0.8418i */
            12'h6BB: dout <= {-10'sd278   , -10'sd430   }; /* W[1398] = -0.5430  -0.8398i */
            12'h6BC: dout <= {-10'sd279   , -10'sd429   }; /* W[1400] = -0.5449  -0.8379i */
            12'h6BD: dout <= {-10'sd281   , -10'sd428   }; /* W[1402] = -0.5488  -0.8359i */
            12'h6BE: dout <= {-10'sd282   , -10'sd427   }; /* W[1404] = -0.5508  -0.8340i */
            12'h6BF: dout <= {-10'sd283   , -10'sd427   }; /* W[1406] = -0.5527  -0.8340i */
            12'h6C0: dout <= {-10'sd284   , -10'sd426   }; /* W[1408] = -0.5547  -0.8320i */
            12'h6C1: dout <= {-10'sd286   , -10'sd425   }; /* W[1410] = -0.5586  -0.8301i */
            12'h6C2: dout <= {-10'sd287   , -10'sd424   }; /* W[1412] = -0.5605  -0.8281i */
            12'h6C3: dout <= {-10'sd288   , -10'sd423   }; /* W[1414] = -0.5625  -0.8262i */
            12'h6C4: dout <= {-10'sd290   , -10'sd422   }; /* W[1416] = -0.5664  -0.8242i */
            12'h6C5: dout <= {-10'sd291   , -10'sd421   }; /* W[1418] = -0.5684  -0.8223i */
            12'h6C6: dout <= {-10'sd292   , -10'sd420   }; /* W[1420] = -0.5703  -0.8203i */
            12'h6C7: dout <= {-10'sd294   , -10'sd420   }; /* W[1422] = -0.5742  -0.8203i */
            12'h6C8: dout <= {-10'sd295   , -10'sd419   }; /* W[1424] = -0.5762  -0.8184i */
            12'h6C9: dout <= {-10'sd296   , -10'sd418   }; /* W[1426] = -0.5781  -0.8164i */
            12'h6CA: dout <= {-10'sd297   , -10'sd417   }; /* W[1428] = -0.5801  -0.8145i */
            12'h6CB: dout <= {-10'sd299   , -10'sd416   }; /* W[1430] = -0.5840  -0.8125i */
            12'h6CC: dout <= {-10'sd300   , -10'sd415   }; /* W[1432] = -0.5859  -0.8105i */
            12'h6CD: dout <= {-10'sd301   , -10'sd414   }; /* W[1434] = -0.5879  -0.8086i */
            12'h6CE: dout <= {-10'sd302   , -10'sd413   }; /* W[1436] = -0.5898  -0.8066i */
            12'h6CF: dout <= {-10'sd304   , -10'sd412   }; /* W[1438] = -0.5938  -0.8047i */
            12'h6D0: dout <= {-10'sd305   , -10'sd411   }; /* W[1440] = -0.5957  -0.8027i */
            12'h6D1: dout <= {-10'sd306   , -10'sd410   }; /* W[1442] = -0.5977  -0.8008i */
            12'h6D2: dout <= {-10'sd308   , -10'sd409   }; /* W[1444] = -0.6016  -0.7988i */
            12'h6D3: dout <= {-10'sd309   , -10'sd408   }; /* W[1446] = -0.6035  -0.7969i */
            12'h6D4: dout <= {-10'sd310   , -10'sd407   }; /* W[1448] = -0.6055  -0.7949i */
            12'h6D5: dout <= {-10'sd311   , -10'sd407   }; /* W[1450] = -0.6074  -0.7949i */
            12'h6D6: dout <= {-10'sd313   , -10'sd406   }; /* W[1452] = -0.6113  -0.7930i */
            12'h6D7: dout <= {-10'sd314   , -10'sd405   }; /* W[1454] = -0.6133  -0.7910i */
            12'h6D8: dout <= {-10'sd315   , -10'sd404   }; /* W[1456] = -0.6152  -0.7891i */
            12'h6D9: dout <= {-10'sd316   , -10'sd403   }; /* W[1458] = -0.6172  -0.7871i */
            12'h6DA: dout <= {-10'sd317   , -10'sd402   }; /* W[1460] = -0.6191  -0.7852i */
            12'h6DB: dout <= {-10'sd319   , -10'sd401   }; /* W[1462] = -0.6230  -0.7832i */
            12'h6DC: dout <= {-10'sd320   , -10'sd400   }; /* W[1464] = -0.6250  -0.7812i */
            12'h6DD: dout <= {-10'sd321   , -10'sd399   }; /* W[1466] = -0.6270  -0.7793i */
            12'h6DE: dout <= {-10'sd322   , -10'sd398   }; /* W[1468] = -0.6289  -0.7773i */
            12'h6DF: dout <= {-10'sd324   , -10'sd397   }; /* W[1470] = -0.6328  -0.7754i */
            12'h6E0: dout <= {-10'sd325   , -10'sd396   }; /* W[1472] = -0.6348  -0.7734i */
            12'h6E1: dout <= {-10'sd326   , -10'sd395   }; /* W[1474] = -0.6367  -0.7715i */
            12'h6E2: dout <= {-10'sd327   , -10'sd394   }; /* W[1476] = -0.6387  -0.7695i */
            12'h6E3: dout <= {-10'sd328   , -10'sd393   }; /* W[1478] = -0.6406  -0.7676i */
            12'h6E4: dout <= {-10'sd330   , -10'sd392   }; /* W[1480] = -0.6445  -0.7656i */
            12'h6E5: dout <= {-10'sd331   , -10'sd391   }; /* W[1482] = -0.6465  -0.7637i */
            12'h6E6: dout <= {-10'sd332   , -10'sd390   }; /* W[1484] = -0.6484  -0.7617i */
            12'h6E7: dout <= {-10'sd333   , -10'sd389   }; /* W[1486] = -0.6504  -0.7598i */
            12'h6E8: dout <= {-10'sd334   , -10'sd388   }; /* W[1488] = -0.6523  -0.7578i */
            12'h6E9: dout <= {-10'sd336   , -10'sd387   }; /* W[1490] = -0.6562  -0.7559i */
            12'h6EA: dout <= {-10'sd337   , -10'sd386   }; /* W[1492] = -0.6582  -0.7539i */
            12'h6EB: dout <= {-10'sd338   , -10'sd385   }; /* W[1494] = -0.6602  -0.7520i */
            12'h6EC: dout <= {-10'sd339   , -10'sd384   }; /* W[1496] = -0.6621  -0.7500i */
            12'h6ED: dout <= {-10'sd340   , -10'sd383   }; /* W[1498] = -0.6641  -0.7480i */
            12'h6EE: dout <= {-10'sd342   , -10'sd381   }; /* W[1500] = -0.6680  -0.7441i */
            12'h6EF: dout <= {-10'sd343   , -10'sd380   }; /* W[1502] = -0.6699  -0.7422i */
            12'h6F0: dout <= {-10'sd344   , -10'sd379   }; /* W[1504] = -0.6719  -0.7402i */
            12'h6F1: dout <= {-10'sd345   , -10'sd378   }; /* W[1506] = -0.6738  -0.7383i */
            12'h6F2: dout <= {-10'sd346   , -10'sd377   }; /* W[1508] = -0.6758  -0.7363i */
            12'h6F3: dout <= {-10'sd347   , -10'sd376   }; /* W[1510] = -0.6777  -0.7344i */
            12'h6F4: dout <= {-10'sd348   , -10'sd375   }; /* W[1512] = -0.6797  -0.7324i */
            12'h6F5: dout <= {-10'sd350   , -10'sd374   }; /* W[1514] = -0.6836  -0.7305i */
            12'h6F6: dout <= {-10'sd351   , -10'sd373   }; /* W[1516] = -0.6855  -0.7285i */
            12'h6F7: dout <= {-10'sd352   , -10'sd372   }; /* W[1518] = -0.6875  -0.7266i */
            12'h6F8: dout <= {-10'sd353   , -10'sd371   }; /* W[1520] = -0.6895  -0.7246i */
            12'h6F9: dout <= {-10'sd354   , -10'sd370   }; /* W[1522] = -0.6914  -0.7227i */
            12'h6FA: dout <= {-10'sd355   , -10'sd369   }; /* W[1524] = -0.6934  -0.7207i */
            12'h6FB: dout <= {-10'sd356   , -10'sd368   }; /* W[1526] = -0.6953  -0.7188i */
            12'h6FC: dout <= {-10'sd358   , -10'sd366   }; /* W[1528] = -0.6992  -0.7148i */
            12'h6FD: dout <= {-10'sd359   , -10'sd365   }; /* W[1530] = -0.7012  -0.7129i */
            12'h6FE: dout <= {-10'sd360   , -10'sd364   }; /* W[1532] = -0.7031  -0.7109i */
            12'h6FF: dout <= {-10'sd361   , -10'sd363   }; /* W[1534] = -0.7051  -0.7090i */
            12'h700: dout <= {-10'sd362   , -10'sd362   }; /* W[1536] = -0.7070  -0.7070i */
            12'h701: dout <= {-10'sd363   , -10'sd361   }; /* W[1538] = -0.7090  -0.7051i */
            12'h702: dout <= {-10'sd364   , -10'sd360   }; /* W[1540] = -0.7109  -0.7031i */
            12'h703: dout <= {-10'sd365   , -10'sd359   }; /* W[1542] = -0.7129  -0.7012i */
            12'h704: dout <= {-10'sd366   , -10'sd358   }; /* W[1544] = -0.7148  -0.6992i */
            12'h705: dout <= {-10'sd368   , -10'sd356   }; /* W[1546] = -0.7188  -0.6953i */
            12'h706: dout <= {-10'sd369   , -10'sd355   }; /* W[1548] = -0.7207  -0.6934i */
            12'h707: dout <= {-10'sd370   , -10'sd354   }; /* W[1550] = -0.7227  -0.6914i */
            12'h708: dout <= {-10'sd371   , -10'sd353   }; /* W[1552] = -0.7246  -0.6895i */
            12'h709: dout <= {-10'sd372   , -10'sd352   }; /* W[1554] = -0.7266  -0.6875i */
            12'h70A: dout <= {-10'sd373   , -10'sd351   }; /* W[1556] = -0.7285  -0.6855i */
            12'h70B: dout <= {-10'sd374   , -10'sd350   }; /* W[1558] = -0.7305  -0.6836i */
            12'h70C: dout <= {-10'sd375   , -10'sd348   }; /* W[1560] = -0.7324  -0.6797i */
            12'h70D: dout <= {-10'sd376   , -10'sd347   }; /* W[1562] = -0.7344  -0.6777i */
            12'h70E: dout <= {-10'sd377   , -10'sd346   }; /* W[1564] = -0.7363  -0.6758i */
            12'h70F: dout <= {-10'sd378   , -10'sd345   }; /* W[1566] = -0.7383  -0.6738i */
            12'h710: dout <= {-10'sd379   , -10'sd344   }; /* W[1568] = -0.7402  -0.6719i */
            12'h711: dout <= {-10'sd380   , -10'sd343   }; /* W[1570] = -0.7422  -0.6699i */
            12'h712: dout <= {-10'sd381   , -10'sd342   }; /* W[1572] = -0.7441  -0.6680i */
            12'h713: dout <= {-10'sd383   , -10'sd340   }; /* W[1574] = -0.7480  -0.6641i */
            12'h714: dout <= {-10'sd384   , -10'sd339   }; /* W[1576] = -0.7500  -0.6621i */
            12'h715: dout <= {-10'sd385   , -10'sd338   }; /* W[1578] = -0.7520  -0.6602i */
            12'h716: dout <= {-10'sd386   , -10'sd337   }; /* W[1580] = -0.7539  -0.6582i */
            12'h717: dout <= {-10'sd387   , -10'sd336   }; /* W[1582] = -0.7559  -0.6562i */
            12'h718: dout <= {-10'sd388   , -10'sd334   }; /* W[1584] = -0.7578  -0.6523i */
            12'h719: dout <= {-10'sd389   , -10'sd333   }; /* W[1586] = -0.7598  -0.6504i */
            12'h71A: dout <= {-10'sd390   , -10'sd332   }; /* W[1588] = -0.7617  -0.6484i */
            12'h71B: dout <= {-10'sd391   , -10'sd331   }; /* W[1590] = -0.7637  -0.6465i */
            12'h71C: dout <= {-10'sd392   , -10'sd330   }; /* W[1592] = -0.7656  -0.6445i */
            12'h71D: dout <= {-10'sd393   , -10'sd328   }; /* W[1594] = -0.7676  -0.6406i */
            12'h71E: dout <= {-10'sd394   , -10'sd327   }; /* W[1596] = -0.7695  -0.6387i */
            12'h71F: dout <= {-10'sd395   , -10'sd326   }; /* W[1598] = -0.7715  -0.6367i */
            12'h720: dout <= {-10'sd396   , -10'sd325   }; /* W[1600] = -0.7734  -0.6348i */
            12'h721: dout <= {-10'sd397   , -10'sd324   }; /* W[1602] = -0.7754  -0.6328i */
            12'h722: dout <= {-10'sd398   , -10'sd322   }; /* W[1604] = -0.7773  -0.6289i */
            12'h723: dout <= {-10'sd399   , -10'sd321   }; /* W[1606] = -0.7793  -0.6270i */
            12'h724: dout <= {-10'sd400   , -10'sd320   }; /* W[1608] = -0.7812  -0.6250i */
            12'h725: dout <= {-10'sd401   , -10'sd319   }; /* W[1610] = -0.7832  -0.6230i */
            12'h726: dout <= {-10'sd402   , -10'sd317   }; /* W[1612] = -0.7852  -0.6191i */
            12'h727: dout <= {-10'sd403   , -10'sd316   }; /* W[1614] = -0.7871  -0.6172i */
            12'h728: dout <= {-10'sd404   , -10'sd315   }; /* W[1616] = -0.7891  -0.6152i */
            12'h729: dout <= {-10'sd405   , -10'sd314   }; /* W[1618] = -0.7910  -0.6133i */
            12'h72A: dout <= {-10'sd406   , -10'sd313   }; /* W[1620] = -0.7930  -0.6113i */
            12'h72B: dout <= {-10'sd407   , -10'sd311   }; /* W[1622] = -0.7949  -0.6074i */
            12'h72C: dout <= {-10'sd407   , -10'sd310   }; /* W[1624] = -0.7949  -0.6055i */
            12'h72D: dout <= {-10'sd408   , -10'sd309   }; /* W[1626] = -0.7969  -0.6035i */
            12'h72E: dout <= {-10'sd409   , -10'sd308   }; /* W[1628] = -0.7988  -0.6016i */
            12'h72F: dout <= {-10'sd410   , -10'sd306   }; /* W[1630] = -0.8008  -0.5977i */
            12'h730: dout <= {-10'sd411   , -10'sd305   }; /* W[1632] = -0.8027  -0.5957i */
            12'h731: dout <= {-10'sd412   , -10'sd304   }; /* W[1634] = -0.8047  -0.5938i */
            12'h732: dout <= {-10'sd413   , -10'sd302   }; /* W[1636] = -0.8066  -0.5898i */
            12'h733: dout <= {-10'sd414   , -10'sd301   }; /* W[1638] = -0.8086  -0.5879i */
            12'h734: dout <= {-10'sd415   , -10'sd300   }; /* W[1640] = -0.8105  -0.5859i */
            12'h735: dout <= {-10'sd416   , -10'sd299   }; /* W[1642] = -0.8125  -0.5840i */
            12'h736: dout <= {-10'sd417   , -10'sd297   }; /* W[1644] = -0.8145  -0.5801i */
            12'h737: dout <= {-10'sd418   , -10'sd296   }; /* W[1646] = -0.8164  -0.5781i */
            12'h738: dout <= {-10'sd419   , -10'sd295   }; /* W[1648] = -0.8184  -0.5762i */
            12'h739: dout <= {-10'sd420   , -10'sd294   }; /* W[1650] = -0.8203  -0.5742i */
            12'h73A: dout <= {-10'sd420   , -10'sd292   }; /* W[1652] = -0.8203  -0.5703i */
            12'h73B: dout <= {-10'sd421   , -10'sd291   }; /* W[1654] = -0.8223  -0.5684i */
            12'h73C: dout <= {-10'sd422   , -10'sd290   }; /* W[1656] = -0.8242  -0.5664i */
            12'h73D: dout <= {-10'sd423   , -10'sd288   }; /* W[1658] = -0.8262  -0.5625i */
            12'h73E: dout <= {-10'sd424   , -10'sd287   }; /* W[1660] = -0.8281  -0.5605i */
            12'h73F: dout <= {-10'sd425   , -10'sd286   }; /* W[1662] = -0.8301  -0.5586i */
            12'h740: dout <= {-10'sd426   , -10'sd284   }; /* W[1664] = -0.8320  -0.5547i */
            12'h741: dout <= {-10'sd427   , -10'sd283   }; /* W[1666] = -0.8340  -0.5527i */
            12'h742: dout <= {-10'sd427   , -10'sd282   }; /* W[1668] = -0.8340  -0.5508i */
            12'h743: dout <= {-10'sd428   , -10'sd281   }; /* W[1670] = -0.8359  -0.5488i */
            12'h744: dout <= {-10'sd429   , -10'sd279   }; /* W[1672] = -0.8379  -0.5449i */
            12'h745: dout <= {-10'sd430   , -10'sd278   }; /* W[1674] = -0.8398  -0.5430i */
            12'h746: dout <= {-10'sd431   , -10'sd277   }; /* W[1676] = -0.8418  -0.5410i */
            12'h747: dout <= {-10'sd432   , -10'sd275   }; /* W[1678] = -0.8438  -0.5371i */
            12'h748: dout <= {-10'sd433   , -10'sd274   }; /* W[1680] = -0.8457  -0.5352i */
            12'h749: dout <= {-10'sd433   , -10'sd273   }; /* W[1682] = -0.8457  -0.5332i */
            12'h74A: dout <= {-10'sd434   , -10'sd271   }; /* W[1684] = -0.8477  -0.5293i */
            12'h74B: dout <= {-10'sd435   , -10'sd270   }; /* W[1686] = -0.8496  -0.5273i */
            12'h74C: dout <= {-10'sd436   , -10'sd269   }; /* W[1688] = -0.8516  -0.5254i */
            12'h74D: dout <= {-10'sd437   , -10'sd267   }; /* W[1690] = -0.8535  -0.5215i */
            12'h74E: dout <= {-10'sd438   , -10'sd266   }; /* W[1692] = -0.8555  -0.5195i */
            12'h74F: dout <= {-10'sd438   , -10'sd265   }; /* W[1694] = -0.8555  -0.5176i */
            12'h750: dout <= {-10'sd439   , -10'sd263   }; /* W[1696] = -0.8574  -0.5137i */
            12'h751: dout <= {-10'sd440   , -10'sd262   }; /* W[1698] = -0.8594  -0.5117i */
            12'h752: dout <= {-10'sd441   , -10'sd261   }; /* W[1700] = -0.8613  -0.5098i */
            12'h753: dout <= {-10'sd442   , -10'sd259   }; /* W[1702] = -0.8633  -0.5059i */
            12'h754: dout <= {-10'sd442   , -10'sd258   }; /* W[1704] = -0.8633  -0.5039i */
            12'h755: dout <= {-10'sd443   , -10'sd256   }; /* W[1706] = -0.8652  -0.5000i */
            12'h756: dout <= {-10'sd444   , -10'sd255   }; /* W[1708] = -0.8672  -0.4980i */
            12'h757: dout <= {-10'sd445   , -10'sd254   }; /* W[1710] = -0.8691  -0.4961i */
            12'h758: dout <= {-10'sd445   , -10'sd252   }; /* W[1712] = -0.8691  -0.4922i */
            12'h759: dout <= {-10'sd446   , -10'sd251   }; /* W[1714] = -0.8711  -0.4902i */
            12'h75A: dout <= {-10'sd447   , -10'sd250   }; /* W[1716] = -0.8730  -0.4883i */
            12'h75B: dout <= {-10'sd448   , -10'sd248   }; /* W[1718] = -0.8750  -0.4844i */
            12'h75C: dout <= {-10'sd449   , -10'sd247   }; /* W[1720] = -0.8770  -0.4824i */
            12'h75D: dout <= {-10'sd449   , -10'sd246   }; /* W[1722] = -0.8770  -0.4805i */
            12'h75E: dout <= {-10'sd450   , -10'sd244   }; /* W[1724] = -0.8789  -0.4766i */
            12'h75F: dout <= {-10'sd451   , -10'sd243   }; /* W[1726] = -0.8809  -0.4746i */
            12'h760: dout <= {-10'sd452   , -10'sd241   }; /* W[1728] = -0.8828  -0.4707i */
            12'h761: dout <= {-10'sd452   , -10'sd240   }; /* W[1730] = -0.8828  -0.4688i */
            12'h762: dout <= {-10'sd453   , -10'sd239   }; /* W[1732] = -0.8848  -0.4668i */
            12'h763: dout <= {-10'sd454   , -10'sd237   }; /* W[1734] = -0.8867  -0.4629i */
            12'h764: dout <= {-10'sd454   , -10'sd236   }; /* W[1736] = -0.8867  -0.4609i */
            12'h765: dout <= {-10'sd455   , -10'sd234   }; /* W[1738] = -0.8887  -0.4570i */
            12'h766: dout <= {-10'sd456   , -10'sd233   }; /* W[1740] = -0.8906  -0.4551i */
            12'h767: dout <= {-10'sd457   , -10'sd232   }; /* W[1742] = -0.8926  -0.4531i */
            12'h768: dout <= {-10'sd457   , -10'sd230   }; /* W[1744] = -0.8926  -0.4492i */
            12'h769: dout <= {-10'sd458   , -10'sd229   }; /* W[1746] = -0.8945  -0.4473i */
            12'h76A: dout <= {-10'sd459   , -10'sd227   }; /* W[1748] = -0.8965  -0.4434i */
            12'h76B: dout <= {-10'sd459   , -10'sd226   }; /* W[1750] = -0.8965  -0.4414i */
            12'h76C: dout <= {-10'sd460   , -10'sd225   }; /* W[1752] = -0.8984  -0.4395i */
            12'h76D: dout <= {-10'sd461   , -10'sd223   }; /* W[1754] = -0.9004  -0.4355i */
            12'h76E: dout <= {-10'sd461   , -10'sd222   }; /* W[1756] = -0.9004  -0.4336i */
            12'h76F: dout <= {-10'sd462   , -10'sd220   }; /* W[1758] = -0.9023  -0.4297i */
            12'h770: dout <= {-10'sd463   , -10'sd219   }; /* W[1760] = -0.9043  -0.4277i */
            12'h771: dout <= {-10'sd464   , -10'sd217   }; /* W[1762] = -0.9062  -0.4238i */
            12'h772: dout <= {-10'sd464   , -10'sd216   }; /* W[1764] = -0.9062  -0.4219i */
            12'h773: dout <= {-10'sd465   , -10'sd215   }; /* W[1766] = -0.9082  -0.4199i */
            12'h774: dout <= {-10'sd465   , -10'sd213   }; /* W[1768] = -0.9082  -0.4160i */
            12'h775: dout <= {-10'sd466   , -10'sd212   }; /* W[1770] = -0.9102  -0.4141i */
            12'h776: dout <= {-10'sd467   , -10'sd210   }; /* W[1772] = -0.9121  -0.4102i */
            12'h777: dout <= {-10'sd467   , -10'sd209   }; /* W[1774] = -0.9121  -0.4082i */
            12'h778: dout <= {-10'sd468   , -10'sd207   }; /* W[1776] = -0.9141  -0.4043i */
            12'h779: dout <= {-10'sd469   , -10'sd206   }; /* W[1778] = -0.9160  -0.4023i */
            12'h77A: dout <= {-10'sd469   , -10'sd205   }; /* W[1780] = -0.9160  -0.4004i */
            12'h77B: dout <= {-10'sd470   , -10'sd203   }; /* W[1782] = -0.9180  -0.3965i */
            12'h77C: dout <= {-10'sd471   , -10'sd202   }; /* W[1784] = -0.9199  -0.3945i */
            12'h77D: dout <= {-10'sd471   , -10'sd200   }; /* W[1786] = -0.9199  -0.3906i */
            12'h77E: dout <= {-10'sd472   , -10'sd199   }; /* W[1788] = -0.9219  -0.3887i */
            12'h77F: dout <= {-10'sd472   , -10'sd197   }; /* W[1790] = -0.9219  -0.3848i */
            12'h780: dout <= {-10'sd473   , -10'sd196   }; /* W[1792] = -0.9238  -0.3828i */
            12'h781: dout <= {-10'sd474   , -10'sd194   }; /* W[1794] = -0.9258  -0.3789i */
            12'h782: dout <= {-10'sd474   , -10'sd193   }; /* W[1796] = -0.9258  -0.3770i */
            12'h783: dout <= {-10'sd475   , -10'sd192   }; /* W[1798] = -0.9277  -0.3750i */
            12'h784: dout <= {-10'sd475   , -10'sd190   }; /* W[1800] = -0.9277  -0.3711i */
            12'h785: dout <= {-10'sd476   , -10'sd189   }; /* W[1802] = -0.9297  -0.3691i */
            12'h786: dout <= {-10'sd477   , -10'sd187   }; /* W[1804] = -0.9316  -0.3652i */
            12'h787: dout <= {-10'sd477   , -10'sd186   }; /* W[1806] = -0.9316  -0.3633i */
            12'h788: dout <= {-10'sd478   , -10'sd184   }; /* W[1808] = -0.9336  -0.3594i */
            12'h789: dout <= {-10'sd478   , -10'sd183   }; /* W[1810] = -0.9336  -0.3574i */
            12'h78A: dout <= {-10'sd479   , -10'sd181   }; /* W[1812] = -0.9355  -0.3535i */
            12'h78B: dout <= {-10'sd479   , -10'sd180   }; /* W[1814] = -0.9355  -0.3516i */
            12'h78C: dout <= {-10'sd480   , -10'sd178   }; /* W[1816] = -0.9375  -0.3477i */
            12'h78D: dout <= {-10'sd480   , -10'sd177   }; /* W[1818] = -0.9375  -0.3457i */
            12'h78E: dout <= {-10'sd481   , -10'sd175   }; /* W[1820] = -0.9395  -0.3418i */
            12'h78F: dout <= {-10'sd482   , -10'sd174   }; /* W[1822] = -0.9414  -0.3398i */
            12'h790: dout <= {-10'sd482   , -10'sd172   }; /* W[1824] = -0.9414  -0.3359i */
            12'h791: dout <= {-10'sd483   , -10'sd171   }; /* W[1826] = -0.9434  -0.3340i */
            12'h792: dout <= {-10'sd483   , -10'sd170   }; /* W[1828] = -0.9434  -0.3320i */
            12'h793: dout <= {-10'sd484   , -10'sd168   }; /* W[1830] = -0.9453  -0.3281i */
            12'h794: dout <= {-10'sd484   , -10'sd167   }; /* W[1832] = -0.9453  -0.3262i */
            12'h795: dout <= {-10'sd485   , -10'sd165   }; /* W[1834] = -0.9473  -0.3223i */
            12'h796: dout <= {-10'sd485   , -10'sd164   }; /* W[1836] = -0.9473  -0.3203i */
            12'h797: dout <= {-10'sd486   , -10'sd162   }; /* W[1838] = -0.9492  -0.3164i */
            12'h798: dout <= {-10'sd486   , -10'sd161   }; /* W[1840] = -0.9492  -0.3145i */
            12'h799: dout <= {-10'sd487   , -10'sd159   }; /* W[1842] = -0.9512  -0.3105i */
            12'h79A: dout <= {-10'sd487   , -10'sd158   }; /* W[1844] = -0.9512  -0.3086i */
            12'h79B: dout <= {-10'sd488   , -10'sd156   }; /* W[1846] = -0.9531  -0.3047i */
            12'h79C: dout <= {-10'sd488   , -10'sd155   }; /* W[1848] = -0.9531  -0.3027i */
            12'h79D: dout <= {-10'sd489   , -10'sd153   }; /* W[1850] = -0.9551  -0.2988i */
            12'h79E: dout <= {-10'sd489   , -10'sd152   }; /* W[1852] = -0.9551  -0.2969i */
            12'h79F: dout <= {-10'sd489   , -10'sd150   }; /* W[1854] = -0.9551  -0.2930i */
            12'h7A0: dout <= {-10'sd490   , -10'sd149   }; /* W[1856] = -0.9570  -0.2910i */
            12'h7A1: dout <= {-10'sd490   , -10'sd147   }; /* W[1858] = -0.9570  -0.2871i */
            12'h7A2: dout <= {-10'sd491   , -10'sd146   }; /* W[1860] = -0.9590  -0.2852i */
            12'h7A3: dout <= {-10'sd491   , -10'sd144   }; /* W[1862] = -0.9590  -0.2812i */
            12'h7A4: dout <= {-10'sd492   , -10'sd143   }; /* W[1864] = -0.9609  -0.2793i */
            12'h7A5: dout <= {-10'sd492   , -10'sd141   }; /* W[1866] = -0.9609  -0.2754i */
            12'h7A6: dout <= {-10'sd493   , -10'sd140   }; /* W[1868] = -0.9629  -0.2734i */
            12'h7A7: dout <= {-10'sd493   , -10'sd138   }; /* W[1870] = -0.9629  -0.2695i */
            12'h7A8: dout <= {-10'sd493   , -10'sd137   }; /* W[1872] = -0.9629  -0.2676i */
            12'h7A9: dout <= {-10'sd494   , -10'sd135   }; /* W[1874] = -0.9648  -0.2637i */
            12'h7AA: dout <= {-10'sd494   , -10'sd134   }; /* W[1876] = -0.9648  -0.2617i */
            12'h7AB: dout <= {-10'sd495   , -10'sd132   }; /* W[1878] = -0.9668  -0.2578i */
            12'h7AC: dout <= {-10'sd495   , -10'sd130   }; /* W[1880] = -0.9668  -0.2539i */
            12'h7AD: dout <= {-10'sd495   , -10'sd129   }; /* W[1882] = -0.9668  -0.2520i */
            12'h7AE: dout <= {-10'sd496   , -10'sd127   }; /* W[1884] = -0.9688  -0.2480i */
            12'h7AF: dout <= {-10'sd496   , -10'sd126   }; /* W[1886] = -0.9688  -0.2461i */
            12'h7B0: dout <= {-10'sd497   , -10'sd124   }; /* W[1888] = -0.9707  -0.2422i */
            12'h7B1: dout <= {-10'sd497   , -10'sd123   }; /* W[1890] = -0.9707  -0.2402i */
            12'h7B2: dout <= {-10'sd497   , -10'sd121   }; /* W[1892] = -0.9707  -0.2363i */
            12'h7B3: dout <= {-10'sd498   , -10'sd120   }; /* W[1894] = -0.9727  -0.2344i */
            12'h7B4: dout <= {-10'sd498   , -10'sd118   }; /* W[1896] = -0.9727  -0.2305i */
            12'h7B5: dout <= {-10'sd499   , -10'sd117   }; /* W[1898] = -0.9746  -0.2285i */
            12'h7B6: dout <= {-10'sd499   , -10'sd115   }; /* W[1900] = -0.9746  -0.2246i */
            12'h7B7: dout <= {-10'sd499   , -10'sd114   }; /* W[1902] = -0.9746  -0.2227i */
            12'h7B8: dout <= {-10'sd500   , -10'sd112   }; /* W[1904] = -0.9766  -0.2188i */
            12'h7B9: dout <= {-10'sd500   , -10'sd111   }; /* W[1906] = -0.9766  -0.2168i */
            12'h7BA: dout <= {-10'sd500   , -10'sd109   }; /* W[1908] = -0.9766  -0.2129i */
            12'h7BB: dout <= {-10'sd501   , -10'sd108   }; /* W[1910] = -0.9785  -0.2109i */
            12'h7BC: dout <= {-10'sd501   , -10'sd106   }; /* W[1912] = -0.9785  -0.2070i */
            12'h7BD: dout <= {-10'sd501   , -10'sd105   }; /* W[1914] = -0.9785  -0.2051i */
            12'h7BE: dout <= {-10'sd502   , -10'sd103   }; /* W[1916] = -0.9805  -0.2012i */
            12'h7BF: dout <= {-10'sd502   , -10'sd101   }; /* W[1918] = -0.9805  -0.1973i */
            12'h7C0: dout <= {-10'sd502   , -10'sd100   }; /* W[1920] = -0.9805  -0.1953i */
            12'h7C1: dout <= {-10'sd502   , -10'sd98    }; /* W[1922] = -0.9805  -0.1914i */
            12'h7C2: dout <= {-10'sd503   , -10'sd97    }; /* W[1924] = -0.9824  -0.1895i */
            12'h7C3: dout <= {-10'sd503   , -10'sd95    }; /* W[1926] = -0.9824  -0.1855i */
            12'h7C4: dout <= {-10'sd503   , -10'sd94    }; /* W[1928] = -0.9824  -0.1836i */
            12'h7C5: dout <= {-10'sd504   , -10'sd92    }; /* W[1930] = -0.9844  -0.1797i */
            12'h7C6: dout <= {-10'sd504   , -10'sd91    }; /* W[1932] = -0.9844  -0.1777i */
            12'h7C7: dout <= {-10'sd504   , -10'sd89    }; /* W[1934] = -0.9844  -0.1738i */
            12'h7C8: dout <= {-10'sd504   , -10'sd88    }; /* W[1936] = -0.9844  -0.1719i */
            12'h7C9: dout <= {-10'sd505   , -10'sd86    }; /* W[1938] = -0.9863  -0.1680i */
            12'h7CA: dout <= {-10'sd505   , -10'sd84    }; /* W[1940] = -0.9863  -0.1641i */
            12'h7CB: dout <= {-10'sd505   , -10'sd83    }; /* W[1942] = -0.9863  -0.1621i */
            12'h7CC: dout <= {-10'sd505   , -10'sd81    }; /* W[1944] = -0.9863  -0.1582i */
            12'h7CD: dout <= {-10'sd506   , -10'sd80    }; /* W[1946] = -0.9883  -0.1562i */
            12'h7CE: dout <= {-10'sd506   , -10'sd78    }; /* W[1948] = -0.9883  -0.1523i */
            12'h7CF: dout <= {-10'sd506   , -10'sd77    }; /* W[1950] = -0.9883  -0.1504i */
            12'h7D0: dout <= {-10'sd506   , -10'sd75    }; /* W[1952] = -0.9883  -0.1465i */
            12'h7D1: dout <= {-10'sd507   , -10'sd74    }; /* W[1954] = -0.9902  -0.1445i */
            12'h7D2: dout <= {-10'sd507   , -10'sd72    }; /* W[1956] = -0.9902  -0.1406i */
            12'h7D3: dout <= {-10'sd507   , -10'sd70    }; /* W[1958] = -0.9902  -0.1367i */
            12'h7D4: dout <= {-10'sd507   , -10'sd69    }; /* W[1960] = -0.9902  -0.1348i */
            12'h7D5: dout <= {-10'sd508   , -10'sd67    }; /* W[1962] = -0.9922  -0.1309i */
            12'h7D6: dout <= {-10'sd508   , -10'sd66    }; /* W[1964] = -0.9922  -0.1289i */
            12'h7D7: dout <= {-10'sd508   , -10'sd64    }; /* W[1966] = -0.9922  -0.1250i */
            12'h7D8: dout <= {-10'sd508   , -10'sd63    }; /* W[1968] = -0.9922  -0.1230i */
            12'h7D9: dout <= {-10'sd508   , -10'sd61    }; /* W[1970] = -0.9922  -0.1191i */
            12'h7DA: dout <= {-10'sd509   , -10'sd60    }; /* W[1972] = -0.9941  -0.1172i */
            12'h7DB: dout <= {-10'sd509   , -10'sd58    }; /* W[1974] = -0.9941  -0.1133i */
            12'h7DC: dout <= {-10'sd509   , -10'sd56    }; /* W[1976] = -0.9941  -0.1094i */
            12'h7DD: dout <= {-10'sd509   , -10'sd55    }; /* W[1978] = -0.9941  -0.1074i */
            12'h7DE: dout <= {-10'sd509   , -10'sd53    }; /* W[1980] = -0.9941  -0.1035i */
            12'h7DF: dout <= {-10'sd509   , -10'sd52    }; /* W[1982] = -0.9941  -0.1016i */
            12'h7E0: dout <= {-10'sd510   , -10'sd50    }; /* W[1984] = -0.9961  -0.0977i */
            12'h7E1: dout <= {-10'sd510   , -10'sd49    }; /* W[1986] = -0.9961  -0.0957i */
            12'h7E2: dout <= {-10'sd510   , -10'sd47    }; /* W[1988] = -0.9961  -0.0918i */
            12'h7E3: dout <= {-10'sd510   , -10'sd45    }; /* W[1990] = -0.9961  -0.0879i */
            12'h7E4: dout <= {-10'sd510   , -10'sd44    }; /* W[1992] = -0.9961  -0.0859i */
            12'h7E5: dout <= {-10'sd510   , -10'sd42    }; /* W[1994] = -0.9961  -0.0820i */
            12'h7E6: dout <= {-10'sd510   , -10'sd41    }; /* W[1996] = -0.9961  -0.0801i */
            12'h7E7: dout <= {-10'sd510   , -10'sd39    }; /* W[1998] = -0.9961  -0.0762i */
            12'h7E8: dout <= {-10'sd511   , -10'sd38    }; /* W[2000] = -0.9980  -0.0742i */
            12'h7E9: dout <= {-10'sd511   , -10'sd36    }; /* W[2002] = -0.9980  -0.0703i */
            12'h7EA: dout <= {-10'sd511   , -10'sd35    }; /* W[2004] = -0.9980  -0.0684i */
            12'h7EB: dout <= {-10'sd511   , -10'sd33    }; /* W[2006] = -0.9980  -0.0645i */
            12'h7EC: dout <= {-10'sd511   , -10'sd31    }; /* W[2008] = -0.9980  -0.0605i */
            12'h7ED: dout <= {-10'sd511   , -10'sd30    }; /* W[2010] = -0.9980  -0.0586i */
            12'h7EE: dout <= {-10'sd511   , -10'sd28    }; /* W[2012] = -0.9980  -0.0547i */
            12'h7EF: dout <= {-10'sd511   , -10'sd27    }; /* W[2014] = -0.9980  -0.0527i */
            12'h7F0: dout <= {-10'sd511   , -10'sd25    }; /* W[2016] = -0.9980  -0.0488i */
            12'h7F1: dout <= {-10'sd511   , -10'sd24    }; /* W[2018] = -0.9980  -0.0469i */
            12'h7F2: dout <= {-10'sd512   , -10'sd22    }; /* W[2020] = -1.0000  -0.0430i */
            12'h7F3: dout <= {-10'sd512   , -10'sd20    }; /* W[2022] = -1.0000  -0.0391i */
            12'h7F4: dout <= {-10'sd512   , -10'sd19    }; /* W[2024] = -1.0000  -0.0371i */
            12'h7F5: dout <= {-10'sd512   , -10'sd17    }; /* W[2026] = -1.0000  -0.0332i */
            12'h7F6: dout <= {-10'sd512   , -10'sd16    }; /* W[2028] = -1.0000  -0.0312i */
            12'h7F7: dout <= {-10'sd512   , -10'sd14    }; /* W[2030] = -1.0000  -0.0273i */
            12'h7F8: dout <= {-10'sd512   , -10'sd13    }; /* W[2032] = -1.0000  -0.0254i */
            12'h7F9: dout <= {-10'sd512   , -10'sd11    }; /* W[2034] = -1.0000  -0.0215i */
            12'h7FA: dout <= {-10'sd512   , -10'sd9     }; /* W[2036] = -1.0000  -0.0176i */
            12'h7FB: dout <= {-10'sd512   , -10'sd8     }; /* W[2038] = -1.0000  -0.0156i */
            12'h7FC: dout <= {-10'sd512   , -10'sd6     }; /* W[2040] = -1.0000  -0.0117i */
            12'h7FD: dout <= {-10'sd512   , -10'sd5     }; /* W[2042] = -1.0000  -0.0098i */
            12'h7FE: dout <= {-10'sd512   , -10'sd3     }; /* W[2044] = -1.0000  -0.0059i */
            12'h7FF: dout <= {-10'sd512   , -10'sd2     }; /* W[2046] = -1.0000  -0.0039i */
            12'h800: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'h801: dout <= { 10'sd511   , -10'sd1     }; /* W[   1] =  0.9980  -0.0020i */
            12'h802: dout <= { 10'sd511   , -10'sd2     }; /* W[   2] =  0.9980  -0.0039i */
            12'h803: dout <= { 10'sd511   , -10'sd2     }; /* W[   3] =  0.9980  -0.0039i */
            12'h804: dout <= { 10'sd511   , -10'sd3     }; /* W[   4] =  0.9980  -0.0059i */
            12'h805: dout <= { 10'sd511   , -10'sd4     }; /* W[   5] =  0.9980  -0.0078i */
            12'h806: dout <= { 10'sd511   , -10'sd5     }; /* W[   6] =  0.9980  -0.0098i */
            12'h807: dout <= { 10'sd511   , -10'sd5     }; /* W[   7] =  0.9980  -0.0098i */
            12'h808: dout <= { 10'sd511   , -10'sd6     }; /* W[   8] =  0.9980  -0.0117i */
            12'h809: dout <= { 10'sd511   , -10'sd7     }; /* W[   9] =  0.9980  -0.0137i */
            12'h80A: dout <= { 10'sd511   , -10'sd8     }; /* W[  10] =  0.9980  -0.0156i */
            12'h80B: dout <= { 10'sd511   , -10'sd9     }; /* W[  11] =  0.9980  -0.0176i */
            12'h80C: dout <= { 10'sd511   , -10'sd9     }; /* W[  12] =  0.9980  -0.0176i */
            12'h80D: dout <= { 10'sd511   , -10'sd10    }; /* W[  13] =  0.9980  -0.0195i */
            12'h80E: dout <= { 10'sd511   , -10'sd11    }; /* W[  14] =  0.9980  -0.0215i */
            12'h80F: dout <= { 10'sd511   , -10'sd12    }; /* W[  15] =  0.9980  -0.0234i */
            12'h810: dout <= { 10'sd511   , -10'sd13    }; /* W[  16] =  0.9980  -0.0254i */
            12'h811: dout <= { 10'sd511   , -10'sd13    }; /* W[  17] =  0.9980  -0.0254i */
            12'h812: dout <= { 10'sd511   , -10'sd14    }; /* W[  18] =  0.9980  -0.0273i */
            12'h813: dout <= { 10'sd511   , -10'sd15    }; /* W[  19] =  0.9980  -0.0293i */
            12'h814: dout <= { 10'sd511   , -10'sd16    }; /* W[  20] =  0.9980  -0.0312i */
            12'h815: dout <= { 10'sd511   , -10'sd16    }; /* W[  21] =  0.9980  -0.0312i */
            12'h816: dout <= { 10'sd511   , -10'sd17    }; /* W[  22] =  0.9980  -0.0332i */
            12'h817: dout <= { 10'sd511   , -10'sd18    }; /* W[  23] =  0.9980  -0.0352i */
            12'h818: dout <= { 10'sd511   , -10'sd19    }; /* W[  24] =  0.9980  -0.0371i */
            12'h819: dout <= { 10'sd511   , -10'sd20    }; /* W[  25] =  0.9980  -0.0391i */
            12'h81A: dout <= { 10'sd511   , -10'sd20    }; /* W[  26] =  0.9980  -0.0391i */
            12'h81B: dout <= { 10'sd511   , -10'sd21    }; /* W[  27] =  0.9980  -0.0410i */
            12'h81C: dout <= { 10'sd511   , -10'sd22    }; /* W[  28] =  0.9980  -0.0430i */
            12'h81D: dout <= { 10'sd511   , -10'sd23    }; /* W[  29] =  0.9980  -0.0449i */
            12'h81E: dout <= { 10'sd511   , -10'sd24    }; /* W[  30] =  0.9980  -0.0469i */
            12'h81F: dout <= { 10'sd511   , -10'sd24    }; /* W[  31] =  0.9980  -0.0469i */
            12'h820: dout <= { 10'sd511   , -10'sd25    }; /* W[  32] =  0.9980  -0.0488i */
            12'h821: dout <= { 10'sd511   , -10'sd26    }; /* W[  33] =  0.9980  -0.0508i */
            12'h822: dout <= { 10'sd511   , -10'sd27    }; /* W[  34] =  0.9980  -0.0527i */
            12'h823: dout <= { 10'sd511   , -10'sd27    }; /* W[  35] =  0.9980  -0.0527i */
            12'h824: dout <= { 10'sd511   , -10'sd28    }; /* W[  36] =  0.9980  -0.0547i */
            12'h825: dout <= { 10'sd511   , -10'sd29    }; /* W[  37] =  0.9980  -0.0566i */
            12'h826: dout <= { 10'sd511   , -10'sd30    }; /* W[  38] =  0.9980  -0.0586i */
            12'h827: dout <= { 10'sd511   , -10'sd31    }; /* W[  39] =  0.9980  -0.0605i */
            12'h828: dout <= { 10'sd511   , -10'sd31    }; /* W[  40] =  0.9980  -0.0605i */
            12'h829: dout <= { 10'sd511   , -10'sd32    }; /* W[  41] =  0.9980  -0.0625i */
            12'h82A: dout <= { 10'sd511   , -10'sd33    }; /* W[  42] =  0.9980  -0.0645i */
            12'h82B: dout <= { 10'sd511   , -10'sd34    }; /* W[  43] =  0.9980  -0.0664i */
            12'h82C: dout <= { 10'sd511   , -10'sd35    }; /* W[  44] =  0.9980  -0.0684i */
            12'h82D: dout <= { 10'sd511   , -10'sd35    }; /* W[  45] =  0.9980  -0.0684i */
            12'h82E: dout <= { 10'sd511   , -10'sd36    }; /* W[  46] =  0.9980  -0.0703i */
            12'h82F: dout <= { 10'sd511   , -10'sd37    }; /* W[  47] =  0.9980  -0.0723i */
            12'h830: dout <= { 10'sd511   , -10'sd38    }; /* W[  48] =  0.9980  -0.0742i */
            12'h831: dout <= { 10'sd511   , -10'sd38    }; /* W[  49] =  0.9980  -0.0742i */
            12'h832: dout <= { 10'sd510   , -10'sd39    }; /* W[  50] =  0.9961  -0.0762i */
            12'h833: dout <= { 10'sd510   , -10'sd40    }; /* W[  51] =  0.9961  -0.0781i */
            12'h834: dout <= { 10'sd510   , -10'sd41    }; /* W[  52] =  0.9961  -0.0801i */
            12'h835: dout <= { 10'sd510   , -10'sd42    }; /* W[  53] =  0.9961  -0.0820i */
            12'h836: dout <= { 10'sd510   , -10'sd42    }; /* W[  54] =  0.9961  -0.0820i */
            12'h837: dout <= { 10'sd510   , -10'sd43    }; /* W[  55] =  0.9961  -0.0840i */
            12'h838: dout <= { 10'sd510   , -10'sd44    }; /* W[  56] =  0.9961  -0.0859i */
            12'h839: dout <= { 10'sd510   , -10'sd45    }; /* W[  57] =  0.9961  -0.0879i */
            12'h83A: dout <= { 10'sd510   , -10'sd45    }; /* W[  58] =  0.9961  -0.0879i */
            12'h83B: dout <= { 10'sd510   , -10'sd46    }; /* W[  59] =  0.9961  -0.0898i */
            12'h83C: dout <= { 10'sd510   , -10'sd47    }; /* W[  60] =  0.9961  -0.0918i */
            12'h83D: dout <= { 10'sd510   , -10'sd48    }; /* W[  61] =  0.9961  -0.0938i */
            12'h83E: dout <= { 10'sd510   , -10'sd49    }; /* W[  62] =  0.9961  -0.0957i */
            12'h83F: dout <= { 10'sd510   , -10'sd49    }; /* W[  63] =  0.9961  -0.0957i */
            12'h840: dout <= { 10'sd510   , -10'sd50    }; /* W[  64] =  0.9961  -0.0977i */
            12'h841: dout <= { 10'sd509   , -10'sd51    }; /* W[  65] =  0.9941  -0.0996i */
            12'h842: dout <= { 10'sd509   , -10'sd52    }; /* W[  66] =  0.9941  -0.1016i */
            12'h843: dout <= { 10'sd509   , -10'sd53    }; /* W[  67] =  0.9941  -0.1035i */
            12'h844: dout <= { 10'sd509   , -10'sd53    }; /* W[  68] =  0.9941  -0.1035i */
            12'h845: dout <= { 10'sd509   , -10'sd54    }; /* W[  69] =  0.9941  -0.1055i */
            12'h846: dout <= { 10'sd509   , -10'sd55    }; /* W[  70] =  0.9941  -0.1074i */
            12'h847: dout <= { 10'sd509   , -10'sd56    }; /* W[  71] =  0.9941  -0.1094i */
            12'h848: dout <= { 10'sd509   , -10'sd56    }; /* W[  72] =  0.9941  -0.1094i */
            12'h849: dout <= { 10'sd509   , -10'sd57    }; /* W[  73] =  0.9941  -0.1113i */
            12'h84A: dout <= { 10'sd509   , -10'sd58    }; /* W[  74] =  0.9941  -0.1133i */
            12'h84B: dout <= { 10'sd509   , -10'sd59    }; /* W[  75] =  0.9941  -0.1152i */
            12'h84C: dout <= { 10'sd509   , -10'sd60    }; /* W[  76] =  0.9941  -0.1172i */
            12'h84D: dout <= { 10'sd508   , -10'sd60    }; /* W[  77] =  0.9922  -0.1172i */
            12'h84E: dout <= { 10'sd508   , -10'sd61    }; /* W[  78] =  0.9922  -0.1191i */
            12'h84F: dout <= { 10'sd508   , -10'sd62    }; /* W[  79] =  0.9922  -0.1211i */
            12'h850: dout <= { 10'sd508   , -10'sd63    }; /* W[  80] =  0.9922  -0.1230i */
            12'h851: dout <= { 10'sd508   , -10'sd63    }; /* W[  81] =  0.9922  -0.1230i */
            12'h852: dout <= { 10'sd508   , -10'sd64    }; /* W[  82] =  0.9922  -0.1250i */
            12'h853: dout <= { 10'sd508   , -10'sd65    }; /* W[  83] =  0.9922  -0.1270i */
            12'h854: dout <= { 10'sd508   , -10'sd66    }; /* W[  84] =  0.9922  -0.1289i */
            12'h855: dout <= { 10'sd508   , -10'sd67    }; /* W[  85] =  0.9922  -0.1309i */
            12'h856: dout <= { 10'sd508   , -10'sd67    }; /* W[  86] =  0.9922  -0.1309i */
            12'h857: dout <= { 10'sd507   , -10'sd68    }; /* W[  87] =  0.9902  -0.1328i */
            12'h858: dout <= { 10'sd507   , -10'sd69    }; /* W[  88] =  0.9902  -0.1348i */
            12'h859: dout <= { 10'sd507   , -10'sd70    }; /* W[  89] =  0.9902  -0.1367i */
            12'h85A: dout <= { 10'sd507   , -10'sd70    }; /* W[  90] =  0.9902  -0.1367i */
            12'h85B: dout <= { 10'sd507   , -10'sd71    }; /* W[  91] =  0.9902  -0.1387i */
            12'h85C: dout <= { 10'sd507   , -10'sd72    }; /* W[  92] =  0.9902  -0.1406i */
            12'h85D: dout <= { 10'sd507   , -10'sd73    }; /* W[  93] =  0.9902  -0.1426i */
            12'h85E: dout <= { 10'sd507   , -10'sd74    }; /* W[  94] =  0.9902  -0.1445i */
            12'h85F: dout <= { 10'sd507   , -10'sd74    }; /* W[  95] =  0.9902  -0.1445i */
            12'h860: dout <= { 10'sd506   , -10'sd75    }; /* W[  96] =  0.9883  -0.1465i */
            12'h861: dout <= { 10'sd506   , -10'sd76    }; /* W[  97] =  0.9883  -0.1484i */
            12'h862: dout <= { 10'sd506   , -10'sd77    }; /* W[  98] =  0.9883  -0.1504i */
            12'h863: dout <= { 10'sd506   , -10'sd77    }; /* W[  99] =  0.9883  -0.1504i */
            12'h864: dout <= { 10'sd506   , -10'sd78    }; /* W[ 100] =  0.9883  -0.1523i */
            12'h865: dout <= { 10'sd506   , -10'sd79    }; /* W[ 101] =  0.9883  -0.1543i */
            12'h866: dout <= { 10'sd506   , -10'sd80    }; /* W[ 102] =  0.9883  -0.1562i */
            12'h867: dout <= { 10'sd506   , -10'sd81    }; /* W[ 103] =  0.9883  -0.1582i */
            12'h868: dout <= { 10'sd505   , -10'sd81    }; /* W[ 104] =  0.9863  -0.1582i */
            12'h869: dout <= { 10'sd505   , -10'sd82    }; /* W[ 105] =  0.9863  -0.1602i */
            12'h86A: dout <= { 10'sd505   , -10'sd83    }; /* W[ 106] =  0.9863  -0.1621i */
            12'h86B: dout <= { 10'sd505   , -10'sd84    }; /* W[ 107] =  0.9863  -0.1641i */
            12'h86C: dout <= { 10'sd505   , -10'sd84    }; /* W[ 108] =  0.9863  -0.1641i */
            12'h86D: dout <= { 10'sd505   , -10'sd85    }; /* W[ 109] =  0.9863  -0.1660i */
            12'h86E: dout <= { 10'sd505   , -10'sd86    }; /* W[ 110] =  0.9863  -0.1680i */
            12'h86F: dout <= { 10'sd505   , -10'sd87    }; /* W[ 111] =  0.9863  -0.1699i */
            12'h870: dout <= { 10'sd504   , -10'sd88    }; /* W[ 112] =  0.9844  -0.1719i */
            12'h871: dout <= { 10'sd504   , -10'sd88    }; /* W[ 113] =  0.9844  -0.1719i */
            12'h872: dout <= { 10'sd504   , -10'sd89    }; /* W[ 114] =  0.9844  -0.1738i */
            12'h873: dout <= { 10'sd504   , -10'sd90    }; /* W[ 115] =  0.9844  -0.1758i */
            12'h874: dout <= { 10'sd504   , -10'sd91    }; /* W[ 116] =  0.9844  -0.1777i */
            12'h875: dout <= { 10'sd504   , -10'sd91    }; /* W[ 117] =  0.9844  -0.1777i */
            12'h876: dout <= { 10'sd504   , -10'sd92    }; /* W[ 118] =  0.9844  -0.1797i */
            12'h877: dout <= { 10'sd503   , -10'sd93    }; /* W[ 119] =  0.9824  -0.1816i */
            12'h878: dout <= { 10'sd503   , -10'sd94    }; /* W[ 120] =  0.9824  -0.1836i */
            12'h879: dout <= { 10'sd503   , -10'sd94    }; /* W[ 121] =  0.9824  -0.1836i */
            12'h87A: dout <= { 10'sd503   , -10'sd95    }; /* W[ 122] =  0.9824  -0.1855i */
            12'h87B: dout <= { 10'sd503   , -10'sd96    }; /* W[ 123] =  0.9824  -0.1875i */
            12'h87C: dout <= { 10'sd503   , -10'sd97    }; /* W[ 124] =  0.9824  -0.1895i */
            12'h87D: dout <= { 10'sd503   , -10'sd98    }; /* W[ 125] =  0.9824  -0.1914i */
            12'h87E: dout <= { 10'sd502   , -10'sd98    }; /* W[ 126] =  0.9805  -0.1914i */
            12'h87F: dout <= { 10'sd502   , -10'sd99    }; /* W[ 127] =  0.9805  -0.1934i */
            12'h880: dout <= { 10'sd502   , -10'sd100   }; /* W[ 128] =  0.9805  -0.1953i */
            12'h881: dout <= { 10'sd502   , -10'sd101   }; /* W[ 129] =  0.9805  -0.1973i */
            12'h882: dout <= { 10'sd502   , -10'sd101   }; /* W[ 130] =  0.9805  -0.1973i */
            12'h883: dout <= { 10'sd502   , -10'sd102   }; /* W[ 131] =  0.9805  -0.1992i */
            12'h884: dout <= { 10'sd502   , -10'sd103   }; /* W[ 132] =  0.9805  -0.2012i */
            12'h885: dout <= { 10'sd501   , -10'sd104   }; /* W[ 133] =  0.9785  -0.2031i */
            12'h886: dout <= { 10'sd501   , -10'sd105   }; /* W[ 134] =  0.9785  -0.2051i */
            12'h887: dout <= { 10'sd501   , -10'sd105   }; /* W[ 135] =  0.9785  -0.2051i */
            12'h888: dout <= { 10'sd501   , -10'sd106   }; /* W[ 136] =  0.9785  -0.2070i */
            12'h889: dout <= { 10'sd501   , -10'sd107   }; /* W[ 137] =  0.9785  -0.2090i */
            12'h88A: dout <= { 10'sd501   , -10'sd108   }; /* W[ 138] =  0.9785  -0.2109i */
            12'h88B: dout <= { 10'sd500   , -10'sd108   }; /* W[ 139] =  0.9766  -0.2109i */
            12'h88C: dout <= { 10'sd500   , -10'sd109   }; /* W[ 140] =  0.9766  -0.2129i */
            12'h88D: dout <= { 10'sd500   , -10'sd110   }; /* W[ 141] =  0.9766  -0.2148i */
            12'h88E: dout <= { 10'sd500   , -10'sd111   }; /* W[ 142] =  0.9766  -0.2168i */
            12'h88F: dout <= { 10'sd500   , -10'sd111   }; /* W[ 143] =  0.9766  -0.2168i */
            12'h890: dout <= { 10'sd500   , -10'sd112   }; /* W[ 144] =  0.9766  -0.2188i */
            12'h891: dout <= { 10'sd499   , -10'sd113   }; /* W[ 145] =  0.9746  -0.2207i */
            12'h892: dout <= { 10'sd499   , -10'sd114   }; /* W[ 146] =  0.9746  -0.2227i */
            12'h893: dout <= { 10'sd499   , -10'sd114   }; /* W[ 147] =  0.9746  -0.2227i */
            12'h894: dout <= { 10'sd499   , -10'sd115   }; /* W[ 148] =  0.9746  -0.2246i */
            12'h895: dout <= { 10'sd499   , -10'sd116   }; /* W[ 149] =  0.9746  -0.2266i */
            12'h896: dout <= { 10'sd499   , -10'sd117   }; /* W[ 150] =  0.9746  -0.2285i */
            12'h897: dout <= { 10'sd498   , -10'sd118   }; /* W[ 151] =  0.9727  -0.2305i */
            12'h898: dout <= { 10'sd498   , -10'sd118   }; /* W[ 152] =  0.9727  -0.2305i */
            12'h899: dout <= { 10'sd498   , -10'sd119   }; /* W[ 153] =  0.9727  -0.2324i */
            12'h89A: dout <= { 10'sd498   , -10'sd120   }; /* W[ 154] =  0.9727  -0.2344i */
            12'h89B: dout <= { 10'sd498   , -10'sd121   }; /* W[ 155] =  0.9727  -0.2363i */
            12'h89C: dout <= { 10'sd497   , -10'sd121   }; /* W[ 156] =  0.9707  -0.2363i */
            12'h89D: dout <= { 10'sd497   , -10'sd122   }; /* W[ 157] =  0.9707  -0.2383i */
            12'h89E: dout <= { 10'sd497   , -10'sd123   }; /* W[ 158] =  0.9707  -0.2402i */
            12'h89F: dout <= { 10'sd497   , -10'sd124   }; /* W[ 159] =  0.9707  -0.2422i */
            12'h8A0: dout <= { 10'sd497   , -10'sd124   }; /* W[ 160] =  0.9707  -0.2422i */
            12'h8A1: dout <= { 10'sd496   , -10'sd125   }; /* W[ 161] =  0.9688  -0.2441i */
            12'h8A2: dout <= { 10'sd496   , -10'sd126   }; /* W[ 162] =  0.9688  -0.2461i */
            12'h8A3: dout <= { 10'sd496   , -10'sd127   }; /* W[ 163] =  0.9688  -0.2480i */
            12'h8A4: dout <= { 10'sd496   , -10'sd127   }; /* W[ 164] =  0.9688  -0.2480i */
            12'h8A5: dout <= { 10'sd496   , -10'sd128   }; /* W[ 165] =  0.9688  -0.2500i */
            12'h8A6: dout <= { 10'sd495   , -10'sd129   }; /* W[ 166] =  0.9668  -0.2520i */
            12'h8A7: dout <= { 10'sd495   , -10'sd130   }; /* W[ 167] =  0.9668  -0.2539i */
            12'h8A8: dout <= { 10'sd495   , -10'sd130   }; /* W[ 168] =  0.9668  -0.2539i */
            12'h8A9: dout <= { 10'sd495   , -10'sd131   }; /* W[ 169] =  0.9668  -0.2559i */
            12'h8AA: dout <= { 10'sd495   , -10'sd132   }; /* W[ 170] =  0.9668  -0.2578i */
            12'h8AB: dout <= { 10'sd494   , -10'sd133   }; /* W[ 171] =  0.9648  -0.2598i */
            12'h8AC: dout <= { 10'sd494   , -10'sd134   }; /* W[ 172] =  0.9648  -0.2617i */
            12'h8AD: dout <= { 10'sd494   , -10'sd134   }; /* W[ 173] =  0.9648  -0.2617i */
            12'h8AE: dout <= { 10'sd494   , -10'sd135   }; /* W[ 174] =  0.9648  -0.2637i */
            12'h8AF: dout <= { 10'sd494   , -10'sd136   }; /* W[ 175] =  0.9648  -0.2656i */
            12'h8B0: dout <= { 10'sd493   , -10'sd137   }; /* W[ 176] =  0.9629  -0.2676i */
            12'h8B1: dout <= { 10'sd493   , -10'sd137   }; /* W[ 177] =  0.9629  -0.2676i */
            12'h8B2: dout <= { 10'sd493   , -10'sd138   }; /* W[ 178] =  0.9629  -0.2695i */
            12'h8B3: dout <= { 10'sd493   , -10'sd139   }; /* W[ 179] =  0.9629  -0.2715i */
            12'h8B4: dout <= { 10'sd493   , -10'sd140   }; /* W[ 180] =  0.9629  -0.2734i */
            12'h8B5: dout <= { 10'sd492   , -10'sd140   }; /* W[ 181] =  0.9609  -0.2734i */
            12'h8B6: dout <= { 10'sd492   , -10'sd141   }; /* W[ 182] =  0.9609  -0.2754i */
            12'h8B7: dout <= { 10'sd492   , -10'sd142   }; /* W[ 183] =  0.9609  -0.2773i */
            12'h8B8: dout <= { 10'sd492   , -10'sd143   }; /* W[ 184] =  0.9609  -0.2793i */
            12'h8B9: dout <= { 10'sd492   , -10'sd143   }; /* W[ 185] =  0.9609  -0.2793i */
            12'h8BA: dout <= { 10'sd491   , -10'sd144   }; /* W[ 186] =  0.9590  -0.2812i */
            12'h8BB: dout <= { 10'sd491   , -10'sd145   }; /* W[ 187] =  0.9590  -0.2832i */
            12'h8BC: dout <= { 10'sd491   , -10'sd146   }; /* W[ 188] =  0.9590  -0.2852i */
            12'h8BD: dout <= { 10'sd491   , -10'sd146   }; /* W[ 189] =  0.9590  -0.2852i */
            12'h8BE: dout <= { 10'sd490   , -10'sd147   }; /* W[ 190] =  0.9570  -0.2871i */
            12'h8BF: dout <= { 10'sd490   , -10'sd148   }; /* W[ 191] =  0.9570  -0.2891i */
            12'h8C0: dout <= { 10'sd490   , -10'sd149   }; /* W[ 192] =  0.9570  -0.2910i */
            12'h8C1: dout <= { 10'sd490   , -10'sd149   }; /* W[ 193] =  0.9570  -0.2910i */
            12'h8C2: dout <= { 10'sd489   , -10'sd150   }; /* W[ 194] =  0.9551  -0.2930i */
            12'h8C3: dout <= { 10'sd489   , -10'sd151   }; /* W[ 195] =  0.9551  -0.2949i */
            12'h8C4: dout <= { 10'sd489   , -10'sd152   }; /* W[ 196] =  0.9551  -0.2969i */
            12'h8C5: dout <= { 10'sd489   , -10'sd152   }; /* W[ 197] =  0.9551  -0.2969i */
            12'h8C6: dout <= { 10'sd489   , -10'sd153   }; /* W[ 198] =  0.9551  -0.2988i */
            12'h8C7: dout <= { 10'sd488   , -10'sd154   }; /* W[ 199] =  0.9531  -0.3008i */
            12'h8C8: dout <= { 10'sd488   , -10'sd155   }; /* W[ 200] =  0.9531  -0.3027i */
            12'h8C9: dout <= { 10'sd488   , -10'sd155   }; /* W[ 201] =  0.9531  -0.3027i */
            12'h8CA: dout <= { 10'sd488   , -10'sd156   }; /* W[ 202] =  0.9531  -0.3047i */
            12'h8CB: dout <= { 10'sd487   , -10'sd157   }; /* W[ 203] =  0.9512  -0.3066i */
            12'h8CC: dout <= { 10'sd487   , -10'sd158   }; /* W[ 204] =  0.9512  -0.3086i */
            12'h8CD: dout <= { 10'sd487   , -10'sd158   }; /* W[ 205] =  0.9512  -0.3086i */
            12'h8CE: dout <= { 10'sd487   , -10'sd159   }; /* W[ 206] =  0.9512  -0.3105i */
            12'h8CF: dout <= { 10'sd486   , -10'sd160   }; /* W[ 207] =  0.9492  -0.3125i */
            12'h8D0: dout <= { 10'sd486   , -10'sd161   }; /* W[ 208] =  0.9492  -0.3145i */
            12'h8D1: dout <= { 10'sd486   , -10'sd161   }; /* W[ 209] =  0.9492  -0.3145i */
            12'h8D2: dout <= { 10'sd486   , -10'sd162   }; /* W[ 210] =  0.9492  -0.3164i */
            12'h8D3: dout <= { 10'sd485   , -10'sd163   }; /* W[ 211] =  0.9473  -0.3184i */
            12'h8D4: dout <= { 10'sd485   , -10'sd164   }; /* W[ 212] =  0.9473  -0.3203i */
            12'h8D5: dout <= { 10'sd485   , -10'sd164   }; /* W[ 213] =  0.9473  -0.3203i */
            12'h8D6: dout <= { 10'sd485   , -10'sd165   }; /* W[ 214] =  0.9473  -0.3223i */
            12'h8D7: dout <= { 10'sd484   , -10'sd166   }; /* W[ 215] =  0.9453  -0.3242i */
            12'h8D8: dout <= { 10'sd484   , -10'sd167   }; /* W[ 216] =  0.9453  -0.3262i */
            12'h8D9: dout <= { 10'sd484   , -10'sd167   }; /* W[ 217] =  0.9453  -0.3262i */
            12'h8DA: dout <= { 10'sd484   , -10'sd168   }; /* W[ 218] =  0.9453  -0.3281i */
            12'h8DB: dout <= { 10'sd483   , -10'sd169   }; /* W[ 219] =  0.9434  -0.3301i */
            12'h8DC: dout <= { 10'sd483   , -10'sd170   }; /* W[ 220] =  0.9434  -0.3320i */
            12'h8DD: dout <= { 10'sd483   , -10'sd170   }; /* W[ 221] =  0.9434  -0.3320i */
            12'h8DE: dout <= { 10'sd483   , -10'sd171   }; /* W[ 222] =  0.9434  -0.3340i */
            12'h8DF: dout <= { 10'sd482   , -10'sd172   }; /* W[ 223] =  0.9414  -0.3359i */
            12'h8E0: dout <= { 10'sd482   , -10'sd172   }; /* W[ 224] =  0.9414  -0.3359i */
            12'h8E1: dout <= { 10'sd482   , -10'sd173   }; /* W[ 225] =  0.9414  -0.3379i */
            12'h8E2: dout <= { 10'sd482   , -10'sd174   }; /* W[ 226] =  0.9414  -0.3398i */
            12'h8E3: dout <= { 10'sd481   , -10'sd175   }; /* W[ 227] =  0.9395  -0.3418i */
            12'h8E4: dout <= { 10'sd481   , -10'sd175   }; /* W[ 228] =  0.9395  -0.3418i */
            12'h8E5: dout <= { 10'sd481   , -10'sd176   }; /* W[ 229] =  0.9395  -0.3438i */
            12'h8E6: dout <= { 10'sd480   , -10'sd177   }; /* W[ 230] =  0.9375  -0.3457i */
            12'h8E7: dout <= { 10'sd480   , -10'sd178   }; /* W[ 231] =  0.9375  -0.3477i */
            12'h8E8: dout <= { 10'sd480   , -10'sd178   }; /* W[ 232] =  0.9375  -0.3477i */
            12'h8E9: dout <= { 10'sd480   , -10'sd179   }; /* W[ 233] =  0.9375  -0.3496i */
            12'h8EA: dout <= { 10'sd479   , -10'sd180   }; /* W[ 234] =  0.9355  -0.3516i */
            12'h8EB: dout <= { 10'sd479   , -10'sd181   }; /* W[ 235] =  0.9355  -0.3535i */
            12'h8EC: dout <= { 10'sd479   , -10'sd181   }; /* W[ 236] =  0.9355  -0.3535i */
            12'h8ED: dout <= { 10'sd479   , -10'sd182   }; /* W[ 237] =  0.9355  -0.3555i */
            12'h8EE: dout <= { 10'sd478   , -10'sd183   }; /* W[ 238] =  0.9336  -0.3574i */
            12'h8EF: dout <= { 10'sd478   , -10'sd184   }; /* W[ 239] =  0.9336  -0.3594i */
            12'h8F0: dout <= { 10'sd478   , -10'sd184   }; /* W[ 240] =  0.9336  -0.3594i */
            12'h8F1: dout <= { 10'sd477   , -10'sd185   }; /* W[ 241] =  0.9316  -0.3613i */
            12'h8F2: dout <= { 10'sd477   , -10'sd186   }; /* W[ 242] =  0.9316  -0.3633i */
            12'h8F3: dout <= { 10'sd477   , -10'sd186   }; /* W[ 243] =  0.9316  -0.3633i */
            12'h8F4: dout <= { 10'sd477   , -10'sd187   }; /* W[ 244] =  0.9316  -0.3652i */
            12'h8F5: dout <= { 10'sd476   , -10'sd188   }; /* W[ 245] =  0.9297  -0.3672i */
            12'h8F6: dout <= { 10'sd476   , -10'sd189   }; /* W[ 246] =  0.9297  -0.3691i */
            12'h8F7: dout <= { 10'sd476   , -10'sd189   }; /* W[ 247] =  0.9297  -0.3691i */
            12'h8F8: dout <= { 10'sd475   , -10'sd190   }; /* W[ 248] =  0.9277  -0.3711i */
            12'h8F9: dout <= { 10'sd475   , -10'sd191   }; /* W[ 249] =  0.9277  -0.3730i */
            12'h8FA: dout <= { 10'sd475   , -10'sd192   }; /* W[ 250] =  0.9277  -0.3750i */
            12'h8FB: dout <= { 10'sd475   , -10'sd192   }; /* W[ 251] =  0.9277  -0.3750i */
            12'h8FC: dout <= { 10'sd474   , -10'sd193   }; /* W[ 252] =  0.9258  -0.3770i */
            12'h8FD: dout <= { 10'sd474   , -10'sd194   }; /* W[ 253] =  0.9258  -0.3789i */
            12'h8FE: dout <= { 10'sd474   , -10'sd194   }; /* W[ 254] =  0.9258  -0.3789i */
            12'h8FF: dout <= { 10'sd473   , -10'sd195   }; /* W[ 255] =  0.9238  -0.3809i */
            12'h900: dout <= { 10'sd473   , -10'sd196   }; /* W[ 256] =  0.9238  -0.3828i */
            12'h901: dout <= { 10'sd473   , -10'sd197   }; /* W[ 257] =  0.9238  -0.3848i */
            12'h902: dout <= { 10'sd472   , -10'sd197   }; /* W[ 258] =  0.9219  -0.3848i */
            12'h903: dout <= { 10'sd472   , -10'sd198   }; /* W[ 259] =  0.9219  -0.3867i */
            12'h904: dout <= { 10'sd472   , -10'sd199   }; /* W[ 260] =  0.9219  -0.3887i */
            12'h905: dout <= { 10'sd472   , -10'sd200   }; /* W[ 261] =  0.9219  -0.3906i */
            12'h906: dout <= { 10'sd471   , -10'sd200   }; /* W[ 262] =  0.9199  -0.3906i */
            12'h907: dout <= { 10'sd471   , -10'sd201   }; /* W[ 263] =  0.9199  -0.3926i */
            12'h908: dout <= { 10'sd471   , -10'sd202   }; /* W[ 264] =  0.9199  -0.3945i */
            12'h909: dout <= { 10'sd470   , -10'sd202   }; /* W[ 265] =  0.9180  -0.3945i */
            12'h90A: dout <= { 10'sd470   , -10'sd203   }; /* W[ 266] =  0.9180  -0.3965i */
            12'h90B: dout <= { 10'sd470   , -10'sd204   }; /* W[ 267] =  0.9180  -0.3984i */
            12'h90C: dout <= { 10'sd469   , -10'sd205   }; /* W[ 268] =  0.9160  -0.4004i */
            12'h90D: dout <= { 10'sd469   , -10'sd205   }; /* W[ 269] =  0.9160  -0.4004i */
            12'h90E: dout <= { 10'sd469   , -10'sd206   }; /* W[ 270] =  0.9160  -0.4023i */
            12'h90F: dout <= { 10'sd468   , -10'sd207   }; /* W[ 271] =  0.9141  -0.4043i */
            12'h910: dout <= { 10'sd468   , -10'sd207   }; /* W[ 272] =  0.9141  -0.4043i */
            12'h911: dout <= { 10'sd468   , -10'sd208   }; /* W[ 273] =  0.9141  -0.4062i */
            12'h912: dout <= { 10'sd467   , -10'sd209   }; /* W[ 274] =  0.9121  -0.4082i */
            12'h913: dout <= { 10'sd467   , -10'sd210   }; /* W[ 275] =  0.9121  -0.4102i */
            12'h914: dout <= { 10'sd467   , -10'sd210   }; /* W[ 276] =  0.9121  -0.4102i */
            12'h915: dout <= { 10'sd466   , -10'sd211   }; /* W[ 277] =  0.9102  -0.4121i */
            12'h916: dout <= { 10'sd466   , -10'sd212   }; /* W[ 278] =  0.9102  -0.4141i */
            12'h917: dout <= { 10'sd466   , -10'sd212   }; /* W[ 279] =  0.9102  -0.4141i */
            12'h918: dout <= { 10'sd465   , -10'sd213   }; /* W[ 280] =  0.9082  -0.4160i */
            12'h919: dout <= { 10'sd465   , -10'sd214   }; /* W[ 281] =  0.9082  -0.4180i */
            12'h91A: dout <= { 10'sd465   , -10'sd215   }; /* W[ 282] =  0.9082  -0.4199i */
            12'h91B: dout <= { 10'sd465   , -10'sd215   }; /* W[ 283] =  0.9082  -0.4199i */
            12'h91C: dout <= { 10'sd464   , -10'sd216   }; /* W[ 284] =  0.9062  -0.4219i */
            12'h91D: dout <= { 10'sd464   , -10'sd217   }; /* W[ 285] =  0.9062  -0.4238i */
            12'h91E: dout <= { 10'sd464   , -10'sd217   }; /* W[ 286] =  0.9062  -0.4238i */
            12'h91F: dout <= { 10'sd463   , -10'sd218   }; /* W[ 287] =  0.9043  -0.4258i */
            12'h920: dout <= { 10'sd463   , -10'sd219   }; /* W[ 288] =  0.9043  -0.4277i */
            12'h921: dout <= { 10'sd463   , -10'sd220   }; /* W[ 289] =  0.9043  -0.4297i */
            12'h922: dout <= { 10'sd462   , -10'sd220   }; /* W[ 290] =  0.9023  -0.4297i */
            12'h923: dout <= { 10'sd462   , -10'sd221   }; /* W[ 291] =  0.9023  -0.4316i */
            12'h924: dout <= { 10'sd461   , -10'sd222   }; /* W[ 292] =  0.9004  -0.4336i */
            12'h925: dout <= { 10'sd461   , -10'sd222   }; /* W[ 293] =  0.9004  -0.4336i */
            12'h926: dout <= { 10'sd461   , -10'sd223   }; /* W[ 294] =  0.9004  -0.4355i */
            12'h927: dout <= { 10'sd460   , -10'sd224   }; /* W[ 295] =  0.8984  -0.4375i */
            12'h928: dout <= { 10'sd460   , -10'sd225   }; /* W[ 296] =  0.8984  -0.4395i */
            12'h929: dout <= { 10'sd460   , -10'sd225   }; /* W[ 297] =  0.8984  -0.4395i */
            12'h92A: dout <= { 10'sd459   , -10'sd226   }; /* W[ 298] =  0.8965  -0.4414i */
            12'h92B: dout <= { 10'sd459   , -10'sd227   }; /* W[ 299] =  0.8965  -0.4434i */
            12'h92C: dout <= { 10'sd459   , -10'sd227   }; /* W[ 300] =  0.8965  -0.4434i */
            12'h92D: dout <= { 10'sd458   , -10'sd228   }; /* W[ 301] =  0.8945  -0.4453i */
            12'h92E: dout <= { 10'sd458   , -10'sd229   }; /* W[ 302] =  0.8945  -0.4473i */
            12'h92F: dout <= { 10'sd458   , -10'sd229   }; /* W[ 303] =  0.8945  -0.4473i */
            12'h930: dout <= { 10'sd457   , -10'sd230   }; /* W[ 304] =  0.8926  -0.4492i */
            12'h931: dout <= { 10'sd457   , -10'sd231   }; /* W[ 305] =  0.8926  -0.4512i */
            12'h932: dout <= { 10'sd457   , -10'sd232   }; /* W[ 306] =  0.8926  -0.4531i */
            12'h933: dout <= { 10'sd456   , -10'sd232   }; /* W[ 307] =  0.8906  -0.4531i */
            12'h934: dout <= { 10'sd456   , -10'sd233   }; /* W[ 308] =  0.8906  -0.4551i */
            12'h935: dout <= { 10'sd456   , -10'sd234   }; /* W[ 309] =  0.8906  -0.4570i */
            12'h936: dout <= { 10'sd455   , -10'sd234   }; /* W[ 310] =  0.8887  -0.4570i */
            12'h937: dout <= { 10'sd455   , -10'sd235   }; /* W[ 311] =  0.8887  -0.4590i */
            12'h938: dout <= { 10'sd454   , -10'sd236   }; /* W[ 312] =  0.8867  -0.4609i */
            12'h939: dout <= { 10'sd454   , -10'sd236   }; /* W[ 313] =  0.8867  -0.4609i */
            12'h93A: dout <= { 10'sd454   , -10'sd237   }; /* W[ 314] =  0.8867  -0.4629i */
            12'h93B: dout <= { 10'sd453   , -10'sd238   }; /* W[ 315] =  0.8848  -0.4648i */
            12'h93C: dout <= { 10'sd453   , -10'sd239   }; /* W[ 316] =  0.8848  -0.4668i */
            12'h93D: dout <= { 10'sd453   , -10'sd239   }; /* W[ 317] =  0.8848  -0.4668i */
            12'h93E: dout <= { 10'sd452   , -10'sd240   }; /* W[ 318] =  0.8828  -0.4688i */
            12'h93F: dout <= { 10'sd452   , -10'sd241   }; /* W[ 319] =  0.8828  -0.4707i */
            12'h940: dout <= { 10'sd452   , -10'sd241   }; /* W[ 320] =  0.8828  -0.4707i */
            12'h941: dout <= { 10'sd451   , -10'sd242   }; /* W[ 321] =  0.8809  -0.4727i */
            12'h942: dout <= { 10'sd451   , -10'sd243   }; /* W[ 322] =  0.8809  -0.4746i */
            12'h943: dout <= { 10'sd450   , -10'sd243   }; /* W[ 323] =  0.8789  -0.4746i */
            12'h944: dout <= { 10'sd450   , -10'sd244   }; /* W[ 324] =  0.8789  -0.4766i */
            12'h945: dout <= { 10'sd450   , -10'sd245   }; /* W[ 325] =  0.8789  -0.4785i */
            12'h946: dout <= { 10'sd449   , -10'sd246   }; /* W[ 326] =  0.8770  -0.4805i */
            12'h947: dout <= { 10'sd449   , -10'sd246   }; /* W[ 327] =  0.8770  -0.4805i */
            12'h948: dout <= { 10'sd449   , -10'sd247   }; /* W[ 328] =  0.8770  -0.4824i */
            12'h949: dout <= { 10'sd448   , -10'sd248   }; /* W[ 329] =  0.8750  -0.4844i */
            12'h94A: dout <= { 10'sd448   , -10'sd248   }; /* W[ 330] =  0.8750  -0.4844i */
            12'h94B: dout <= { 10'sd447   , -10'sd249   }; /* W[ 331] =  0.8730  -0.4863i */
            12'h94C: dout <= { 10'sd447   , -10'sd250   }; /* W[ 332] =  0.8730  -0.4883i */
            12'h94D: dout <= { 10'sd447   , -10'sd250   }; /* W[ 333] =  0.8730  -0.4883i */
            12'h94E: dout <= { 10'sd446   , -10'sd251   }; /* W[ 334] =  0.8711  -0.4902i */
            12'h94F: dout <= { 10'sd446   , -10'sd252   }; /* W[ 335] =  0.8711  -0.4922i */
            12'h950: dout <= { 10'sd445   , -10'sd252   }; /* W[ 336] =  0.8691  -0.4922i */
            12'h951: dout <= { 10'sd445   , -10'sd253   }; /* W[ 337] =  0.8691  -0.4941i */
            12'h952: dout <= { 10'sd445   , -10'sd254   }; /* W[ 338] =  0.8691  -0.4961i */
            12'h953: dout <= { 10'sd444   , -10'sd254   }; /* W[ 339] =  0.8672  -0.4961i */
            12'h954: dout <= { 10'sd444   , -10'sd255   }; /* W[ 340] =  0.8672  -0.4980i */
            12'h955: dout <= { 10'sd444   , -10'sd256   }; /* W[ 341] =  0.8672  -0.5000i */
            12'h956: dout <= { 10'sd443   , -10'sd256   }; /* W[ 342] =  0.8652  -0.5000i */
            12'h957: dout <= { 10'sd443   , -10'sd257   }; /* W[ 343] =  0.8652  -0.5020i */
            12'h958: dout <= { 10'sd442   , -10'sd258   }; /* W[ 344] =  0.8633  -0.5039i */
            12'h959: dout <= { 10'sd442   , -10'sd258   }; /* W[ 345] =  0.8633  -0.5039i */
            12'h95A: dout <= { 10'sd442   , -10'sd259   }; /* W[ 346] =  0.8633  -0.5059i */
            12'h95B: dout <= { 10'sd441   , -10'sd260   }; /* W[ 347] =  0.8613  -0.5078i */
            12'h95C: dout <= { 10'sd441   , -10'sd261   }; /* W[ 348] =  0.8613  -0.5098i */
            12'h95D: dout <= { 10'sd440   , -10'sd261   }; /* W[ 349] =  0.8594  -0.5098i */
            12'h95E: dout <= { 10'sd440   , -10'sd262   }; /* W[ 350] =  0.8594  -0.5117i */
            12'h95F: dout <= { 10'sd440   , -10'sd263   }; /* W[ 351] =  0.8594  -0.5137i */
            12'h960: dout <= { 10'sd439   , -10'sd263   }; /* W[ 352] =  0.8574  -0.5137i */
            12'h961: dout <= { 10'sd439   , -10'sd264   }; /* W[ 353] =  0.8574  -0.5156i */
            12'h962: dout <= { 10'sd438   , -10'sd265   }; /* W[ 354] =  0.8555  -0.5176i */
            12'h963: dout <= { 10'sd438   , -10'sd265   }; /* W[ 355] =  0.8555  -0.5176i */
            12'h964: dout <= { 10'sd438   , -10'sd266   }; /* W[ 356] =  0.8555  -0.5195i */
            12'h965: dout <= { 10'sd437   , -10'sd267   }; /* W[ 357] =  0.8535  -0.5215i */
            12'h966: dout <= { 10'sd437   , -10'sd267   }; /* W[ 358] =  0.8535  -0.5215i */
            12'h967: dout <= { 10'sd436   , -10'sd268   }; /* W[ 359] =  0.8516  -0.5234i */
            12'h968: dout <= { 10'sd436   , -10'sd269   }; /* W[ 360] =  0.8516  -0.5254i */
            12'h969: dout <= { 10'sd435   , -10'sd269   }; /* W[ 361] =  0.8496  -0.5254i */
            12'h96A: dout <= { 10'sd435   , -10'sd270   }; /* W[ 362] =  0.8496  -0.5273i */
            12'h96B: dout <= { 10'sd435   , -10'sd271   }; /* W[ 363] =  0.8496  -0.5293i */
            12'h96C: dout <= { 10'sd434   , -10'sd271   }; /* W[ 364] =  0.8477  -0.5293i */
            12'h96D: dout <= { 10'sd434   , -10'sd272   }; /* W[ 365] =  0.8477  -0.5312i */
            12'h96E: dout <= { 10'sd433   , -10'sd273   }; /* W[ 366] =  0.8457  -0.5332i */
            12'h96F: dout <= { 10'sd433   , -10'sd273   }; /* W[ 367] =  0.8457  -0.5332i */
            12'h970: dout <= { 10'sd433   , -10'sd274   }; /* W[ 368] =  0.8457  -0.5352i */
            12'h971: dout <= { 10'sd432   , -10'sd275   }; /* W[ 369] =  0.8438  -0.5371i */
            12'h972: dout <= { 10'sd432   , -10'sd275   }; /* W[ 370] =  0.8438  -0.5371i */
            12'h973: dout <= { 10'sd431   , -10'sd276   }; /* W[ 371] =  0.8418  -0.5391i */
            12'h974: dout <= { 10'sd431   , -10'sd277   }; /* W[ 372] =  0.8418  -0.5410i */
            12'h975: dout <= { 10'sd430   , -10'sd277   }; /* W[ 373] =  0.8398  -0.5410i */
            12'h976: dout <= { 10'sd430   , -10'sd278   }; /* W[ 374] =  0.8398  -0.5430i */
            12'h977: dout <= { 10'sd430   , -10'sd279   }; /* W[ 375] =  0.8398  -0.5449i */
            12'h978: dout <= { 10'sd429   , -10'sd279   }; /* W[ 376] =  0.8379  -0.5449i */
            12'h979: dout <= { 10'sd429   , -10'sd280   }; /* W[ 377] =  0.8379  -0.5469i */
            12'h97A: dout <= { 10'sd428   , -10'sd281   }; /* W[ 378] =  0.8359  -0.5488i */
            12'h97B: dout <= { 10'sd428   , -10'sd281   }; /* W[ 379] =  0.8359  -0.5488i */
            12'h97C: dout <= { 10'sd427   , -10'sd282   }; /* W[ 380] =  0.8340  -0.5508i */
            12'h97D: dout <= { 10'sd427   , -10'sd282   }; /* W[ 381] =  0.8340  -0.5508i */
            12'h97E: dout <= { 10'sd427   , -10'sd283   }; /* W[ 382] =  0.8340  -0.5527i */
            12'h97F: dout <= { 10'sd426   , -10'sd284   }; /* W[ 383] =  0.8320  -0.5547i */
            12'h980: dout <= { 10'sd426   , -10'sd284   }; /* W[ 384] =  0.8320  -0.5547i */
            12'h981: dout <= { 10'sd425   , -10'sd285   }; /* W[ 385] =  0.8301  -0.5566i */
            12'h982: dout <= { 10'sd425   , -10'sd286   }; /* W[ 386] =  0.8301  -0.5586i */
            12'h983: dout <= { 10'sd424   , -10'sd286   }; /* W[ 387] =  0.8281  -0.5586i */
            12'h984: dout <= { 10'sd424   , -10'sd287   }; /* W[ 388] =  0.8281  -0.5605i */
            12'h985: dout <= { 10'sd424   , -10'sd288   }; /* W[ 389] =  0.8281  -0.5625i */
            12'h986: dout <= { 10'sd423   , -10'sd288   }; /* W[ 390] =  0.8262  -0.5625i */
            12'h987: dout <= { 10'sd423   , -10'sd289   }; /* W[ 391] =  0.8262  -0.5645i */
            12'h988: dout <= { 10'sd422   , -10'sd290   }; /* W[ 392] =  0.8242  -0.5664i */
            12'h989: dout <= { 10'sd422   , -10'sd290   }; /* W[ 393] =  0.8242  -0.5664i */
            12'h98A: dout <= { 10'sd421   , -10'sd291   }; /* W[ 394] =  0.8223  -0.5684i */
            12'h98B: dout <= { 10'sd421   , -10'sd292   }; /* W[ 395] =  0.8223  -0.5703i */
            12'h98C: dout <= { 10'sd420   , -10'sd292   }; /* W[ 396] =  0.8203  -0.5703i */
            12'h98D: dout <= { 10'sd420   , -10'sd293   }; /* W[ 397] =  0.8203  -0.5723i */
            12'h98E: dout <= { 10'sd420   , -10'sd294   }; /* W[ 398] =  0.8203  -0.5742i */
            12'h98F: dout <= { 10'sd419   , -10'sd294   }; /* W[ 399] =  0.8184  -0.5742i */
            12'h990: dout <= { 10'sd419   , -10'sd295   }; /* W[ 400] =  0.8184  -0.5762i */
            12'h991: dout <= { 10'sd418   , -10'sd295   }; /* W[ 401] =  0.8164  -0.5762i */
            12'h992: dout <= { 10'sd418   , -10'sd296   }; /* W[ 402] =  0.8164  -0.5781i */
            12'h993: dout <= { 10'sd417   , -10'sd297   }; /* W[ 403] =  0.8145  -0.5801i */
            12'h994: dout <= { 10'sd417   , -10'sd297   }; /* W[ 404] =  0.8145  -0.5801i */
            12'h995: dout <= { 10'sd416   , -10'sd298   }; /* W[ 405] =  0.8125  -0.5820i */
            12'h996: dout <= { 10'sd416   , -10'sd299   }; /* W[ 406] =  0.8125  -0.5840i */
            12'h997: dout <= { 10'sd415   , -10'sd299   }; /* W[ 407] =  0.8105  -0.5840i */
            12'h998: dout <= { 10'sd415   , -10'sd300   }; /* W[ 408] =  0.8105  -0.5859i */
            12'h999: dout <= { 10'sd414   , -10'sd301   }; /* W[ 409] =  0.8086  -0.5879i */
            12'h99A: dout <= { 10'sd414   , -10'sd301   }; /* W[ 410] =  0.8086  -0.5879i */
            12'h99B: dout <= { 10'sd414   , -10'sd302   }; /* W[ 411] =  0.8086  -0.5898i */
            12'h99C: dout <= { 10'sd413   , -10'sd302   }; /* W[ 412] =  0.8066  -0.5898i */
            12'h99D: dout <= { 10'sd413   , -10'sd303   }; /* W[ 413] =  0.8066  -0.5918i */
            12'h99E: dout <= { 10'sd412   , -10'sd304   }; /* W[ 414] =  0.8047  -0.5938i */
            12'h99F: dout <= { 10'sd412   , -10'sd304   }; /* W[ 415] =  0.8047  -0.5938i */
            12'h9A0: dout <= { 10'sd411   , -10'sd305   }; /* W[ 416] =  0.8027  -0.5957i */
            12'h9A1: dout <= { 10'sd411   , -10'sd306   }; /* W[ 417] =  0.8027  -0.5977i */
            12'h9A2: dout <= { 10'sd410   , -10'sd306   }; /* W[ 418] =  0.8008  -0.5977i */
            12'h9A3: dout <= { 10'sd410   , -10'sd307   }; /* W[ 419] =  0.8008  -0.5996i */
            12'h9A4: dout <= { 10'sd409   , -10'sd308   }; /* W[ 420] =  0.7988  -0.6016i */
            12'h9A5: dout <= { 10'sd409   , -10'sd308   }; /* W[ 421] =  0.7988  -0.6016i */
            12'h9A6: dout <= { 10'sd408   , -10'sd309   }; /* W[ 422] =  0.7969  -0.6035i */
            12'h9A7: dout <= { 10'sd408   , -10'sd309   }; /* W[ 423] =  0.7969  -0.6035i */
            12'h9A8: dout <= { 10'sd407   , -10'sd310   }; /* W[ 424] =  0.7949  -0.6055i */
            12'h9A9: dout <= { 10'sd407   , -10'sd311   }; /* W[ 425] =  0.7949  -0.6074i */
            12'h9AA: dout <= { 10'sd407   , -10'sd311   }; /* W[ 426] =  0.7949  -0.6074i */
            12'h9AB: dout <= { 10'sd406   , -10'sd312   }; /* W[ 427] =  0.7930  -0.6094i */
            12'h9AC: dout <= { 10'sd406   , -10'sd313   }; /* W[ 428] =  0.7930  -0.6113i */
            12'h9AD: dout <= { 10'sd405   , -10'sd313   }; /* W[ 429] =  0.7910  -0.6113i */
            12'h9AE: dout <= { 10'sd405   , -10'sd314   }; /* W[ 430] =  0.7910  -0.6133i */
            12'h9AF: dout <= { 10'sd404   , -10'sd314   }; /* W[ 431] =  0.7891  -0.6133i */
            12'h9B0: dout <= { 10'sd404   , -10'sd315   }; /* W[ 432] =  0.7891  -0.6152i */
            12'h9B1: dout <= { 10'sd403   , -10'sd316   }; /* W[ 433] =  0.7871  -0.6172i */
            12'h9B2: dout <= { 10'sd403   , -10'sd316   }; /* W[ 434] =  0.7871  -0.6172i */
            12'h9B3: dout <= { 10'sd402   , -10'sd317   }; /* W[ 435] =  0.7852  -0.6191i */
            12'h9B4: dout <= { 10'sd402   , -10'sd317   }; /* W[ 436] =  0.7852  -0.6191i */
            12'h9B5: dout <= { 10'sd401   , -10'sd318   }; /* W[ 437] =  0.7832  -0.6211i */
            12'h9B6: dout <= { 10'sd401   , -10'sd319   }; /* W[ 438] =  0.7832  -0.6230i */
            12'h9B7: dout <= { 10'sd400   , -10'sd319   }; /* W[ 439] =  0.7812  -0.6230i */
            12'h9B8: dout <= { 10'sd400   , -10'sd320   }; /* W[ 440] =  0.7812  -0.6250i */
            12'h9B9: dout <= { 10'sd399   , -10'sd321   }; /* W[ 441] =  0.7793  -0.6270i */
            12'h9BA: dout <= { 10'sd399   , -10'sd321   }; /* W[ 442] =  0.7793  -0.6270i */
            12'h9BB: dout <= { 10'sd398   , -10'sd322   }; /* W[ 443] =  0.7773  -0.6289i */
            12'h9BC: dout <= { 10'sd398   , -10'sd322   }; /* W[ 444] =  0.7773  -0.6289i */
            12'h9BD: dout <= { 10'sd397   , -10'sd323   }; /* W[ 445] =  0.7754  -0.6309i */
            12'h9BE: dout <= { 10'sd397   , -10'sd324   }; /* W[ 446] =  0.7754  -0.6328i */
            12'h9BF: dout <= { 10'sd396   , -10'sd324   }; /* W[ 447] =  0.7734  -0.6328i */
            12'h9C0: dout <= { 10'sd396   , -10'sd325   }; /* W[ 448] =  0.7734  -0.6348i */
            12'h9C1: dout <= { 10'sd395   , -10'sd325   }; /* W[ 449] =  0.7715  -0.6348i */
            12'h9C2: dout <= { 10'sd395   , -10'sd326   }; /* W[ 450] =  0.7715  -0.6367i */
            12'h9C3: dout <= { 10'sd394   , -10'sd327   }; /* W[ 451] =  0.7695  -0.6387i */
            12'h9C4: dout <= { 10'sd394   , -10'sd327   }; /* W[ 452] =  0.7695  -0.6387i */
            12'h9C5: dout <= { 10'sd393   , -10'sd328   }; /* W[ 453] =  0.7676  -0.6406i */
            12'h9C6: dout <= { 10'sd393   , -10'sd328   }; /* W[ 454] =  0.7676  -0.6406i */
            12'h9C7: dout <= { 10'sd392   , -10'sd329   }; /* W[ 455] =  0.7656  -0.6426i */
            12'h9C8: dout <= { 10'sd392   , -10'sd330   }; /* W[ 456] =  0.7656  -0.6445i */
            12'h9C9: dout <= { 10'sd391   , -10'sd330   }; /* W[ 457] =  0.7637  -0.6445i */
            12'h9CA: dout <= { 10'sd391   , -10'sd331   }; /* W[ 458] =  0.7637  -0.6465i */
            12'h9CB: dout <= { 10'sd390   , -10'sd331   }; /* W[ 459] =  0.7617  -0.6465i */
            12'h9CC: dout <= { 10'sd390   , -10'sd332   }; /* W[ 460] =  0.7617  -0.6484i */
            12'h9CD: dout <= { 10'sd389   , -10'sd333   }; /* W[ 461] =  0.7598  -0.6504i */
            12'h9CE: dout <= { 10'sd389   , -10'sd333   }; /* W[ 462] =  0.7598  -0.6504i */
            12'h9CF: dout <= { 10'sd388   , -10'sd334   }; /* W[ 463] =  0.7578  -0.6523i */
            12'h9D0: dout <= { 10'sd388   , -10'sd334   }; /* W[ 464] =  0.7578  -0.6523i */
            12'h9D1: dout <= { 10'sd387   , -10'sd335   }; /* W[ 465] =  0.7559  -0.6543i */
            12'h9D2: dout <= { 10'sd387   , -10'sd336   }; /* W[ 466] =  0.7559  -0.6562i */
            12'h9D3: dout <= { 10'sd386   , -10'sd336   }; /* W[ 467] =  0.7539  -0.6562i */
            12'h9D4: dout <= { 10'sd386   , -10'sd337   }; /* W[ 468] =  0.7539  -0.6582i */
            12'h9D5: dout <= { 10'sd385   , -10'sd337   }; /* W[ 469] =  0.7520  -0.6582i */
            12'h9D6: dout <= { 10'sd385   , -10'sd338   }; /* W[ 470] =  0.7520  -0.6602i */
            12'h9D7: dout <= { 10'sd384   , -10'sd339   }; /* W[ 471] =  0.7500  -0.6621i */
            12'h9D8: dout <= { 10'sd384   , -10'sd339   }; /* W[ 472] =  0.7500  -0.6621i */
            12'h9D9: dout <= { 10'sd383   , -10'sd340   }; /* W[ 473] =  0.7480  -0.6641i */
            12'h9DA: dout <= { 10'sd383   , -10'sd340   }; /* W[ 474] =  0.7480  -0.6641i */
            12'h9DB: dout <= { 10'sd382   , -10'sd341   }; /* W[ 475] =  0.7461  -0.6660i */
            12'h9DC: dout <= { 10'sd381   , -10'sd342   }; /* W[ 476] =  0.7441  -0.6680i */
            12'h9DD: dout <= { 10'sd381   , -10'sd342   }; /* W[ 477] =  0.7441  -0.6680i */
            12'h9DE: dout <= { 10'sd380   , -10'sd343   }; /* W[ 478] =  0.7422  -0.6699i */
            12'h9DF: dout <= { 10'sd380   , -10'sd343   }; /* W[ 479] =  0.7422  -0.6699i */
            12'h9E0: dout <= { 10'sd379   , -10'sd344   }; /* W[ 480] =  0.7402  -0.6719i */
            12'h9E1: dout <= { 10'sd379   , -10'sd344   }; /* W[ 481] =  0.7402  -0.6719i */
            12'h9E2: dout <= { 10'sd378   , -10'sd345   }; /* W[ 482] =  0.7383  -0.6738i */
            12'h9E3: dout <= { 10'sd378   , -10'sd346   }; /* W[ 483] =  0.7383  -0.6758i */
            12'h9E4: dout <= { 10'sd377   , -10'sd346   }; /* W[ 484] =  0.7363  -0.6758i */
            12'h9E5: dout <= { 10'sd377   , -10'sd347   }; /* W[ 485] =  0.7363  -0.6777i */
            12'h9E6: dout <= { 10'sd376   , -10'sd347   }; /* W[ 486] =  0.7344  -0.6777i */
            12'h9E7: dout <= { 10'sd376   , -10'sd348   }; /* W[ 487] =  0.7344  -0.6797i */
            12'h9E8: dout <= { 10'sd375   , -10'sd348   }; /* W[ 488] =  0.7324  -0.6797i */
            12'h9E9: dout <= { 10'sd375   , -10'sd349   }; /* W[ 489] =  0.7324  -0.6816i */
            12'h9EA: dout <= { 10'sd374   , -10'sd350   }; /* W[ 490] =  0.7305  -0.6836i */
            12'h9EB: dout <= { 10'sd374   , -10'sd350   }; /* W[ 491] =  0.7305  -0.6836i */
            12'h9EC: dout <= { 10'sd373   , -10'sd351   }; /* W[ 492] =  0.7285  -0.6855i */
            12'h9ED: dout <= { 10'sd372   , -10'sd351   }; /* W[ 493] =  0.7266  -0.6855i */
            12'h9EE: dout <= { 10'sd372   , -10'sd352   }; /* W[ 494] =  0.7266  -0.6875i */
            12'h9EF: dout <= { 10'sd371   , -10'sd352   }; /* W[ 495] =  0.7246  -0.6875i */
            12'h9F0: dout <= { 10'sd371   , -10'sd353   }; /* W[ 496] =  0.7246  -0.6895i */
            12'h9F1: dout <= { 10'sd370   , -10'sd354   }; /* W[ 497] =  0.7227  -0.6914i */
            12'h9F2: dout <= { 10'sd370   , -10'sd354   }; /* W[ 498] =  0.7227  -0.6914i */
            12'h9F3: dout <= { 10'sd369   , -10'sd355   }; /* W[ 499] =  0.7207  -0.6934i */
            12'h9F4: dout <= { 10'sd369   , -10'sd355   }; /* W[ 500] =  0.7207  -0.6934i */
            12'h9F5: dout <= { 10'sd368   , -10'sd356   }; /* W[ 501] =  0.7188  -0.6953i */
            12'h9F6: dout <= { 10'sd368   , -10'sd356   }; /* W[ 502] =  0.7188  -0.6953i */
            12'h9F7: dout <= { 10'sd367   , -10'sd357   }; /* W[ 503] =  0.7168  -0.6973i */
            12'h9F8: dout <= { 10'sd366   , -10'sd358   }; /* W[ 504] =  0.7148  -0.6992i */
            12'h9F9: dout <= { 10'sd366   , -10'sd358   }; /* W[ 505] =  0.7148  -0.6992i */
            12'h9FA: dout <= { 10'sd365   , -10'sd359   }; /* W[ 506] =  0.7129  -0.7012i */
            12'h9FB: dout <= { 10'sd365   , -10'sd359   }; /* W[ 507] =  0.7129  -0.7012i */
            12'h9FC: dout <= { 10'sd364   , -10'sd360   }; /* W[ 508] =  0.7109  -0.7031i */
            12'h9FD: dout <= { 10'sd364   , -10'sd360   }; /* W[ 509] =  0.7109  -0.7031i */
            12'h9FE: dout <= { 10'sd363   , -10'sd361   }; /* W[ 510] =  0.7090  -0.7051i */
            12'h9FF: dout <= { 10'sd363   , -10'sd361   }; /* W[ 511] =  0.7090  -0.7051i */
            12'hA00: dout <= { 10'sd362   , -10'sd362   }; /* W[ 512] =  0.7070  -0.7070i */
            12'hA01: dout <= { 10'sd361   , -10'sd363   }; /* W[ 513] =  0.7051  -0.7090i */
            12'hA02: dout <= { 10'sd361   , -10'sd363   }; /* W[ 514] =  0.7051  -0.7090i */
            12'hA03: dout <= { 10'sd360   , -10'sd364   }; /* W[ 515] =  0.7031  -0.7109i */
            12'hA04: dout <= { 10'sd360   , -10'sd364   }; /* W[ 516] =  0.7031  -0.7109i */
            12'hA05: dout <= { 10'sd359   , -10'sd365   }; /* W[ 517] =  0.7012  -0.7129i */
            12'hA06: dout <= { 10'sd359   , -10'sd365   }; /* W[ 518] =  0.7012  -0.7129i */
            12'hA07: dout <= { 10'sd358   , -10'sd366   }; /* W[ 519] =  0.6992  -0.7148i */
            12'hA08: dout <= { 10'sd358   , -10'sd366   }; /* W[ 520] =  0.6992  -0.7148i */
            12'hA09: dout <= { 10'sd357   , -10'sd367   }; /* W[ 521] =  0.6973  -0.7168i */
            12'hA0A: dout <= { 10'sd356   , -10'sd368   }; /* W[ 522] =  0.6953  -0.7188i */
            12'hA0B: dout <= { 10'sd356   , -10'sd368   }; /* W[ 523] =  0.6953  -0.7188i */
            12'hA0C: dout <= { 10'sd355   , -10'sd369   }; /* W[ 524] =  0.6934  -0.7207i */
            12'hA0D: dout <= { 10'sd355   , -10'sd369   }; /* W[ 525] =  0.6934  -0.7207i */
            12'hA0E: dout <= { 10'sd354   , -10'sd370   }; /* W[ 526] =  0.6914  -0.7227i */
            12'hA0F: dout <= { 10'sd354   , -10'sd370   }; /* W[ 527] =  0.6914  -0.7227i */
            12'hA10: dout <= { 10'sd353   , -10'sd371   }; /* W[ 528] =  0.6895  -0.7246i */
            12'hA11: dout <= { 10'sd352   , -10'sd371   }; /* W[ 529] =  0.6875  -0.7246i */
            12'hA12: dout <= { 10'sd352   , -10'sd372   }; /* W[ 530] =  0.6875  -0.7266i */
            12'hA13: dout <= { 10'sd351   , -10'sd372   }; /* W[ 531] =  0.6855  -0.7266i */
            12'hA14: dout <= { 10'sd351   , -10'sd373   }; /* W[ 532] =  0.6855  -0.7285i */
            12'hA15: dout <= { 10'sd350   , -10'sd374   }; /* W[ 533] =  0.6836  -0.7305i */
            12'hA16: dout <= { 10'sd350   , -10'sd374   }; /* W[ 534] =  0.6836  -0.7305i */
            12'hA17: dout <= { 10'sd349   , -10'sd375   }; /* W[ 535] =  0.6816  -0.7324i */
            12'hA18: dout <= { 10'sd348   , -10'sd375   }; /* W[ 536] =  0.6797  -0.7324i */
            12'hA19: dout <= { 10'sd348   , -10'sd376   }; /* W[ 537] =  0.6797  -0.7344i */
            12'hA1A: dout <= { 10'sd347   , -10'sd376   }; /* W[ 538] =  0.6777  -0.7344i */
            12'hA1B: dout <= { 10'sd347   , -10'sd377   }; /* W[ 539] =  0.6777  -0.7363i */
            12'hA1C: dout <= { 10'sd346   , -10'sd377   }; /* W[ 540] =  0.6758  -0.7363i */
            12'hA1D: dout <= { 10'sd346   , -10'sd378   }; /* W[ 541] =  0.6758  -0.7383i */
            12'hA1E: dout <= { 10'sd345   , -10'sd378   }; /* W[ 542] =  0.6738  -0.7383i */
            12'hA1F: dout <= { 10'sd344   , -10'sd379   }; /* W[ 543] =  0.6719  -0.7402i */
            12'hA20: dout <= { 10'sd344   , -10'sd379   }; /* W[ 544] =  0.6719  -0.7402i */
            12'hA21: dout <= { 10'sd343   , -10'sd380   }; /* W[ 545] =  0.6699  -0.7422i */
            12'hA22: dout <= { 10'sd343   , -10'sd380   }; /* W[ 546] =  0.6699  -0.7422i */
            12'hA23: dout <= { 10'sd342   , -10'sd381   }; /* W[ 547] =  0.6680  -0.7441i */
            12'hA24: dout <= { 10'sd342   , -10'sd381   }; /* W[ 548] =  0.6680  -0.7441i */
            12'hA25: dout <= { 10'sd341   , -10'sd382   }; /* W[ 549] =  0.6660  -0.7461i */
            12'hA26: dout <= { 10'sd340   , -10'sd383   }; /* W[ 550] =  0.6641  -0.7480i */
            12'hA27: dout <= { 10'sd340   , -10'sd383   }; /* W[ 551] =  0.6641  -0.7480i */
            12'hA28: dout <= { 10'sd339   , -10'sd384   }; /* W[ 552] =  0.6621  -0.7500i */
            12'hA29: dout <= { 10'sd339   , -10'sd384   }; /* W[ 553] =  0.6621  -0.7500i */
            12'hA2A: dout <= { 10'sd338   , -10'sd385   }; /* W[ 554] =  0.6602  -0.7520i */
            12'hA2B: dout <= { 10'sd337   , -10'sd385   }; /* W[ 555] =  0.6582  -0.7520i */
            12'hA2C: dout <= { 10'sd337   , -10'sd386   }; /* W[ 556] =  0.6582  -0.7539i */
            12'hA2D: dout <= { 10'sd336   , -10'sd386   }; /* W[ 557] =  0.6562  -0.7539i */
            12'hA2E: dout <= { 10'sd336   , -10'sd387   }; /* W[ 558] =  0.6562  -0.7559i */
            12'hA2F: dout <= { 10'sd335   , -10'sd387   }; /* W[ 559] =  0.6543  -0.7559i */
            12'hA30: dout <= { 10'sd334   , -10'sd388   }; /* W[ 560] =  0.6523  -0.7578i */
            12'hA31: dout <= { 10'sd334   , -10'sd388   }; /* W[ 561] =  0.6523  -0.7578i */
            12'hA32: dout <= { 10'sd333   , -10'sd389   }; /* W[ 562] =  0.6504  -0.7598i */
            12'hA33: dout <= { 10'sd333   , -10'sd389   }; /* W[ 563] =  0.6504  -0.7598i */
            12'hA34: dout <= { 10'sd332   , -10'sd390   }; /* W[ 564] =  0.6484  -0.7617i */
            12'hA35: dout <= { 10'sd331   , -10'sd390   }; /* W[ 565] =  0.6465  -0.7617i */
            12'hA36: dout <= { 10'sd331   , -10'sd391   }; /* W[ 566] =  0.6465  -0.7637i */
            12'hA37: dout <= { 10'sd330   , -10'sd391   }; /* W[ 567] =  0.6445  -0.7637i */
            12'hA38: dout <= { 10'sd330   , -10'sd392   }; /* W[ 568] =  0.6445  -0.7656i */
            12'hA39: dout <= { 10'sd329   , -10'sd392   }; /* W[ 569] =  0.6426  -0.7656i */
            12'hA3A: dout <= { 10'sd328   , -10'sd393   }; /* W[ 570] =  0.6406  -0.7676i */
            12'hA3B: dout <= { 10'sd328   , -10'sd393   }; /* W[ 571] =  0.6406  -0.7676i */
            12'hA3C: dout <= { 10'sd327   , -10'sd394   }; /* W[ 572] =  0.6387  -0.7695i */
            12'hA3D: dout <= { 10'sd327   , -10'sd394   }; /* W[ 573] =  0.6387  -0.7695i */
            12'hA3E: dout <= { 10'sd326   , -10'sd395   }; /* W[ 574] =  0.6367  -0.7715i */
            12'hA3F: dout <= { 10'sd325   , -10'sd395   }; /* W[ 575] =  0.6348  -0.7715i */
            12'hA40: dout <= { 10'sd325   , -10'sd396   }; /* W[ 576] =  0.6348  -0.7734i */
            12'hA41: dout <= { 10'sd324   , -10'sd396   }; /* W[ 577] =  0.6328  -0.7734i */
            12'hA42: dout <= { 10'sd324   , -10'sd397   }; /* W[ 578] =  0.6328  -0.7754i */
            12'hA43: dout <= { 10'sd323   , -10'sd397   }; /* W[ 579] =  0.6309  -0.7754i */
            12'hA44: dout <= { 10'sd322   , -10'sd398   }; /* W[ 580] =  0.6289  -0.7773i */
            12'hA45: dout <= { 10'sd322   , -10'sd398   }; /* W[ 581] =  0.6289  -0.7773i */
            12'hA46: dout <= { 10'sd321   , -10'sd399   }; /* W[ 582] =  0.6270  -0.7793i */
            12'hA47: dout <= { 10'sd321   , -10'sd399   }; /* W[ 583] =  0.6270  -0.7793i */
            12'hA48: dout <= { 10'sd320   , -10'sd400   }; /* W[ 584] =  0.6250  -0.7812i */
            12'hA49: dout <= { 10'sd319   , -10'sd400   }; /* W[ 585] =  0.6230  -0.7812i */
            12'hA4A: dout <= { 10'sd319   , -10'sd401   }; /* W[ 586] =  0.6230  -0.7832i */
            12'hA4B: dout <= { 10'sd318   , -10'sd401   }; /* W[ 587] =  0.6211  -0.7832i */
            12'hA4C: dout <= { 10'sd317   , -10'sd402   }; /* W[ 588] =  0.6191  -0.7852i */
            12'hA4D: dout <= { 10'sd317   , -10'sd402   }; /* W[ 589] =  0.6191  -0.7852i */
            12'hA4E: dout <= { 10'sd316   , -10'sd403   }; /* W[ 590] =  0.6172  -0.7871i */
            12'hA4F: dout <= { 10'sd316   , -10'sd403   }; /* W[ 591] =  0.6172  -0.7871i */
            12'hA50: dout <= { 10'sd315   , -10'sd404   }; /* W[ 592] =  0.6152  -0.7891i */
            12'hA51: dout <= { 10'sd314   , -10'sd404   }; /* W[ 593] =  0.6133  -0.7891i */
            12'hA52: dout <= { 10'sd314   , -10'sd405   }; /* W[ 594] =  0.6133  -0.7910i */
            12'hA53: dout <= { 10'sd313   , -10'sd405   }; /* W[ 595] =  0.6113  -0.7910i */
            12'hA54: dout <= { 10'sd313   , -10'sd406   }; /* W[ 596] =  0.6113  -0.7930i */
            12'hA55: dout <= { 10'sd312   , -10'sd406   }; /* W[ 597] =  0.6094  -0.7930i */
            12'hA56: dout <= { 10'sd311   , -10'sd407   }; /* W[ 598] =  0.6074  -0.7949i */
            12'hA57: dout <= { 10'sd311   , -10'sd407   }; /* W[ 599] =  0.6074  -0.7949i */
            12'hA58: dout <= { 10'sd310   , -10'sd407   }; /* W[ 600] =  0.6055  -0.7949i */
            12'hA59: dout <= { 10'sd309   , -10'sd408   }; /* W[ 601] =  0.6035  -0.7969i */
            12'hA5A: dout <= { 10'sd309   , -10'sd408   }; /* W[ 602] =  0.6035  -0.7969i */
            12'hA5B: dout <= { 10'sd308   , -10'sd409   }; /* W[ 603] =  0.6016  -0.7988i */
            12'hA5C: dout <= { 10'sd308   , -10'sd409   }; /* W[ 604] =  0.6016  -0.7988i */
            12'hA5D: dout <= { 10'sd307   , -10'sd410   }; /* W[ 605] =  0.5996  -0.8008i */
            12'hA5E: dout <= { 10'sd306   , -10'sd410   }; /* W[ 606] =  0.5977  -0.8008i */
            12'hA5F: dout <= { 10'sd306   , -10'sd411   }; /* W[ 607] =  0.5977  -0.8027i */
            12'hA60: dout <= { 10'sd305   , -10'sd411   }; /* W[ 608] =  0.5957  -0.8027i */
            12'hA61: dout <= { 10'sd304   , -10'sd412   }; /* W[ 609] =  0.5938  -0.8047i */
            12'hA62: dout <= { 10'sd304   , -10'sd412   }; /* W[ 610] =  0.5938  -0.8047i */
            12'hA63: dout <= { 10'sd303   , -10'sd413   }; /* W[ 611] =  0.5918  -0.8066i */
            12'hA64: dout <= { 10'sd302   , -10'sd413   }; /* W[ 612] =  0.5898  -0.8066i */
            12'hA65: dout <= { 10'sd302   , -10'sd414   }; /* W[ 613] =  0.5898  -0.8086i */
            12'hA66: dout <= { 10'sd301   , -10'sd414   }; /* W[ 614] =  0.5879  -0.8086i */
            12'hA67: dout <= { 10'sd301   , -10'sd414   }; /* W[ 615] =  0.5879  -0.8086i */
            12'hA68: dout <= { 10'sd300   , -10'sd415   }; /* W[ 616] =  0.5859  -0.8105i */
            12'hA69: dout <= { 10'sd299   , -10'sd415   }; /* W[ 617] =  0.5840  -0.8105i */
            12'hA6A: dout <= { 10'sd299   , -10'sd416   }; /* W[ 618] =  0.5840  -0.8125i */
            12'hA6B: dout <= { 10'sd298   , -10'sd416   }; /* W[ 619] =  0.5820  -0.8125i */
            12'hA6C: dout <= { 10'sd297   , -10'sd417   }; /* W[ 620] =  0.5801  -0.8145i */
            12'hA6D: dout <= { 10'sd297   , -10'sd417   }; /* W[ 621] =  0.5801  -0.8145i */
            12'hA6E: dout <= { 10'sd296   , -10'sd418   }; /* W[ 622] =  0.5781  -0.8164i */
            12'hA6F: dout <= { 10'sd295   , -10'sd418   }; /* W[ 623] =  0.5762  -0.8164i */
            12'hA70: dout <= { 10'sd295   , -10'sd419   }; /* W[ 624] =  0.5762  -0.8184i */
            12'hA71: dout <= { 10'sd294   , -10'sd419   }; /* W[ 625] =  0.5742  -0.8184i */
            12'hA72: dout <= { 10'sd294   , -10'sd420   }; /* W[ 626] =  0.5742  -0.8203i */
            12'hA73: dout <= { 10'sd293   , -10'sd420   }; /* W[ 627] =  0.5723  -0.8203i */
            12'hA74: dout <= { 10'sd292   , -10'sd420   }; /* W[ 628] =  0.5703  -0.8203i */
            12'hA75: dout <= { 10'sd292   , -10'sd421   }; /* W[ 629] =  0.5703  -0.8223i */
            12'hA76: dout <= { 10'sd291   , -10'sd421   }; /* W[ 630] =  0.5684  -0.8223i */
            12'hA77: dout <= { 10'sd290   , -10'sd422   }; /* W[ 631] =  0.5664  -0.8242i */
            12'hA78: dout <= { 10'sd290   , -10'sd422   }; /* W[ 632] =  0.5664  -0.8242i */
            12'hA79: dout <= { 10'sd289   , -10'sd423   }; /* W[ 633] =  0.5645  -0.8262i */
            12'hA7A: dout <= { 10'sd288   , -10'sd423   }; /* W[ 634] =  0.5625  -0.8262i */
            12'hA7B: dout <= { 10'sd288   , -10'sd424   }; /* W[ 635] =  0.5625  -0.8281i */
            12'hA7C: dout <= { 10'sd287   , -10'sd424   }; /* W[ 636] =  0.5605  -0.8281i */
            12'hA7D: dout <= { 10'sd286   , -10'sd424   }; /* W[ 637] =  0.5586  -0.8281i */
            12'hA7E: dout <= { 10'sd286   , -10'sd425   }; /* W[ 638] =  0.5586  -0.8301i */
            12'hA7F: dout <= { 10'sd285   , -10'sd425   }; /* W[ 639] =  0.5566  -0.8301i */
            12'hA80: dout <= { 10'sd284   , -10'sd426   }; /* W[ 640] =  0.5547  -0.8320i */
            12'hA81: dout <= { 10'sd284   , -10'sd426   }; /* W[ 641] =  0.5547  -0.8320i */
            12'hA82: dout <= { 10'sd283   , -10'sd427   }; /* W[ 642] =  0.5527  -0.8340i */
            12'hA83: dout <= { 10'sd282   , -10'sd427   }; /* W[ 643] =  0.5508  -0.8340i */
            12'hA84: dout <= { 10'sd282   , -10'sd427   }; /* W[ 644] =  0.5508  -0.8340i */
            12'hA85: dout <= { 10'sd281   , -10'sd428   }; /* W[ 645] =  0.5488  -0.8359i */
            12'hA86: dout <= { 10'sd281   , -10'sd428   }; /* W[ 646] =  0.5488  -0.8359i */
            12'hA87: dout <= { 10'sd280   , -10'sd429   }; /* W[ 647] =  0.5469  -0.8379i */
            12'hA88: dout <= { 10'sd279   , -10'sd429   }; /* W[ 648] =  0.5449  -0.8379i */
            12'hA89: dout <= { 10'sd279   , -10'sd430   }; /* W[ 649] =  0.5449  -0.8398i */
            12'hA8A: dout <= { 10'sd278   , -10'sd430   }; /* W[ 650] =  0.5430  -0.8398i */
            12'hA8B: dout <= { 10'sd277   , -10'sd430   }; /* W[ 651] =  0.5410  -0.8398i */
            12'hA8C: dout <= { 10'sd277   , -10'sd431   }; /* W[ 652] =  0.5410  -0.8418i */
            12'hA8D: dout <= { 10'sd276   , -10'sd431   }; /* W[ 653] =  0.5391  -0.8418i */
            12'hA8E: dout <= { 10'sd275   , -10'sd432   }; /* W[ 654] =  0.5371  -0.8438i */
            12'hA8F: dout <= { 10'sd275   , -10'sd432   }; /* W[ 655] =  0.5371  -0.8438i */
            12'hA90: dout <= { 10'sd274   , -10'sd433   }; /* W[ 656] =  0.5352  -0.8457i */
            12'hA91: dout <= { 10'sd273   , -10'sd433   }; /* W[ 657] =  0.5332  -0.8457i */
            12'hA92: dout <= { 10'sd273   , -10'sd433   }; /* W[ 658] =  0.5332  -0.8457i */
            12'hA93: dout <= { 10'sd272   , -10'sd434   }; /* W[ 659] =  0.5312  -0.8477i */
            12'hA94: dout <= { 10'sd271   , -10'sd434   }; /* W[ 660] =  0.5293  -0.8477i */
            12'hA95: dout <= { 10'sd271   , -10'sd435   }; /* W[ 661] =  0.5293  -0.8496i */
            12'hA96: dout <= { 10'sd270   , -10'sd435   }; /* W[ 662] =  0.5273  -0.8496i */
            12'hA97: dout <= { 10'sd269   , -10'sd435   }; /* W[ 663] =  0.5254  -0.8496i */
            12'hA98: dout <= { 10'sd269   , -10'sd436   }; /* W[ 664] =  0.5254  -0.8516i */
            12'hA99: dout <= { 10'sd268   , -10'sd436   }; /* W[ 665] =  0.5234  -0.8516i */
            12'hA9A: dout <= { 10'sd267   , -10'sd437   }; /* W[ 666] =  0.5215  -0.8535i */
            12'hA9B: dout <= { 10'sd267   , -10'sd437   }; /* W[ 667] =  0.5215  -0.8535i */
            12'hA9C: dout <= { 10'sd266   , -10'sd438   }; /* W[ 668] =  0.5195  -0.8555i */
            12'hA9D: dout <= { 10'sd265   , -10'sd438   }; /* W[ 669] =  0.5176  -0.8555i */
            12'hA9E: dout <= { 10'sd265   , -10'sd438   }; /* W[ 670] =  0.5176  -0.8555i */
            12'hA9F: dout <= { 10'sd264   , -10'sd439   }; /* W[ 671] =  0.5156  -0.8574i */
            12'hAA0: dout <= { 10'sd263   , -10'sd439   }; /* W[ 672] =  0.5137  -0.8574i */
            12'hAA1: dout <= { 10'sd263   , -10'sd440   }; /* W[ 673] =  0.5137  -0.8594i */
            12'hAA2: dout <= { 10'sd262   , -10'sd440   }; /* W[ 674] =  0.5117  -0.8594i */
            12'hAA3: dout <= { 10'sd261   , -10'sd440   }; /* W[ 675] =  0.5098  -0.8594i */
            12'hAA4: dout <= { 10'sd261   , -10'sd441   }; /* W[ 676] =  0.5098  -0.8613i */
            12'hAA5: dout <= { 10'sd260   , -10'sd441   }; /* W[ 677] =  0.5078  -0.8613i */
            12'hAA6: dout <= { 10'sd259   , -10'sd442   }; /* W[ 678] =  0.5059  -0.8633i */
            12'hAA7: dout <= { 10'sd258   , -10'sd442   }; /* W[ 679] =  0.5039  -0.8633i */
            12'hAA8: dout <= { 10'sd258   , -10'sd442   }; /* W[ 680] =  0.5039  -0.8633i */
            12'hAA9: dout <= { 10'sd257   , -10'sd443   }; /* W[ 681] =  0.5020  -0.8652i */
            12'hAAA: dout <= { 10'sd256   , -10'sd443   }; /* W[ 682] =  0.5000  -0.8652i */
            12'hAAB: dout <= { 10'sd256   , -10'sd444   }; /* W[ 683] =  0.5000  -0.8672i */
            12'hAAC: dout <= { 10'sd255   , -10'sd444   }; /* W[ 684] =  0.4980  -0.8672i */
            12'hAAD: dout <= { 10'sd254   , -10'sd444   }; /* W[ 685] =  0.4961  -0.8672i */
            12'hAAE: dout <= { 10'sd254   , -10'sd445   }; /* W[ 686] =  0.4961  -0.8691i */
            12'hAAF: dout <= { 10'sd253   , -10'sd445   }; /* W[ 687] =  0.4941  -0.8691i */
            12'hAB0: dout <= { 10'sd252   , -10'sd445   }; /* W[ 688] =  0.4922  -0.8691i */
            12'hAB1: dout <= { 10'sd252   , -10'sd446   }; /* W[ 689] =  0.4922  -0.8711i */
            12'hAB2: dout <= { 10'sd251   , -10'sd446   }; /* W[ 690] =  0.4902  -0.8711i */
            12'hAB3: dout <= { 10'sd250   , -10'sd447   }; /* W[ 691] =  0.4883  -0.8730i */
            12'hAB4: dout <= { 10'sd250   , -10'sd447   }; /* W[ 692] =  0.4883  -0.8730i */
            12'hAB5: dout <= { 10'sd249   , -10'sd447   }; /* W[ 693] =  0.4863  -0.8730i */
            12'hAB6: dout <= { 10'sd248   , -10'sd448   }; /* W[ 694] =  0.4844  -0.8750i */
            12'hAB7: dout <= { 10'sd248   , -10'sd448   }; /* W[ 695] =  0.4844  -0.8750i */
            12'hAB8: dout <= { 10'sd247   , -10'sd449   }; /* W[ 696] =  0.4824  -0.8770i */
            12'hAB9: dout <= { 10'sd246   , -10'sd449   }; /* W[ 697] =  0.4805  -0.8770i */
            12'hABA: dout <= { 10'sd246   , -10'sd449   }; /* W[ 698] =  0.4805  -0.8770i */
            12'hABB: dout <= { 10'sd245   , -10'sd450   }; /* W[ 699] =  0.4785  -0.8789i */
            12'hABC: dout <= { 10'sd244   , -10'sd450   }; /* W[ 700] =  0.4766  -0.8789i */
            12'hABD: dout <= { 10'sd243   , -10'sd450   }; /* W[ 701] =  0.4746  -0.8789i */
            12'hABE: dout <= { 10'sd243   , -10'sd451   }; /* W[ 702] =  0.4746  -0.8809i */
            12'hABF: dout <= { 10'sd242   , -10'sd451   }; /* W[ 703] =  0.4727  -0.8809i */
            12'hAC0: dout <= { 10'sd241   , -10'sd452   }; /* W[ 704] =  0.4707  -0.8828i */
            12'hAC1: dout <= { 10'sd241   , -10'sd452   }; /* W[ 705] =  0.4707  -0.8828i */
            12'hAC2: dout <= { 10'sd240   , -10'sd452   }; /* W[ 706] =  0.4688  -0.8828i */
            12'hAC3: dout <= { 10'sd239   , -10'sd453   }; /* W[ 707] =  0.4668  -0.8848i */
            12'hAC4: dout <= { 10'sd239   , -10'sd453   }; /* W[ 708] =  0.4668  -0.8848i */
            12'hAC5: dout <= { 10'sd238   , -10'sd453   }; /* W[ 709] =  0.4648  -0.8848i */
            12'hAC6: dout <= { 10'sd237   , -10'sd454   }; /* W[ 710] =  0.4629  -0.8867i */
            12'hAC7: dout <= { 10'sd236   , -10'sd454   }; /* W[ 711] =  0.4609  -0.8867i */
            12'hAC8: dout <= { 10'sd236   , -10'sd454   }; /* W[ 712] =  0.4609  -0.8867i */
            12'hAC9: dout <= { 10'sd235   , -10'sd455   }; /* W[ 713] =  0.4590  -0.8887i */
            12'hACA: dout <= { 10'sd234   , -10'sd455   }; /* W[ 714] =  0.4570  -0.8887i */
            12'hACB: dout <= { 10'sd234   , -10'sd456   }; /* W[ 715] =  0.4570  -0.8906i */
            12'hACC: dout <= { 10'sd233   , -10'sd456   }; /* W[ 716] =  0.4551  -0.8906i */
            12'hACD: dout <= { 10'sd232   , -10'sd456   }; /* W[ 717] =  0.4531  -0.8906i */
            12'hACE: dout <= { 10'sd232   , -10'sd457   }; /* W[ 718] =  0.4531  -0.8926i */
            12'hACF: dout <= { 10'sd231   , -10'sd457   }; /* W[ 719] =  0.4512  -0.8926i */
            12'hAD0: dout <= { 10'sd230   , -10'sd457   }; /* W[ 720] =  0.4492  -0.8926i */
            12'hAD1: dout <= { 10'sd229   , -10'sd458   }; /* W[ 721] =  0.4473  -0.8945i */
            12'hAD2: dout <= { 10'sd229   , -10'sd458   }; /* W[ 722] =  0.4473  -0.8945i */
            12'hAD3: dout <= { 10'sd228   , -10'sd458   }; /* W[ 723] =  0.4453  -0.8945i */
            12'hAD4: dout <= { 10'sd227   , -10'sd459   }; /* W[ 724] =  0.4434  -0.8965i */
            12'hAD5: dout <= { 10'sd227   , -10'sd459   }; /* W[ 725] =  0.4434  -0.8965i */
            12'hAD6: dout <= { 10'sd226   , -10'sd459   }; /* W[ 726] =  0.4414  -0.8965i */
            12'hAD7: dout <= { 10'sd225   , -10'sd460   }; /* W[ 727] =  0.4395  -0.8984i */
            12'hAD8: dout <= { 10'sd225   , -10'sd460   }; /* W[ 728] =  0.4395  -0.8984i */
            12'hAD9: dout <= { 10'sd224   , -10'sd460   }; /* W[ 729] =  0.4375  -0.8984i */
            12'hADA: dout <= { 10'sd223   , -10'sd461   }; /* W[ 730] =  0.4355  -0.9004i */
            12'hADB: dout <= { 10'sd222   , -10'sd461   }; /* W[ 731] =  0.4336  -0.9004i */
            12'hADC: dout <= { 10'sd222   , -10'sd461   }; /* W[ 732] =  0.4336  -0.9004i */
            12'hADD: dout <= { 10'sd221   , -10'sd462   }; /* W[ 733] =  0.4316  -0.9023i */
            12'hADE: dout <= { 10'sd220   , -10'sd462   }; /* W[ 734] =  0.4297  -0.9023i */
            12'hADF: dout <= { 10'sd220   , -10'sd463   }; /* W[ 735] =  0.4297  -0.9043i */
            12'hAE0: dout <= { 10'sd219   , -10'sd463   }; /* W[ 736] =  0.4277  -0.9043i */
            12'hAE1: dout <= { 10'sd218   , -10'sd463   }; /* W[ 737] =  0.4258  -0.9043i */
            12'hAE2: dout <= { 10'sd217   , -10'sd464   }; /* W[ 738] =  0.4238  -0.9062i */
            12'hAE3: dout <= { 10'sd217   , -10'sd464   }; /* W[ 739] =  0.4238  -0.9062i */
            12'hAE4: dout <= { 10'sd216   , -10'sd464   }; /* W[ 740] =  0.4219  -0.9062i */
            12'hAE5: dout <= { 10'sd215   , -10'sd465   }; /* W[ 741] =  0.4199  -0.9082i */
            12'hAE6: dout <= { 10'sd215   , -10'sd465   }; /* W[ 742] =  0.4199  -0.9082i */
            12'hAE7: dout <= { 10'sd214   , -10'sd465   }; /* W[ 743] =  0.4180  -0.9082i */
            12'hAE8: dout <= { 10'sd213   , -10'sd465   }; /* W[ 744] =  0.4160  -0.9082i */
            12'hAE9: dout <= { 10'sd212   , -10'sd466   }; /* W[ 745] =  0.4141  -0.9102i */
            12'hAEA: dout <= { 10'sd212   , -10'sd466   }; /* W[ 746] =  0.4141  -0.9102i */
            12'hAEB: dout <= { 10'sd211   , -10'sd466   }; /* W[ 747] =  0.4121  -0.9102i */
            12'hAEC: dout <= { 10'sd210   , -10'sd467   }; /* W[ 748] =  0.4102  -0.9121i */
            12'hAED: dout <= { 10'sd210   , -10'sd467   }; /* W[ 749] =  0.4102  -0.9121i */
            12'hAEE: dout <= { 10'sd209   , -10'sd467   }; /* W[ 750] =  0.4082  -0.9121i */
            12'hAEF: dout <= { 10'sd208   , -10'sd468   }; /* W[ 751] =  0.4062  -0.9141i */
            12'hAF0: dout <= { 10'sd207   , -10'sd468   }; /* W[ 752] =  0.4043  -0.9141i */
            12'hAF1: dout <= { 10'sd207   , -10'sd468   }; /* W[ 753] =  0.4043  -0.9141i */
            12'hAF2: dout <= { 10'sd206   , -10'sd469   }; /* W[ 754] =  0.4023  -0.9160i */
            12'hAF3: dout <= { 10'sd205   , -10'sd469   }; /* W[ 755] =  0.4004  -0.9160i */
            12'hAF4: dout <= { 10'sd205   , -10'sd469   }; /* W[ 756] =  0.4004  -0.9160i */
            12'hAF5: dout <= { 10'sd204   , -10'sd470   }; /* W[ 757] =  0.3984  -0.9180i */
            12'hAF6: dout <= { 10'sd203   , -10'sd470   }; /* W[ 758] =  0.3965  -0.9180i */
            12'hAF7: dout <= { 10'sd202   , -10'sd470   }; /* W[ 759] =  0.3945  -0.9180i */
            12'hAF8: dout <= { 10'sd202   , -10'sd471   }; /* W[ 760] =  0.3945  -0.9199i */
            12'hAF9: dout <= { 10'sd201   , -10'sd471   }; /* W[ 761] =  0.3926  -0.9199i */
            12'hAFA: dout <= { 10'sd200   , -10'sd471   }; /* W[ 762] =  0.3906  -0.9199i */
            12'hAFB: dout <= { 10'sd200   , -10'sd472   }; /* W[ 763] =  0.3906  -0.9219i */
            12'hAFC: dout <= { 10'sd199   , -10'sd472   }; /* W[ 764] =  0.3887  -0.9219i */
            12'hAFD: dout <= { 10'sd198   , -10'sd472   }; /* W[ 765] =  0.3867  -0.9219i */
            12'hAFE: dout <= { 10'sd197   , -10'sd472   }; /* W[ 766] =  0.3848  -0.9219i */
            12'hAFF: dout <= { 10'sd197   , -10'sd473   }; /* W[ 767] =  0.3848  -0.9238i */
            12'hB00: dout <= { 10'sd196   , -10'sd473   }; /* W[ 768] =  0.3828  -0.9238i */
            12'hB01: dout <= { 10'sd195   , -10'sd473   }; /* W[ 769] =  0.3809  -0.9238i */
            12'hB02: dout <= { 10'sd194   , -10'sd474   }; /* W[ 770] =  0.3789  -0.9258i */
            12'hB03: dout <= { 10'sd194   , -10'sd474   }; /* W[ 771] =  0.3789  -0.9258i */
            12'hB04: dout <= { 10'sd193   , -10'sd474   }; /* W[ 772] =  0.3770  -0.9258i */
            12'hB05: dout <= { 10'sd192   , -10'sd475   }; /* W[ 773] =  0.3750  -0.9277i */
            12'hB06: dout <= { 10'sd192   , -10'sd475   }; /* W[ 774] =  0.3750  -0.9277i */
            12'hB07: dout <= { 10'sd191   , -10'sd475   }; /* W[ 775] =  0.3730  -0.9277i */
            12'hB08: dout <= { 10'sd190   , -10'sd475   }; /* W[ 776] =  0.3711  -0.9277i */
            12'hB09: dout <= { 10'sd189   , -10'sd476   }; /* W[ 777] =  0.3691  -0.9297i */
            12'hB0A: dout <= { 10'sd189   , -10'sd476   }; /* W[ 778] =  0.3691  -0.9297i */
            12'hB0B: dout <= { 10'sd188   , -10'sd476   }; /* W[ 779] =  0.3672  -0.9297i */
            12'hB0C: dout <= { 10'sd187   , -10'sd477   }; /* W[ 780] =  0.3652  -0.9316i */
            12'hB0D: dout <= { 10'sd186   , -10'sd477   }; /* W[ 781] =  0.3633  -0.9316i */
            12'hB0E: dout <= { 10'sd186   , -10'sd477   }; /* W[ 782] =  0.3633  -0.9316i */
            12'hB0F: dout <= { 10'sd185   , -10'sd477   }; /* W[ 783] =  0.3613  -0.9316i */
            12'hB10: dout <= { 10'sd184   , -10'sd478   }; /* W[ 784] =  0.3594  -0.9336i */
            12'hB11: dout <= { 10'sd184   , -10'sd478   }; /* W[ 785] =  0.3594  -0.9336i */
            12'hB12: dout <= { 10'sd183   , -10'sd478   }; /* W[ 786] =  0.3574  -0.9336i */
            12'hB13: dout <= { 10'sd182   , -10'sd479   }; /* W[ 787] =  0.3555  -0.9355i */
            12'hB14: dout <= { 10'sd181   , -10'sd479   }; /* W[ 788] =  0.3535  -0.9355i */
            12'hB15: dout <= { 10'sd181   , -10'sd479   }; /* W[ 789] =  0.3535  -0.9355i */
            12'hB16: dout <= { 10'sd180   , -10'sd479   }; /* W[ 790] =  0.3516  -0.9355i */
            12'hB17: dout <= { 10'sd179   , -10'sd480   }; /* W[ 791] =  0.3496  -0.9375i */
            12'hB18: dout <= { 10'sd178   , -10'sd480   }; /* W[ 792] =  0.3477  -0.9375i */
            12'hB19: dout <= { 10'sd178   , -10'sd480   }; /* W[ 793] =  0.3477  -0.9375i */
            12'hB1A: dout <= { 10'sd177   , -10'sd480   }; /* W[ 794] =  0.3457  -0.9375i */
            12'hB1B: dout <= { 10'sd176   , -10'sd481   }; /* W[ 795] =  0.3438  -0.9395i */
            12'hB1C: dout <= { 10'sd175   , -10'sd481   }; /* W[ 796] =  0.3418  -0.9395i */
            12'hB1D: dout <= { 10'sd175   , -10'sd481   }; /* W[ 797] =  0.3418  -0.9395i */
            12'hB1E: dout <= { 10'sd174   , -10'sd482   }; /* W[ 798] =  0.3398  -0.9414i */
            12'hB1F: dout <= { 10'sd173   , -10'sd482   }; /* W[ 799] =  0.3379  -0.9414i */
            12'hB20: dout <= { 10'sd172   , -10'sd482   }; /* W[ 800] =  0.3359  -0.9414i */
            12'hB21: dout <= { 10'sd172   , -10'sd482   }; /* W[ 801] =  0.3359  -0.9414i */
            12'hB22: dout <= { 10'sd171   , -10'sd483   }; /* W[ 802] =  0.3340  -0.9434i */
            12'hB23: dout <= { 10'sd170   , -10'sd483   }; /* W[ 803] =  0.3320  -0.9434i */
            12'hB24: dout <= { 10'sd170   , -10'sd483   }; /* W[ 804] =  0.3320  -0.9434i */
            12'hB25: dout <= { 10'sd169   , -10'sd483   }; /* W[ 805] =  0.3301  -0.9434i */
            12'hB26: dout <= { 10'sd168   , -10'sd484   }; /* W[ 806] =  0.3281  -0.9453i */
            12'hB27: dout <= { 10'sd167   , -10'sd484   }; /* W[ 807] =  0.3262  -0.9453i */
            12'hB28: dout <= { 10'sd167   , -10'sd484   }; /* W[ 808] =  0.3262  -0.9453i */
            12'hB29: dout <= { 10'sd166   , -10'sd484   }; /* W[ 809] =  0.3242  -0.9453i */
            12'hB2A: dout <= { 10'sd165   , -10'sd485   }; /* W[ 810] =  0.3223  -0.9473i */
            12'hB2B: dout <= { 10'sd164   , -10'sd485   }; /* W[ 811] =  0.3203  -0.9473i */
            12'hB2C: dout <= { 10'sd164   , -10'sd485   }; /* W[ 812] =  0.3203  -0.9473i */
            12'hB2D: dout <= { 10'sd163   , -10'sd485   }; /* W[ 813] =  0.3184  -0.9473i */
            12'hB2E: dout <= { 10'sd162   , -10'sd486   }; /* W[ 814] =  0.3164  -0.9492i */
            12'hB2F: dout <= { 10'sd161   , -10'sd486   }; /* W[ 815] =  0.3145  -0.9492i */
            12'hB30: dout <= { 10'sd161   , -10'sd486   }; /* W[ 816] =  0.3145  -0.9492i */
            12'hB31: dout <= { 10'sd160   , -10'sd486   }; /* W[ 817] =  0.3125  -0.9492i */
            12'hB32: dout <= { 10'sd159   , -10'sd487   }; /* W[ 818] =  0.3105  -0.9512i */
            12'hB33: dout <= { 10'sd158   , -10'sd487   }; /* W[ 819] =  0.3086  -0.9512i */
            12'hB34: dout <= { 10'sd158   , -10'sd487   }; /* W[ 820] =  0.3086  -0.9512i */
            12'hB35: dout <= { 10'sd157   , -10'sd487   }; /* W[ 821] =  0.3066  -0.9512i */
            12'hB36: dout <= { 10'sd156   , -10'sd488   }; /* W[ 822] =  0.3047  -0.9531i */
            12'hB37: dout <= { 10'sd155   , -10'sd488   }; /* W[ 823] =  0.3027  -0.9531i */
            12'hB38: dout <= { 10'sd155   , -10'sd488   }; /* W[ 824] =  0.3027  -0.9531i */
            12'hB39: dout <= { 10'sd154   , -10'sd488   }; /* W[ 825] =  0.3008  -0.9531i */
            12'hB3A: dout <= { 10'sd153   , -10'sd489   }; /* W[ 826] =  0.2988  -0.9551i */
            12'hB3B: dout <= { 10'sd152   , -10'sd489   }; /* W[ 827] =  0.2969  -0.9551i */
            12'hB3C: dout <= { 10'sd152   , -10'sd489   }; /* W[ 828] =  0.2969  -0.9551i */
            12'hB3D: dout <= { 10'sd151   , -10'sd489   }; /* W[ 829] =  0.2949  -0.9551i */
            12'hB3E: dout <= { 10'sd150   , -10'sd489   }; /* W[ 830] =  0.2930  -0.9551i */
            12'hB3F: dout <= { 10'sd149   , -10'sd490   }; /* W[ 831] =  0.2910  -0.9570i */
            12'hB40: dout <= { 10'sd149   , -10'sd490   }; /* W[ 832] =  0.2910  -0.9570i */
            12'hB41: dout <= { 10'sd148   , -10'sd490   }; /* W[ 833] =  0.2891  -0.9570i */
            12'hB42: dout <= { 10'sd147   , -10'sd490   }; /* W[ 834] =  0.2871  -0.9570i */
            12'hB43: dout <= { 10'sd146   , -10'sd491   }; /* W[ 835] =  0.2852  -0.9590i */
            12'hB44: dout <= { 10'sd146   , -10'sd491   }; /* W[ 836] =  0.2852  -0.9590i */
            12'hB45: dout <= { 10'sd145   , -10'sd491   }; /* W[ 837] =  0.2832  -0.9590i */
            12'hB46: dout <= { 10'sd144   , -10'sd491   }; /* W[ 838] =  0.2812  -0.9590i */
            12'hB47: dout <= { 10'sd143   , -10'sd492   }; /* W[ 839] =  0.2793  -0.9609i */
            12'hB48: dout <= { 10'sd143   , -10'sd492   }; /* W[ 840] =  0.2793  -0.9609i */
            12'hB49: dout <= { 10'sd142   , -10'sd492   }; /* W[ 841] =  0.2773  -0.9609i */
            12'hB4A: dout <= { 10'sd141   , -10'sd492   }; /* W[ 842] =  0.2754  -0.9609i */
            12'hB4B: dout <= { 10'sd140   , -10'sd492   }; /* W[ 843] =  0.2734  -0.9609i */
            12'hB4C: dout <= { 10'sd140   , -10'sd493   }; /* W[ 844] =  0.2734  -0.9629i */
            12'hB4D: dout <= { 10'sd139   , -10'sd493   }; /* W[ 845] =  0.2715  -0.9629i */
            12'hB4E: dout <= { 10'sd138   , -10'sd493   }; /* W[ 846] =  0.2695  -0.9629i */
            12'hB4F: dout <= { 10'sd137   , -10'sd493   }; /* W[ 847] =  0.2676  -0.9629i */
            12'hB50: dout <= { 10'sd137   , -10'sd493   }; /* W[ 848] =  0.2676  -0.9629i */
            12'hB51: dout <= { 10'sd136   , -10'sd494   }; /* W[ 849] =  0.2656  -0.9648i */
            12'hB52: dout <= { 10'sd135   , -10'sd494   }; /* W[ 850] =  0.2637  -0.9648i */
            12'hB53: dout <= { 10'sd134   , -10'sd494   }; /* W[ 851] =  0.2617  -0.9648i */
            12'hB54: dout <= { 10'sd134   , -10'sd494   }; /* W[ 852] =  0.2617  -0.9648i */
            12'hB55: dout <= { 10'sd133   , -10'sd494   }; /* W[ 853] =  0.2598  -0.9648i */
            12'hB56: dout <= { 10'sd132   , -10'sd495   }; /* W[ 854] =  0.2578  -0.9668i */
            12'hB57: dout <= { 10'sd131   , -10'sd495   }; /* W[ 855] =  0.2559  -0.9668i */
            12'hB58: dout <= { 10'sd130   , -10'sd495   }; /* W[ 856] =  0.2539  -0.9668i */
            12'hB59: dout <= { 10'sd130   , -10'sd495   }; /* W[ 857] =  0.2539  -0.9668i */
            12'hB5A: dout <= { 10'sd129   , -10'sd495   }; /* W[ 858] =  0.2520  -0.9668i */
            12'hB5B: dout <= { 10'sd128   , -10'sd496   }; /* W[ 859] =  0.2500  -0.9688i */
            12'hB5C: dout <= { 10'sd127   , -10'sd496   }; /* W[ 860] =  0.2480  -0.9688i */
            12'hB5D: dout <= { 10'sd127   , -10'sd496   }; /* W[ 861] =  0.2480  -0.9688i */
            12'hB5E: dout <= { 10'sd126   , -10'sd496   }; /* W[ 862] =  0.2461  -0.9688i */
            12'hB5F: dout <= { 10'sd125   , -10'sd496   }; /* W[ 863] =  0.2441  -0.9688i */
            12'hB60: dout <= { 10'sd124   , -10'sd497   }; /* W[ 864] =  0.2422  -0.9707i */
            12'hB61: dout <= { 10'sd124   , -10'sd497   }; /* W[ 865] =  0.2422  -0.9707i */
            12'hB62: dout <= { 10'sd123   , -10'sd497   }; /* W[ 866] =  0.2402  -0.9707i */
            12'hB63: dout <= { 10'sd122   , -10'sd497   }; /* W[ 867] =  0.2383  -0.9707i */
            12'hB64: dout <= { 10'sd121   , -10'sd497   }; /* W[ 868] =  0.2363  -0.9707i */
            12'hB65: dout <= { 10'sd121   , -10'sd498   }; /* W[ 869] =  0.2363  -0.9727i */
            12'hB66: dout <= { 10'sd120   , -10'sd498   }; /* W[ 870] =  0.2344  -0.9727i */
            12'hB67: dout <= { 10'sd119   , -10'sd498   }; /* W[ 871] =  0.2324  -0.9727i */
            12'hB68: dout <= { 10'sd118   , -10'sd498   }; /* W[ 872] =  0.2305  -0.9727i */
            12'hB69: dout <= { 10'sd118   , -10'sd498   }; /* W[ 873] =  0.2305  -0.9727i */
            12'hB6A: dout <= { 10'sd117   , -10'sd499   }; /* W[ 874] =  0.2285  -0.9746i */
            12'hB6B: dout <= { 10'sd116   , -10'sd499   }; /* W[ 875] =  0.2266  -0.9746i */
            12'hB6C: dout <= { 10'sd115   , -10'sd499   }; /* W[ 876] =  0.2246  -0.9746i */
            12'hB6D: dout <= { 10'sd114   , -10'sd499   }; /* W[ 877] =  0.2227  -0.9746i */
            12'hB6E: dout <= { 10'sd114   , -10'sd499   }; /* W[ 878] =  0.2227  -0.9746i */
            12'hB6F: dout <= { 10'sd113   , -10'sd499   }; /* W[ 879] =  0.2207  -0.9746i */
            12'hB70: dout <= { 10'sd112   , -10'sd500   }; /* W[ 880] =  0.2188  -0.9766i */
            12'hB71: dout <= { 10'sd111   , -10'sd500   }; /* W[ 881] =  0.2168  -0.9766i */
            12'hB72: dout <= { 10'sd111   , -10'sd500   }; /* W[ 882] =  0.2168  -0.9766i */
            12'hB73: dout <= { 10'sd110   , -10'sd500   }; /* W[ 883] =  0.2148  -0.9766i */
            12'hB74: dout <= { 10'sd109   , -10'sd500   }; /* W[ 884] =  0.2129  -0.9766i */
            12'hB75: dout <= { 10'sd108   , -10'sd500   }; /* W[ 885] =  0.2109  -0.9766i */
            12'hB76: dout <= { 10'sd108   , -10'sd501   }; /* W[ 886] =  0.2109  -0.9785i */
            12'hB77: dout <= { 10'sd107   , -10'sd501   }; /* W[ 887] =  0.2090  -0.9785i */
            12'hB78: dout <= { 10'sd106   , -10'sd501   }; /* W[ 888] =  0.2070  -0.9785i */
            12'hB79: dout <= { 10'sd105   , -10'sd501   }; /* W[ 889] =  0.2051  -0.9785i */
            12'hB7A: dout <= { 10'sd105   , -10'sd501   }; /* W[ 890] =  0.2051  -0.9785i */
            12'hB7B: dout <= { 10'sd104   , -10'sd501   }; /* W[ 891] =  0.2031  -0.9785i */
            12'hB7C: dout <= { 10'sd103   , -10'sd502   }; /* W[ 892] =  0.2012  -0.9805i */
            12'hB7D: dout <= { 10'sd102   , -10'sd502   }; /* W[ 893] =  0.1992  -0.9805i */
            12'hB7E: dout <= { 10'sd101   , -10'sd502   }; /* W[ 894] =  0.1973  -0.9805i */
            12'hB7F: dout <= { 10'sd101   , -10'sd502   }; /* W[ 895] =  0.1973  -0.9805i */
            12'hB80: dout <= { 10'sd100   , -10'sd502   }; /* W[ 896] =  0.1953  -0.9805i */
            12'hB81: dout <= { 10'sd99    , -10'sd502   }; /* W[ 897] =  0.1934  -0.9805i */
            12'hB82: dout <= { 10'sd98    , -10'sd502   }; /* W[ 898] =  0.1914  -0.9805i */
            12'hB83: dout <= { 10'sd98    , -10'sd503   }; /* W[ 899] =  0.1914  -0.9824i */
            12'hB84: dout <= { 10'sd97    , -10'sd503   }; /* W[ 900] =  0.1895  -0.9824i */
            12'hB85: dout <= { 10'sd96    , -10'sd503   }; /* W[ 901] =  0.1875  -0.9824i */
            12'hB86: dout <= { 10'sd95    , -10'sd503   }; /* W[ 902] =  0.1855  -0.9824i */
            12'hB87: dout <= { 10'sd94    , -10'sd503   }; /* W[ 903] =  0.1836  -0.9824i */
            12'hB88: dout <= { 10'sd94    , -10'sd503   }; /* W[ 904] =  0.1836  -0.9824i */
            12'hB89: dout <= { 10'sd93    , -10'sd503   }; /* W[ 905] =  0.1816  -0.9824i */
            12'hB8A: dout <= { 10'sd92    , -10'sd504   }; /* W[ 906] =  0.1797  -0.9844i */
            12'hB8B: dout <= { 10'sd91    , -10'sd504   }; /* W[ 907] =  0.1777  -0.9844i */
            12'hB8C: dout <= { 10'sd91    , -10'sd504   }; /* W[ 908] =  0.1777  -0.9844i */
            12'hB8D: dout <= { 10'sd90    , -10'sd504   }; /* W[ 909] =  0.1758  -0.9844i */
            12'hB8E: dout <= { 10'sd89    , -10'sd504   }; /* W[ 910] =  0.1738  -0.9844i */
            12'hB8F: dout <= { 10'sd88    , -10'sd504   }; /* W[ 911] =  0.1719  -0.9844i */
            12'hB90: dout <= { 10'sd88    , -10'sd504   }; /* W[ 912] =  0.1719  -0.9844i */
            12'hB91: dout <= { 10'sd87    , -10'sd505   }; /* W[ 913] =  0.1699  -0.9863i */
            12'hB92: dout <= { 10'sd86    , -10'sd505   }; /* W[ 914] =  0.1680  -0.9863i */
            12'hB93: dout <= { 10'sd85    , -10'sd505   }; /* W[ 915] =  0.1660  -0.9863i */
            12'hB94: dout <= { 10'sd84    , -10'sd505   }; /* W[ 916] =  0.1641  -0.9863i */
            12'hB95: dout <= { 10'sd84    , -10'sd505   }; /* W[ 917] =  0.1641  -0.9863i */
            12'hB96: dout <= { 10'sd83    , -10'sd505   }; /* W[ 918] =  0.1621  -0.9863i */
            12'hB97: dout <= { 10'sd82    , -10'sd505   }; /* W[ 919] =  0.1602  -0.9863i */
            12'hB98: dout <= { 10'sd81    , -10'sd505   }; /* W[ 920] =  0.1582  -0.9863i */
            12'hB99: dout <= { 10'sd81    , -10'sd506   }; /* W[ 921] =  0.1582  -0.9883i */
            12'hB9A: dout <= { 10'sd80    , -10'sd506   }; /* W[ 922] =  0.1562  -0.9883i */
            12'hB9B: dout <= { 10'sd79    , -10'sd506   }; /* W[ 923] =  0.1543  -0.9883i */
            12'hB9C: dout <= { 10'sd78    , -10'sd506   }; /* W[ 924] =  0.1523  -0.9883i */
            12'hB9D: dout <= { 10'sd77    , -10'sd506   }; /* W[ 925] =  0.1504  -0.9883i */
            12'hB9E: dout <= { 10'sd77    , -10'sd506   }; /* W[ 926] =  0.1504  -0.9883i */
            12'hB9F: dout <= { 10'sd76    , -10'sd506   }; /* W[ 927] =  0.1484  -0.9883i */
            12'hBA0: dout <= { 10'sd75    , -10'sd506   }; /* W[ 928] =  0.1465  -0.9883i */
            12'hBA1: dout <= { 10'sd74    , -10'sd507   }; /* W[ 929] =  0.1445  -0.9902i */
            12'hBA2: dout <= { 10'sd74    , -10'sd507   }; /* W[ 930] =  0.1445  -0.9902i */
            12'hBA3: dout <= { 10'sd73    , -10'sd507   }; /* W[ 931] =  0.1426  -0.9902i */
            12'hBA4: dout <= { 10'sd72    , -10'sd507   }; /* W[ 932] =  0.1406  -0.9902i */
            12'hBA5: dout <= { 10'sd71    , -10'sd507   }; /* W[ 933] =  0.1387  -0.9902i */
            12'hBA6: dout <= { 10'sd70    , -10'sd507   }; /* W[ 934] =  0.1367  -0.9902i */
            12'hBA7: dout <= { 10'sd70    , -10'sd507   }; /* W[ 935] =  0.1367  -0.9902i */
            12'hBA8: dout <= { 10'sd69    , -10'sd507   }; /* W[ 936] =  0.1348  -0.9902i */
            12'hBA9: dout <= { 10'sd68    , -10'sd507   }; /* W[ 937] =  0.1328  -0.9902i */
            12'hBAA: dout <= { 10'sd67    , -10'sd508   }; /* W[ 938] =  0.1309  -0.9922i */
            12'hBAB: dout <= { 10'sd67    , -10'sd508   }; /* W[ 939] =  0.1309  -0.9922i */
            12'hBAC: dout <= { 10'sd66    , -10'sd508   }; /* W[ 940] =  0.1289  -0.9922i */
            12'hBAD: dout <= { 10'sd65    , -10'sd508   }; /* W[ 941] =  0.1270  -0.9922i */
            12'hBAE: dout <= { 10'sd64    , -10'sd508   }; /* W[ 942] =  0.1250  -0.9922i */
            12'hBAF: dout <= { 10'sd63    , -10'sd508   }; /* W[ 943] =  0.1230  -0.9922i */
            12'hBB0: dout <= { 10'sd63    , -10'sd508   }; /* W[ 944] =  0.1230  -0.9922i */
            12'hBB1: dout <= { 10'sd62    , -10'sd508   }; /* W[ 945] =  0.1211  -0.9922i */
            12'hBB2: dout <= { 10'sd61    , -10'sd508   }; /* W[ 946] =  0.1191  -0.9922i */
            12'hBB3: dout <= { 10'sd60    , -10'sd508   }; /* W[ 947] =  0.1172  -0.9922i */
            12'hBB4: dout <= { 10'sd60    , -10'sd509   }; /* W[ 948] =  0.1172  -0.9941i */
            12'hBB5: dout <= { 10'sd59    , -10'sd509   }; /* W[ 949] =  0.1152  -0.9941i */
            12'hBB6: dout <= { 10'sd58    , -10'sd509   }; /* W[ 950] =  0.1133  -0.9941i */
            12'hBB7: dout <= { 10'sd57    , -10'sd509   }; /* W[ 951] =  0.1113  -0.9941i */
            12'hBB8: dout <= { 10'sd56    , -10'sd509   }; /* W[ 952] =  0.1094  -0.9941i */
            12'hBB9: dout <= { 10'sd56    , -10'sd509   }; /* W[ 953] =  0.1094  -0.9941i */
            12'hBBA: dout <= { 10'sd55    , -10'sd509   }; /* W[ 954] =  0.1074  -0.9941i */
            12'hBBB: dout <= { 10'sd54    , -10'sd509   }; /* W[ 955] =  0.1055  -0.9941i */
            12'hBBC: dout <= { 10'sd53    , -10'sd509   }; /* W[ 956] =  0.1035  -0.9941i */
            12'hBBD: dout <= { 10'sd53    , -10'sd509   }; /* W[ 957] =  0.1035  -0.9941i */
            12'hBBE: dout <= { 10'sd52    , -10'sd509   }; /* W[ 958] =  0.1016  -0.9941i */
            12'hBBF: dout <= { 10'sd51    , -10'sd509   }; /* W[ 959] =  0.0996  -0.9941i */
            12'hBC0: dout <= { 10'sd50    , -10'sd510   }; /* W[ 960] =  0.0977  -0.9961i */
            12'hBC1: dout <= { 10'sd49    , -10'sd510   }; /* W[ 961] =  0.0957  -0.9961i */
            12'hBC2: dout <= { 10'sd49    , -10'sd510   }; /* W[ 962] =  0.0957  -0.9961i */
            12'hBC3: dout <= { 10'sd48    , -10'sd510   }; /* W[ 963] =  0.0938  -0.9961i */
            12'hBC4: dout <= { 10'sd47    , -10'sd510   }; /* W[ 964] =  0.0918  -0.9961i */
            12'hBC5: dout <= { 10'sd46    , -10'sd510   }; /* W[ 965] =  0.0898  -0.9961i */
            12'hBC6: dout <= { 10'sd45    , -10'sd510   }; /* W[ 966] =  0.0879  -0.9961i */
            12'hBC7: dout <= { 10'sd45    , -10'sd510   }; /* W[ 967] =  0.0879  -0.9961i */
            12'hBC8: dout <= { 10'sd44    , -10'sd510   }; /* W[ 968] =  0.0859  -0.9961i */
            12'hBC9: dout <= { 10'sd43    , -10'sd510   }; /* W[ 969] =  0.0840  -0.9961i */
            12'hBCA: dout <= { 10'sd42    , -10'sd510   }; /* W[ 970] =  0.0820  -0.9961i */
            12'hBCB: dout <= { 10'sd42    , -10'sd510   }; /* W[ 971] =  0.0820  -0.9961i */
            12'hBCC: dout <= { 10'sd41    , -10'sd510   }; /* W[ 972] =  0.0801  -0.9961i */
            12'hBCD: dout <= { 10'sd40    , -10'sd510   }; /* W[ 973] =  0.0781  -0.9961i */
            12'hBCE: dout <= { 10'sd39    , -10'sd510   }; /* W[ 974] =  0.0762  -0.9961i */
            12'hBCF: dout <= { 10'sd38    , -10'sd511   }; /* W[ 975] =  0.0742  -0.9980i */
            12'hBD0: dout <= { 10'sd38    , -10'sd511   }; /* W[ 976] =  0.0742  -0.9980i */
            12'hBD1: dout <= { 10'sd37    , -10'sd511   }; /* W[ 977] =  0.0723  -0.9980i */
            12'hBD2: dout <= { 10'sd36    , -10'sd511   }; /* W[ 978] =  0.0703  -0.9980i */
            12'hBD3: dout <= { 10'sd35    , -10'sd511   }; /* W[ 979] =  0.0684  -0.9980i */
            12'hBD4: dout <= { 10'sd35    , -10'sd511   }; /* W[ 980] =  0.0684  -0.9980i */
            12'hBD5: dout <= { 10'sd34    , -10'sd511   }; /* W[ 981] =  0.0664  -0.9980i */
            12'hBD6: dout <= { 10'sd33    , -10'sd511   }; /* W[ 982] =  0.0645  -0.9980i */
            12'hBD7: dout <= { 10'sd32    , -10'sd511   }; /* W[ 983] =  0.0625  -0.9980i */
            12'hBD8: dout <= { 10'sd31    , -10'sd511   }; /* W[ 984] =  0.0605  -0.9980i */
            12'hBD9: dout <= { 10'sd31    , -10'sd511   }; /* W[ 985] =  0.0605  -0.9980i */
            12'hBDA: dout <= { 10'sd30    , -10'sd511   }; /* W[ 986] =  0.0586  -0.9980i */
            12'hBDB: dout <= { 10'sd29    , -10'sd511   }; /* W[ 987] =  0.0566  -0.9980i */
            12'hBDC: dout <= { 10'sd28    , -10'sd511   }; /* W[ 988] =  0.0547  -0.9980i */
            12'hBDD: dout <= { 10'sd27    , -10'sd511   }; /* W[ 989] =  0.0527  -0.9980i */
            12'hBDE: dout <= { 10'sd27    , -10'sd511   }; /* W[ 990] =  0.0527  -0.9980i */
            12'hBDF: dout <= { 10'sd26    , -10'sd511   }; /* W[ 991] =  0.0508  -0.9980i */
            12'hBE0: dout <= { 10'sd25    , -10'sd511   }; /* W[ 992] =  0.0488  -0.9980i */
            12'hBE1: dout <= { 10'sd24    , -10'sd511   }; /* W[ 993] =  0.0469  -0.9980i */
            12'hBE2: dout <= { 10'sd24    , -10'sd511   }; /* W[ 994] =  0.0469  -0.9980i */
            12'hBE3: dout <= { 10'sd23    , -10'sd511   }; /* W[ 995] =  0.0449  -0.9980i */
            12'hBE4: dout <= { 10'sd22    , -10'sd512   }; /* W[ 996] =  0.0430  -1.0000i */
            12'hBE5: dout <= { 10'sd21    , -10'sd512   }; /* W[ 997] =  0.0410  -1.0000i */
            12'hBE6: dout <= { 10'sd20    , -10'sd512   }; /* W[ 998] =  0.0391  -1.0000i */
            12'hBE7: dout <= { 10'sd20    , -10'sd512   }; /* W[ 999] =  0.0391  -1.0000i */
            12'hBE8: dout <= { 10'sd19    , -10'sd512   }; /* W[1000] =  0.0371  -1.0000i */
            12'hBE9: dout <= { 10'sd18    , -10'sd512   }; /* W[1001] =  0.0352  -1.0000i */
            12'hBEA: dout <= { 10'sd17    , -10'sd512   }; /* W[1002] =  0.0332  -1.0000i */
            12'hBEB: dout <= { 10'sd16    , -10'sd512   }; /* W[1003] =  0.0312  -1.0000i */
            12'hBEC: dout <= { 10'sd16    , -10'sd512   }; /* W[1004] =  0.0312  -1.0000i */
            12'hBED: dout <= { 10'sd15    , -10'sd512   }; /* W[1005] =  0.0293  -1.0000i */
            12'hBEE: dout <= { 10'sd14    , -10'sd512   }; /* W[1006] =  0.0273  -1.0000i */
            12'hBEF: dout <= { 10'sd13    , -10'sd512   }; /* W[1007] =  0.0254  -1.0000i */
            12'hBF0: dout <= { 10'sd13    , -10'sd512   }; /* W[1008] =  0.0254  -1.0000i */
            12'hBF1: dout <= { 10'sd12    , -10'sd512   }; /* W[1009] =  0.0234  -1.0000i */
            12'hBF2: dout <= { 10'sd11    , -10'sd512   }; /* W[1010] =  0.0215  -1.0000i */
            12'hBF3: dout <= { 10'sd10    , -10'sd512   }; /* W[1011] =  0.0195  -1.0000i */
            12'hBF4: dout <= { 10'sd9     , -10'sd512   }; /* W[1012] =  0.0176  -1.0000i */
            12'hBF5: dout <= { 10'sd9     , -10'sd512   }; /* W[1013] =  0.0176  -1.0000i */
            12'hBF6: dout <= { 10'sd8     , -10'sd512   }; /* W[1014] =  0.0156  -1.0000i */
            12'hBF7: dout <= { 10'sd7     , -10'sd512   }; /* W[1015] =  0.0137  -1.0000i */
            12'hBF8: dout <= { 10'sd6     , -10'sd512   }; /* W[1016] =  0.0117  -1.0000i */
            12'hBF9: dout <= { 10'sd5     , -10'sd512   }; /* W[1017] =  0.0098  -1.0000i */
            12'hBFA: dout <= { 10'sd5     , -10'sd512   }; /* W[1018] =  0.0098  -1.0000i */
            12'hBFB: dout <= { 10'sd4     , -10'sd512   }; /* W[1019] =  0.0078  -1.0000i */
            12'hBFC: dout <= { 10'sd3     , -10'sd512   }; /* W[1020] =  0.0059  -1.0000i */
            12'hBFD: dout <= { 10'sd2     , -10'sd512   }; /* W[1021] =  0.0039  -1.0000i */
            12'hBFE: dout <= { 10'sd2     , -10'sd512   }; /* W[1022] =  0.0039  -1.0000i */
            12'hBFF: dout <= { 10'sd1     , -10'sd512   }; /* W[1023] =  0.0020  -1.0000i */
            12'hC00: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            12'hC01: dout <= { 10'sd511   , -10'sd2     }; /* W[   3] =  0.9980  -0.0039i */
            12'hC02: dout <= { 10'sd511   , -10'sd5     }; /* W[   6] =  0.9980  -0.0098i */
            12'hC03: dout <= { 10'sd511   , -10'sd7     }; /* W[   9] =  0.9980  -0.0137i */
            12'hC04: dout <= { 10'sd511   , -10'sd9     }; /* W[  12] =  0.9980  -0.0176i */
            12'hC05: dout <= { 10'sd511   , -10'sd12    }; /* W[  15] =  0.9980  -0.0234i */
            12'hC06: dout <= { 10'sd511   , -10'sd14    }; /* W[  18] =  0.9980  -0.0273i */
            12'hC07: dout <= { 10'sd511   , -10'sd16    }; /* W[  21] =  0.9980  -0.0312i */
            12'hC08: dout <= { 10'sd511   , -10'sd19    }; /* W[  24] =  0.9980  -0.0371i */
            12'hC09: dout <= { 10'sd511   , -10'sd21    }; /* W[  27] =  0.9980  -0.0410i */
            12'hC0A: dout <= { 10'sd511   , -10'sd24    }; /* W[  30] =  0.9980  -0.0469i */
            12'hC0B: dout <= { 10'sd511   , -10'sd26    }; /* W[  33] =  0.9980  -0.0508i */
            12'hC0C: dout <= { 10'sd511   , -10'sd28    }; /* W[  36] =  0.9980  -0.0547i */
            12'hC0D: dout <= { 10'sd511   , -10'sd31    }; /* W[  39] =  0.9980  -0.0605i */
            12'hC0E: dout <= { 10'sd511   , -10'sd33    }; /* W[  42] =  0.9980  -0.0645i */
            12'hC0F: dout <= { 10'sd511   , -10'sd35    }; /* W[  45] =  0.9980  -0.0684i */
            12'hC10: dout <= { 10'sd511   , -10'sd38    }; /* W[  48] =  0.9980  -0.0742i */
            12'hC11: dout <= { 10'sd510   , -10'sd40    }; /* W[  51] =  0.9961  -0.0781i */
            12'hC12: dout <= { 10'sd510   , -10'sd42    }; /* W[  54] =  0.9961  -0.0820i */
            12'hC13: dout <= { 10'sd510   , -10'sd45    }; /* W[  57] =  0.9961  -0.0879i */
            12'hC14: dout <= { 10'sd510   , -10'sd47    }; /* W[  60] =  0.9961  -0.0918i */
            12'hC15: dout <= { 10'sd510   , -10'sd49    }; /* W[  63] =  0.9961  -0.0957i */
            12'hC16: dout <= { 10'sd509   , -10'sd52    }; /* W[  66] =  0.9941  -0.1016i */
            12'hC17: dout <= { 10'sd509   , -10'sd54    }; /* W[  69] =  0.9941  -0.1055i */
            12'hC18: dout <= { 10'sd509   , -10'sd56    }; /* W[  72] =  0.9941  -0.1094i */
            12'hC19: dout <= { 10'sd509   , -10'sd59    }; /* W[  75] =  0.9941  -0.1152i */
            12'hC1A: dout <= { 10'sd508   , -10'sd61    }; /* W[  78] =  0.9922  -0.1191i */
            12'hC1B: dout <= { 10'sd508   , -10'sd63    }; /* W[  81] =  0.9922  -0.1230i */
            12'hC1C: dout <= { 10'sd508   , -10'sd66    }; /* W[  84] =  0.9922  -0.1289i */
            12'hC1D: dout <= { 10'sd507   , -10'sd68    }; /* W[  87] =  0.9902  -0.1328i */
            12'hC1E: dout <= { 10'sd507   , -10'sd70    }; /* W[  90] =  0.9902  -0.1367i */
            12'hC1F: dout <= { 10'sd507   , -10'sd73    }; /* W[  93] =  0.9902  -0.1426i */
            12'hC20: dout <= { 10'sd506   , -10'sd75    }; /* W[  96] =  0.9883  -0.1465i */
            12'hC21: dout <= { 10'sd506   , -10'sd77    }; /* W[  99] =  0.9883  -0.1504i */
            12'hC22: dout <= { 10'sd506   , -10'sd80    }; /* W[ 102] =  0.9883  -0.1562i */
            12'hC23: dout <= { 10'sd505   , -10'sd82    }; /* W[ 105] =  0.9863  -0.1602i */
            12'hC24: dout <= { 10'sd505   , -10'sd84    }; /* W[ 108] =  0.9863  -0.1641i */
            12'hC25: dout <= { 10'sd505   , -10'sd87    }; /* W[ 111] =  0.9863  -0.1699i */
            12'hC26: dout <= { 10'sd504   , -10'sd89    }; /* W[ 114] =  0.9844  -0.1738i */
            12'hC27: dout <= { 10'sd504   , -10'sd91    }; /* W[ 117] =  0.9844  -0.1777i */
            12'hC28: dout <= { 10'sd503   , -10'sd94    }; /* W[ 120] =  0.9824  -0.1836i */
            12'hC29: dout <= { 10'sd503   , -10'sd96    }; /* W[ 123] =  0.9824  -0.1875i */
            12'hC2A: dout <= { 10'sd502   , -10'sd98    }; /* W[ 126] =  0.9805  -0.1914i */
            12'hC2B: dout <= { 10'sd502   , -10'sd101   }; /* W[ 129] =  0.9805  -0.1973i */
            12'hC2C: dout <= { 10'sd502   , -10'sd103   }; /* W[ 132] =  0.9805  -0.2012i */
            12'hC2D: dout <= { 10'sd501   , -10'sd105   }; /* W[ 135] =  0.9785  -0.2051i */
            12'hC2E: dout <= { 10'sd501   , -10'sd108   }; /* W[ 138] =  0.9785  -0.2109i */
            12'hC2F: dout <= { 10'sd500   , -10'sd110   }; /* W[ 141] =  0.9766  -0.2148i */
            12'hC30: dout <= { 10'sd500   , -10'sd112   }; /* W[ 144] =  0.9766  -0.2188i */
            12'hC31: dout <= { 10'sd499   , -10'sd114   }; /* W[ 147] =  0.9746  -0.2227i */
            12'hC32: dout <= { 10'sd499   , -10'sd117   }; /* W[ 150] =  0.9746  -0.2285i */
            12'hC33: dout <= { 10'sd498   , -10'sd119   }; /* W[ 153] =  0.9727  -0.2324i */
            12'hC34: dout <= { 10'sd497   , -10'sd121   }; /* W[ 156] =  0.9707  -0.2363i */
            12'hC35: dout <= { 10'sd497   , -10'sd124   }; /* W[ 159] =  0.9707  -0.2422i */
            12'hC36: dout <= { 10'sd496   , -10'sd126   }; /* W[ 162] =  0.9688  -0.2461i */
            12'hC37: dout <= { 10'sd496   , -10'sd128   }; /* W[ 165] =  0.9688  -0.2500i */
            12'hC38: dout <= { 10'sd495   , -10'sd130   }; /* W[ 168] =  0.9668  -0.2539i */
            12'hC39: dout <= { 10'sd494   , -10'sd133   }; /* W[ 171] =  0.9648  -0.2598i */
            12'hC3A: dout <= { 10'sd494   , -10'sd135   }; /* W[ 174] =  0.9648  -0.2637i */
            12'hC3B: dout <= { 10'sd493   , -10'sd137   }; /* W[ 177] =  0.9629  -0.2676i */
            12'hC3C: dout <= { 10'sd493   , -10'sd140   }; /* W[ 180] =  0.9629  -0.2734i */
            12'hC3D: dout <= { 10'sd492   , -10'sd142   }; /* W[ 183] =  0.9609  -0.2773i */
            12'hC3E: dout <= { 10'sd491   , -10'sd144   }; /* W[ 186] =  0.9590  -0.2812i */
            12'hC3F: dout <= { 10'sd491   , -10'sd146   }; /* W[ 189] =  0.9590  -0.2852i */
            12'hC40: dout <= { 10'sd490   , -10'sd149   }; /* W[ 192] =  0.9570  -0.2910i */
            12'hC41: dout <= { 10'sd489   , -10'sd151   }; /* W[ 195] =  0.9551  -0.2949i */
            12'hC42: dout <= { 10'sd489   , -10'sd153   }; /* W[ 198] =  0.9551  -0.2988i */
            12'hC43: dout <= { 10'sd488   , -10'sd155   }; /* W[ 201] =  0.9531  -0.3027i */
            12'hC44: dout <= { 10'sd487   , -10'sd158   }; /* W[ 204] =  0.9512  -0.3086i */
            12'hC45: dout <= { 10'sd486   , -10'sd160   }; /* W[ 207] =  0.9492  -0.3125i */
            12'hC46: dout <= { 10'sd486   , -10'sd162   }; /* W[ 210] =  0.9492  -0.3164i */
            12'hC47: dout <= { 10'sd485   , -10'sd164   }; /* W[ 213] =  0.9473  -0.3203i */
            12'hC48: dout <= { 10'sd484   , -10'sd167   }; /* W[ 216] =  0.9453  -0.3262i */
            12'hC49: dout <= { 10'sd483   , -10'sd169   }; /* W[ 219] =  0.9434  -0.3301i */
            12'hC4A: dout <= { 10'sd483   , -10'sd171   }; /* W[ 222] =  0.9434  -0.3340i */
            12'hC4B: dout <= { 10'sd482   , -10'sd173   }; /* W[ 225] =  0.9414  -0.3379i */
            12'hC4C: dout <= { 10'sd481   , -10'sd175   }; /* W[ 228] =  0.9395  -0.3418i */
            12'hC4D: dout <= { 10'sd480   , -10'sd178   }; /* W[ 231] =  0.9375  -0.3477i */
            12'hC4E: dout <= { 10'sd479   , -10'sd180   }; /* W[ 234] =  0.9355  -0.3516i */
            12'hC4F: dout <= { 10'sd479   , -10'sd182   }; /* W[ 237] =  0.9355  -0.3555i */
            12'hC50: dout <= { 10'sd478   , -10'sd184   }; /* W[ 240] =  0.9336  -0.3594i */
            12'hC51: dout <= { 10'sd477   , -10'sd186   }; /* W[ 243] =  0.9316  -0.3633i */
            12'hC52: dout <= { 10'sd476   , -10'sd189   }; /* W[ 246] =  0.9297  -0.3691i */
            12'hC53: dout <= { 10'sd475   , -10'sd191   }; /* W[ 249] =  0.9277  -0.3730i */
            12'hC54: dout <= { 10'sd474   , -10'sd193   }; /* W[ 252] =  0.9258  -0.3770i */
            12'hC55: dout <= { 10'sd473   , -10'sd195   }; /* W[ 255] =  0.9238  -0.3809i */
            12'hC56: dout <= { 10'sd472   , -10'sd197   }; /* W[ 258] =  0.9219  -0.3848i */
            12'hC57: dout <= { 10'sd472   , -10'sd200   }; /* W[ 261] =  0.9219  -0.3906i */
            12'hC58: dout <= { 10'sd471   , -10'sd202   }; /* W[ 264] =  0.9199  -0.3945i */
            12'hC59: dout <= { 10'sd470   , -10'sd204   }; /* W[ 267] =  0.9180  -0.3984i */
            12'hC5A: dout <= { 10'sd469   , -10'sd206   }; /* W[ 270] =  0.9160  -0.4023i */
            12'hC5B: dout <= { 10'sd468   , -10'sd208   }; /* W[ 273] =  0.9141  -0.4062i */
            12'hC5C: dout <= { 10'sd467   , -10'sd210   }; /* W[ 276] =  0.9121  -0.4102i */
            12'hC5D: dout <= { 10'sd466   , -10'sd212   }; /* W[ 279] =  0.9102  -0.4141i */
            12'hC5E: dout <= { 10'sd465   , -10'sd215   }; /* W[ 282] =  0.9082  -0.4199i */
            12'hC5F: dout <= { 10'sd464   , -10'sd217   }; /* W[ 285] =  0.9062  -0.4238i */
            12'hC60: dout <= { 10'sd463   , -10'sd219   }; /* W[ 288] =  0.9043  -0.4277i */
            12'hC61: dout <= { 10'sd462   , -10'sd221   }; /* W[ 291] =  0.9023  -0.4316i */
            12'hC62: dout <= { 10'sd461   , -10'sd223   }; /* W[ 294] =  0.9004  -0.4355i */
            12'hC63: dout <= { 10'sd460   , -10'sd225   }; /* W[ 297] =  0.8984  -0.4395i */
            12'hC64: dout <= { 10'sd459   , -10'sd227   }; /* W[ 300] =  0.8965  -0.4434i */
            12'hC65: dout <= { 10'sd458   , -10'sd229   }; /* W[ 303] =  0.8945  -0.4473i */
            12'hC66: dout <= { 10'sd457   , -10'sd232   }; /* W[ 306] =  0.8926  -0.4531i */
            12'hC67: dout <= { 10'sd456   , -10'sd234   }; /* W[ 309] =  0.8906  -0.4570i */
            12'hC68: dout <= { 10'sd454   , -10'sd236   }; /* W[ 312] =  0.8867  -0.4609i */
            12'hC69: dout <= { 10'sd453   , -10'sd238   }; /* W[ 315] =  0.8848  -0.4648i */
            12'hC6A: dout <= { 10'sd452   , -10'sd240   }; /* W[ 318] =  0.8828  -0.4688i */
            12'hC6B: dout <= { 10'sd451   , -10'sd242   }; /* W[ 321] =  0.8809  -0.4727i */
            12'hC6C: dout <= { 10'sd450   , -10'sd244   }; /* W[ 324] =  0.8789  -0.4766i */
            12'hC6D: dout <= { 10'sd449   , -10'sd246   }; /* W[ 327] =  0.8770  -0.4805i */
            12'hC6E: dout <= { 10'sd448   , -10'sd248   }; /* W[ 330] =  0.8750  -0.4844i */
            12'hC6F: dout <= { 10'sd447   , -10'sd250   }; /* W[ 333] =  0.8730  -0.4883i */
            12'hC70: dout <= { 10'sd445   , -10'sd252   }; /* W[ 336] =  0.8691  -0.4922i */
            12'hC71: dout <= { 10'sd444   , -10'sd254   }; /* W[ 339] =  0.8672  -0.4961i */
            12'hC72: dout <= { 10'sd443   , -10'sd256   }; /* W[ 342] =  0.8652  -0.5000i */
            12'hC73: dout <= { 10'sd442   , -10'sd258   }; /* W[ 345] =  0.8633  -0.5039i */
            12'hC74: dout <= { 10'sd441   , -10'sd261   }; /* W[ 348] =  0.8613  -0.5098i */
            12'hC75: dout <= { 10'sd440   , -10'sd263   }; /* W[ 351] =  0.8594  -0.5137i */
            12'hC76: dout <= { 10'sd438   , -10'sd265   }; /* W[ 354] =  0.8555  -0.5176i */
            12'hC77: dout <= { 10'sd437   , -10'sd267   }; /* W[ 357] =  0.8535  -0.5215i */
            12'hC78: dout <= { 10'sd436   , -10'sd269   }; /* W[ 360] =  0.8516  -0.5254i */
            12'hC79: dout <= { 10'sd435   , -10'sd271   }; /* W[ 363] =  0.8496  -0.5293i */
            12'hC7A: dout <= { 10'sd433   , -10'sd273   }; /* W[ 366] =  0.8457  -0.5332i */
            12'hC7B: dout <= { 10'sd432   , -10'sd275   }; /* W[ 369] =  0.8438  -0.5371i */
            12'hC7C: dout <= { 10'sd431   , -10'sd277   }; /* W[ 372] =  0.8418  -0.5410i */
            12'hC7D: dout <= { 10'sd430   , -10'sd279   }; /* W[ 375] =  0.8398  -0.5449i */
            12'hC7E: dout <= { 10'sd428   , -10'sd281   }; /* W[ 378] =  0.8359  -0.5488i */
            12'hC7F: dout <= { 10'sd427   , -10'sd282   }; /* W[ 381] =  0.8340  -0.5508i */
            12'hC80: dout <= { 10'sd426   , -10'sd284   }; /* W[ 384] =  0.8320  -0.5547i */
            12'hC81: dout <= { 10'sd424   , -10'sd286   }; /* W[ 387] =  0.8281  -0.5586i */
            12'hC82: dout <= { 10'sd423   , -10'sd288   }; /* W[ 390] =  0.8262  -0.5625i */
            12'hC83: dout <= { 10'sd422   , -10'sd290   }; /* W[ 393] =  0.8242  -0.5664i */
            12'hC84: dout <= { 10'sd420   , -10'sd292   }; /* W[ 396] =  0.8203  -0.5703i */
            12'hC85: dout <= { 10'sd419   , -10'sd294   }; /* W[ 399] =  0.8184  -0.5742i */
            12'hC86: dout <= { 10'sd418   , -10'sd296   }; /* W[ 402] =  0.8164  -0.5781i */
            12'hC87: dout <= { 10'sd416   , -10'sd298   }; /* W[ 405] =  0.8125  -0.5820i */
            12'hC88: dout <= { 10'sd415   , -10'sd300   }; /* W[ 408] =  0.8105  -0.5859i */
            12'hC89: dout <= { 10'sd414   , -10'sd302   }; /* W[ 411] =  0.8086  -0.5898i */
            12'hC8A: dout <= { 10'sd412   , -10'sd304   }; /* W[ 414] =  0.8047  -0.5938i */
            12'hC8B: dout <= { 10'sd411   , -10'sd306   }; /* W[ 417] =  0.8027  -0.5977i */
            12'hC8C: dout <= { 10'sd409   , -10'sd308   }; /* W[ 420] =  0.7988  -0.6016i */
            12'hC8D: dout <= { 10'sd408   , -10'sd309   }; /* W[ 423] =  0.7969  -0.6035i */
            12'hC8E: dout <= { 10'sd407   , -10'sd311   }; /* W[ 426] =  0.7949  -0.6074i */
            12'hC8F: dout <= { 10'sd405   , -10'sd313   }; /* W[ 429] =  0.7910  -0.6113i */
            12'hC90: dout <= { 10'sd404   , -10'sd315   }; /* W[ 432] =  0.7891  -0.6152i */
            12'hC91: dout <= { 10'sd402   , -10'sd317   }; /* W[ 435] =  0.7852  -0.6191i */
            12'hC92: dout <= { 10'sd401   , -10'sd319   }; /* W[ 438] =  0.7832  -0.6230i */
            12'hC93: dout <= { 10'sd399   , -10'sd321   }; /* W[ 441] =  0.7793  -0.6270i */
            12'hC94: dout <= { 10'sd398   , -10'sd322   }; /* W[ 444] =  0.7773  -0.6289i */
            12'hC95: dout <= { 10'sd396   , -10'sd324   }; /* W[ 447] =  0.7734  -0.6328i */
            12'hC96: dout <= { 10'sd395   , -10'sd326   }; /* W[ 450] =  0.7715  -0.6367i */
            12'hC97: dout <= { 10'sd393   , -10'sd328   }; /* W[ 453] =  0.7676  -0.6406i */
            12'hC98: dout <= { 10'sd392   , -10'sd330   }; /* W[ 456] =  0.7656  -0.6445i */
            12'hC99: dout <= { 10'sd390   , -10'sd331   }; /* W[ 459] =  0.7617  -0.6465i */
            12'hC9A: dout <= { 10'sd389   , -10'sd333   }; /* W[ 462] =  0.7598  -0.6504i */
            12'hC9B: dout <= { 10'sd387   , -10'sd335   }; /* W[ 465] =  0.7559  -0.6543i */
            12'hC9C: dout <= { 10'sd386   , -10'sd337   }; /* W[ 468] =  0.7539  -0.6582i */
            12'hC9D: dout <= { 10'sd384   , -10'sd339   }; /* W[ 471] =  0.7500  -0.6621i */
            12'hC9E: dout <= { 10'sd383   , -10'sd340   }; /* W[ 474] =  0.7480  -0.6641i */
            12'hC9F: dout <= { 10'sd381   , -10'sd342   }; /* W[ 477] =  0.7441  -0.6680i */
            12'hCA0: dout <= { 10'sd379   , -10'sd344   }; /* W[ 480] =  0.7402  -0.6719i */
            12'hCA1: dout <= { 10'sd378   , -10'sd346   }; /* W[ 483] =  0.7383  -0.6758i */
            12'hCA2: dout <= { 10'sd376   , -10'sd347   }; /* W[ 486] =  0.7344  -0.6777i */
            12'hCA3: dout <= { 10'sd375   , -10'sd349   }; /* W[ 489] =  0.7324  -0.6816i */
            12'hCA4: dout <= { 10'sd373   , -10'sd351   }; /* W[ 492] =  0.7285  -0.6855i */
            12'hCA5: dout <= { 10'sd371   , -10'sd352   }; /* W[ 495] =  0.7246  -0.6875i */
            12'hCA6: dout <= { 10'sd370   , -10'sd354   }; /* W[ 498] =  0.7227  -0.6914i */
            12'hCA7: dout <= { 10'sd368   , -10'sd356   }; /* W[ 501] =  0.7188  -0.6953i */
            12'hCA8: dout <= { 10'sd366   , -10'sd358   }; /* W[ 504] =  0.7148  -0.6992i */
            12'hCA9: dout <= { 10'sd365   , -10'sd359   }; /* W[ 507] =  0.7129  -0.7012i */
            12'hCAA: dout <= { 10'sd363   , -10'sd361   }; /* W[ 510] =  0.7090  -0.7051i */
            12'hCAB: dout <= { 10'sd361   , -10'sd363   }; /* W[ 513] =  0.7051  -0.7090i */
            12'hCAC: dout <= { 10'sd360   , -10'sd364   }; /* W[ 516] =  0.7031  -0.7109i */
            12'hCAD: dout <= { 10'sd358   , -10'sd366   }; /* W[ 519] =  0.6992  -0.7148i */
            12'hCAE: dout <= { 10'sd356   , -10'sd368   }; /* W[ 522] =  0.6953  -0.7188i */
            12'hCAF: dout <= { 10'sd355   , -10'sd369   }; /* W[ 525] =  0.6934  -0.7207i */
            12'hCB0: dout <= { 10'sd353   , -10'sd371   }; /* W[ 528] =  0.6895  -0.7246i */
            12'hCB1: dout <= { 10'sd351   , -10'sd372   }; /* W[ 531] =  0.6855  -0.7266i */
            12'hCB2: dout <= { 10'sd350   , -10'sd374   }; /* W[ 534] =  0.6836  -0.7305i */
            12'hCB3: dout <= { 10'sd348   , -10'sd376   }; /* W[ 537] =  0.6797  -0.7344i */
            12'hCB4: dout <= { 10'sd346   , -10'sd377   }; /* W[ 540] =  0.6758  -0.7363i */
            12'hCB5: dout <= { 10'sd344   , -10'sd379   }; /* W[ 543] =  0.6719  -0.7402i */
            12'hCB6: dout <= { 10'sd343   , -10'sd380   }; /* W[ 546] =  0.6699  -0.7422i */
            12'hCB7: dout <= { 10'sd341   , -10'sd382   }; /* W[ 549] =  0.6660  -0.7461i */
            12'hCB8: dout <= { 10'sd339   , -10'sd384   }; /* W[ 552] =  0.6621  -0.7500i */
            12'hCB9: dout <= { 10'sd337   , -10'sd385   }; /* W[ 555] =  0.6582  -0.7520i */
            12'hCBA: dout <= { 10'sd336   , -10'sd387   }; /* W[ 558] =  0.6562  -0.7559i */
            12'hCBB: dout <= { 10'sd334   , -10'sd388   }; /* W[ 561] =  0.6523  -0.7578i */
            12'hCBC: dout <= { 10'sd332   , -10'sd390   }; /* W[ 564] =  0.6484  -0.7617i */
            12'hCBD: dout <= { 10'sd330   , -10'sd391   }; /* W[ 567] =  0.6445  -0.7637i */
            12'hCBE: dout <= { 10'sd328   , -10'sd393   }; /* W[ 570] =  0.6406  -0.7676i */
            12'hCBF: dout <= { 10'sd327   , -10'sd394   }; /* W[ 573] =  0.6387  -0.7695i */
            12'hCC0: dout <= { 10'sd325   , -10'sd396   }; /* W[ 576] =  0.6348  -0.7734i */
            12'hCC1: dout <= { 10'sd323   , -10'sd397   }; /* W[ 579] =  0.6309  -0.7754i */
            12'hCC2: dout <= { 10'sd321   , -10'sd399   }; /* W[ 582] =  0.6270  -0.7793i */
            12'hCC3: dout <= { 10'sd319   , -10'sd400   }; /* W[ 585] =  0.6230  -0.7812i */
            12'hCC4: dout <= { 10'sd317   , -10'sd402   }; /* W[ 588] =  0.6191  -0.7852i */
            12'hCC5: dout <= { 10'sd316   , -10'sd403   }; /* W[ 591] =  0.6172  -0.7871i */
            12'hCC6: dout <= { 10'sd314   , -10'sd405   }; /* W[ 594] =  0.6133  -0.7910i */
            12'hCC7: dout <= { 10'sd312   , -10'sd406   }; /* W[ 597] =  0.6094  -0.7930i */
            12'hCC8: dout <= { 10'sd310   , -10'sd407   }; /* W[ 600] =  0.6055  -0.7949i */
            12'hCC9: dout <= { 10'sd308   , -10'sd409   }; /* W[ 603] =  0.6016  -0.7988i */
            12'hCCA: dout <= { 10'sd306   , -10'sd410   }; /* W[ 606] =  0.5977  -0.8008i */
            12'hCCB: dout <= { 10'sd304   , -10'sd412   }; /* W[ 609] =  0.5938  -0.8047i */
            12'hCCC: dout <= { 10'sd302   , -10'sd413   }; /* W[ 612] =  0.5898  -0.8066i */
            12'hCCD: dout <= { 10'sd301   , -10'sd414   }; /* W[ 615] =  0.5879  -0.8086i */
            12'hCCE: dout <= { 10'sd299   , -10'sd416   }; /* W[ 618] =  0.5840  -0.8125i */
            12'hCCF: dout <= { 10'sd297   , -10'sd417   }; /* W[ 621] =  0.5801  -0.8145i */
            12'hCD0: dout <= { 10'sd295   , -10'sd419   }; /* W[ 624] =  0.5762  -0.8184i */
            12'hCD1: dout <= { 10'sd293   , -10'sd420   }; /* W[ 627] =  0.5723  -0.8203i */
            12'hCD2: dout <= { 10'sd291   , -10'sd421   }; /* W[ 630] =  0.5684  -0.8223i */
            12'hCD3: dout <= { 10'sd289   , -10'sd423   }; /* W[ 633] =  0.5645  -0.8262i */
            12'hCD4: dout <= { 10'sd287   , -10'sd424   }; /* W[ 636] =  0.5605  -0.8281i */
            12'hCD5: dout <= { 10'sd285   , -10'sd425   }; /* W[ 639] =  0.5566  -0.8301i */
            12'hCD6: dout <= { 10'sd283   , -10'sd427   }; /* W[ 642] =  0.5527  -0.8340i */
            12'hCD7: dout <= { 10'sd281   , -10'sd428   }; /* W[ 645] =  0.5488  -0.8359i */
            12'hCD8: dout <= { 10'sd279   , -10'sd429   }; /* W[ 648] =  0.5449  -0.8379i */
            12'hCD9: dout <= { 10'sd277   , -10'sd430   }; /* W[ 651] =  0.5410  -0.8398i */
            12'hCDA: dout <= { 10'sd275   , -10'sd432   }; /* W[ 654] =  0.5371  -0.8438i */
            12'hCDB: dout <= { 10'sd273   , -10'sd433   }; /* W[ 657] =  0.5332  -0.8457i */
            12'hCDC: dout <= { 10'sd271   , -10'sd434   }; /* W[ 660] =  0.5293  -0.8477i */
            12'hCDD: dout <= { 10'sd269   , -10'sd435   }; /* W[ 663] =  0.5254  -0.8496i */
            12'hCDE: dout <= { 10'sd267   , -10'sd437   }; /* W[ 666] =  0.5215  -0.8535i */
            12'hCDF: dout <= { 10'sd265   , -10'sd438   }; /* W[ 669] =  0.5176  -0.8555i */
            12'hCE0: dout <= { 10'sd263   , -10'sd439   }; /* W[ 672] =  0.5137  -0.8574i */
            12'hCE1: dout <= { 10'sd261   , -10'sd440   }; /* W[ 675] =  0.5098  -0.8594i */
            12'hCE2: dout <= { 10'sd259   , -10'sd442   }; /* W[ 678] =  0.5059  -0.8633i */
            12'hCE3: dout <= { 10'sd257   , -10'sd443   }; /* W[ 681] =  0.5020  -0.8652i */
            12'hCE4: dout <= { 10'sd255   , -10'sd444   }; /* W[ 684] =  0.4980  -0.8672i */
            12'hCE5: dout <= { 10'sd253   , -10'sd445   }; /* W[ 687] =  0.4941  -0.8691i */
            12'hCE6: dout <= { 10'sd251   , -10'sd446   }; /* W[ 690] =  0.4902  -0.8711i */
            12'hCE7: dout <= { 10'sd249   , -10'sd447   }; /* W[ 693] =  0.4863  -0.8730i */
            12'hCE8: dout <= { 10'sd247   , -10'sd449   }; /* W[ 696] =  0.4824  -0.8770i */
            12'hCE9: dout <= { 10'sd245   , -10'sd450   }; /* W[ 699] =  0.4785  -0.8789i */
            12'hCEA: dout <= { 10'sd243   , -10'sd451   }; /* W[ 702] =  0.4746  -0.8809i */
            12'hCEB: dout <= { 10'sd241   , -10'sd452   }; /* W[ 705] =  0.4707  -0.8828i */
            12'hCEC: dout <= { 10'sd239   , -10'sd453   }; /* W[ 708] =  0.4668  -0.8848i */
            12'hCED: dout <= { 10'sd236   , -10'sd454   }; /* W[ 711] =  0.4609  -0.8867i */
            12'hCEE: dout <= { 10'sd234   , -10'sd455   }; /* W[ 714] =  0.4570  -0.8887i */
            12'hCEF: dout <= { 10'sd232   , -10'sd456   }; /* W[ 717] =  0.4531  -0.8906i */
            12'hCF0: dout <= { 10'sd230   , -10'sd457   }; /* W[ 720] =  0.4492  -0.8926i */
            12'hCF1: dout <= { 10'sd228   , -10'sd458   }; /* W[ 723] =  0.4453  -0.8945i */
            12'hCF2: dout <= { 10'sd226   , -10'sd459   }; /* W[ 726] =  0.4414  -0.8965i */
            12'hCF3: dout <= { 10'sd224   , -10'sd460   }; /* W[ 729] =  0.4375  -0.8984i */
            12'hCF4: dout <= { 10'sd222   , -10'sd461   }; /* W[ 732] =  0.4336  -0.9004i */
            12'hCF5: dout <= { 10'sd220   , -10'sd463   }; /* W[ 735] =  0.4297  -0.9043i */
            12'hCF6: dout <= { 10'sd217   , -10'sd464   }; /* W[ 738] =  0.4238  -0.9062i */
            12'hCF7: dout <= { 10'sd215   , -10'sd465   }; /* W[ 741] =  0.4199  -0.9082i */
            12'hCF8: dout <= { 10'sd213   , -10'sd465   }; /* W[ 744] =  0.4160  -0.9082i */
            12'hCF9: dout <= { 10'sd211   , -10'sd466   }; /* W[ 747] =  0.4121  -0.9102i */
            12'hCFA: dout <= { 10'sd209   , -10'sd467   }; /* W[ 750] =  0.4082  -0.9121i */
            12'hCFB: dout <= { 10'sd207   , -10'sd468   }; /* W[ 753] =  0.4043  -0.9141i */
            12'hCFC: dout <= { 10'sd205   , -10'sd469   }; /* W[ 756] =  0.4004  -0.9160i */
            12'hCFD: dout <= { 10'sd202   , -10'sd470   }; /* W[ 759] =  0.3945  -0.9180i */
            12'hCFE: dout <= { 10'sd200   , -10'sd471   }; /* W[ 762] =  0.3906  -0.9199i */
            12'hCFF: dout <= { 10'sd198   , -10'sd472   }; /* W[ 765] =  0.3867  -0.9219i */
            12'hD00: dout <= { 10'sd196   , -10'sd473   }; /* W[ 768] =  0.3828  -0.9238i */
            12'hD01: dout <= { 10'sd194   , -10'sd474   }; /* W[ 771] =  0.3789  -0.9258i */
            12'hD02: dout <= { 10'sd192   , -10'sd475   }; /* W[ 774] =  0.3750  -0.9277i */
            12'hD03: dout <= { 10'sd189   , -10'sd476   }; /* W[ 777] =  0.3691  -0.9297i */
            12'hD04: dout <= { 10'sd187   , -10'sd477   }; /* W[ 780] =  0.3652  -0.9316i */
            12'hD05: dout <= { 10'sd185   , -10'sd477   }; /* W[ 783] =  0.3613  -0.9316i */
            12'hD06: dout <= { 10'sd183   , -10'sd478   }; /* W[ 786] =  0.3574  -0.9336i */
            12'hD07: dout <= { 10'sd181   , -10'sd479   }; /* W[ 789] =  0.3535  -0.9355i */
            12'hD08: dout <= { 10'sd178   , -10'sd480   }; /* W[ 792] =  0.3477  -0.9375i */
            12'hD09: dout <= { 10'sd176   , -10'sd481   }; /* W[ 795] =  0.3438  -0.9395i */
            12'hD0A: dout <= { 10'sd174   , -10'sd482   }; /* W[ 798] =  0.3398  -0.9414i */
            12'hD0B: dout <= { 10'sd172   , -10'sd482   }; /* W[ 801] =  0.3359  -0.9414i */
            12'hD0C: dout <= { 10'sd170   , -10'sd483   }; /* W[ 804] =  0.3320  -0.9434i */
            12'hD0D: dout <= { 10'sd167   , -10'sd484   }; /* W[ 807] =  0.3262  -0.9453i */
            12'hD0E: dout <= { 10'sd165   , -10'sd485   }; /* W[ 810] =  0.3223  -0.9473i */
            12'hD0F: dout <= { 10'sd163   , -10'sd485   }; /* W[ 813] =  0.3184  -0.9473i */
            12'hD10: dout <= { 10'sd161   , -10'sd486   }; /* W[ 816] =  0.3145  -0.9492i */
            12'hD11: dout <= { 10'sd158   , -10'sd487   }; /* W[ 819] =  0.3086  -0.9512i */
            12'hD12: dout <= { 10'sd156   , -10'sd488   }; /* W[ 822] =  0.3047  -0.9531i */
            12'hD13: dout <= { 10'sd154   , -10'sd488   }; /* W[ 825] =  0.3008  -0.9531i */
            12'hD14: dout <= { 10'sd152   , -10'sd489   }; /* W[ 828] =  0.2969  -0.9551i */
            12'hD15: dout <= { 10'sd149   , -10'sd490   }; /* W[ 831] =  0.2910  -0.9570i */
            12'hD16: dout <= { 10'sd147   , -10'sd490   }; /* W[ 834] =  0.2871  -0.9570i */
            12'hD17: dout <= { 10'sd145   , -10'sd491   }; /* W[ 837] =  0.2832  -0.9590i */
            12'hD18: dout <= { 10'sd143   , -10'sd492   }; /* W[ 840] =  0.2793  -0.9609i */
            12'hD19: dout <= { 10'sd140   , -10'sd492   }; /* W[ 843] =  0.2734  -0.9609i */
            12'hD1A: dout <= { 10'sd138   , -10'sd493   }; /* W[ 846] =  0.2695  -0.9629i */
            12'hD1B: dout <= { 10'sd136   , -10'sd494   }; /* W[ 849] =  0.2656  -0.9648i */
            12'hD1C: dout <= { 10'sd134   , -10'sd494   }; /* W[ 852] =  0.2617  -0.9648i */
            12'hD1D: dout <= { 10'sd131   , -10'sd495   }; /* W[ 855] =  0.2559  -0.9668i */
            12'hD1E: dout <= { 10'sd129   , -10'sd495   }; /* W[ 858] =  0.2520  -0.9668i */
            12'hD1F: dout <= { 10'sd127   , -10'sd496   }; /* W[ 861] =  0.2480  -0.9688i */
            12'hD20: dout <= { 10'sd124   , -10'sd497   }; /* W[ 864] =  0.2422  -0.9707i */
            12'hD21: dout <= { 10'sd122   , -10'sd497   }; /* W[ 867] =  0.2383  -0.9707i */
            12'hD22: dout <= { 10'sd120   , -10'sd498   }; /* W[ 870] =  0.2344  -0.9727i */
            12'hD23: dout <= { 10'sd118   , -10'sd498   }; /* W[ 873] =  0.2305  -0.9727i */
            12'hD24: dout <= { 10'sd115   , -10'sd499   }; /* W[ 876] =  0.2246  -0.9746i */
            12'hD25: dout <= { 10'sd113   , -10'sd499   }; /* W[ 879] =  0.2207  -0.9746i */
            12'hD26: dout <= { 10'sd111   , -10'sd500   }; /* W[ 882] =  0.2168  -0.9766i */
            12'hD27: dout <= { 10'sd108   , -10'sd500   }; /* W[ 885] =  0.2109  -0.9766i */
            12'hD28: dout <= { 10'sd106   , -10'sd501   }; /* W[ 888] =  0.2070  -0.9785i */
            12'hD29: dout <= { 10'sd104   , -10'sd501   }; /* W[ 891] =  0.2031  -0.9785i */
            12'hD2A: dout <= { 10'sd101   , -10'sd502   }; /* W[ 894] =  0.1973  -0.9805i */
            12'hD2B: dout <= { 10'sd99    , -10'sd502   }; /* W[ 897] =  0.1934  -0.9805i */
            12'hD2C: dout <= { 10'sd97    , -10'sd503   }; /* W[ 900] =  0.1895  -0.9824i */
            12'hD2D: dout <= { 10'sd94    , -10'sd503   }; /* W[ 903] =  0.1836  -0.9824i */
            12'hD2E: dout <= { 10'sd92    , -10'sd504   }; /* W[ 906] =  0.1797  -0.9844i */
            12'hD2F: dout <= { 10'sd90    , -10'sd504   }; /* W[ 909] =  0.1758  -0.9844i */
            12'hD30: dout <= { 10'sd88    , -10'sd504   }; /* W[ 912] =  0.1719  -0.9844i */
            12'hD31: dout <= { 10'sd85    , -10'sd505   }; /* W[ 915] =  0.1660  -0.9863i */
            12'hD32: dout <= { 10'sd83    , -10'sd505   }; /* W[ 918] =  0.1621  -0.9863i */
            12'hD33: dout <= { 10'sd81    , -10'sd506   }; /* W[ 921] =  0.1582  -0.9883i */
            12'hD34: dout <= { 10'sd78    , -10'sd506   }; /* W[ 924] =  0.1523  -0.9883i */
            12'hD35: dout <= { 10'sd76    , -10'sd506   }; /* W[ 927] =  0.1484  -0.9883i */
            12'hD36: dout <= { 10'sd74    , -10'sd507   }; /* W[ 930] =  0.1445  -0.9902i */
            12'hD37: dout <= { 10'sd71    , -10'sd507   }; /* W[ 933] =  0.1387  -0.9902i */
            12'hD38: dout <= { 10'sd69    , -10'sd507   }; /* W[ 936] =  0.1348  -0.9902i */
            12'hD39: dout <= { 10'sd67    , -10'sd508   }; /* W[ 939] =  0.1309  -0.9922i */
            12'hD3A: dout <= { 10'sd64    , -10'sd508   }; /* W[ 942] =  0.1250  -0.9922i */
            12'hD3B: dout <= { 10'sd62    , -10'sd508   }; /* W[ 945] =  0.1211  -0.9922i */
            12'hD3C: dout <= { 10'sd60    , -10'sd509   }; /* W[ 948] =  0.1172  -0.9941i */
            12'hD3D: dout <= { 10'sd57    , -10'sd509   }; /* W[ 951] =  0.1113  -0.9941i */
            12'hD3E: dout <= { 10'sd55    , -10'sd509   }; /* W[ 954] =  0.1074  -0.9941i */
            12'hD3F: dout <= { 10'sd53    , -10'sd509   }; /* W[ 957] =  0.1035  -0.9941i */
            12'hD40: dout <= { 10'sd50    , -10'sd510   }; /* W[ 960] =  0.0977  -0.9961i */
            12'hD41: dout <= { 10'sd48    , -10'sd510   }; /* W[ 963] =  0.0938  -0.9961i */
            12'hD42: dout <= { 10'sd45    , -10'sd510   }; /* W[ 966] =  0.0879  -0.9961i */
            12'hD43: dout <= { 10'sd43    , -10'sd510   }; /* W[ 969] =  0.0840  -0.9961i */
            12'hD44: dout <= { 10'sd41    , -10'sd510   }; /* W[ 972] =  0.0801  -0.9961i */
            12'hD45: dout <= { 10'sd38    , -10'sd511   }; /* W[ 975] =  0.0742  -0.9980i */
            12'hD46: dout <= { 10'sd36    , -10'sd511   }; /* W[ 978] =  0.0703  -0.9980i */
            12'hD47: dout <= { 10'sd34    , -10'sd511   }; /* W[ 981] =  0.0664  -0.9980i */
            12'hD48: dout <= { 10'sd31    , -10'sd511   }; /* W[ 984] =  0.0605  -0.9980i */
            12'hD49: dout <= { 10'sd29    , -10'sd511   }; /* W[ 987] =  0.0566  -0.9980i */
            12'hD4A: dout <= { 10'sd27    , -10'sd511   }; /* W[ 990] =  0.0527  -0.9980i */
            12'hD4B: dout <= { 10'sd24    , -10'sd511   }; /* W[ 993] =  0.0469  -0.9980i */
            12'hD4C: dout <= { 10'sd22    , -10'sd512   }; /* W[ 996] =  0.0430  -1.0000i */
            12'hD4D: dout <= { 10'sd20    , -10'sd512   }; /* W[ 999] =  0.0391  -1.0000i */
            12'hD4E: dout <= { 10'sd17    , -10'sd512   }; /* W[1002] =  0.0332  -1.0000i */
            12'hD4F: dout <= { 10'sd15    , -10'sd512   }; /* W[1005] =  0.0293  -1.0000i */
            12'hD50: dout <= { 10'sd13    , -10'sd512   }; /* W[1008] =  0.0254  -1.0000i */
            12'hD51: dout <= { 10'sd10    , -10'sd512   }; /* W[1011] =  0.0195  -1.0000i */
            12'hD52: dout <= { 10'sd8     , -10'sd512   }; /* W[1014] =  0.0156  -1.0000i */
            12'hD53: dout <= { 10'sd5     , -10'sd512   }; /* W[1017] =  0.0098  -1.0000i */
            12'hD54: dout <= { 10'sd3     , -10'sd512   }; /* W[1020] =  0.0059  -1.0000i */
            12'hD55: dout <= { 10'sd1     , -10'sd512   }; /* W[1023] =  0.0020  -1.0000i */
            12'hD56: dout <= {-10'sd2     , -10'sd512   }; /* W[1026] = -0.0039  -1.0000i */
            12'hD57: dout <= {-10'sd4     , -10'sd512   }; /* W[1029] = -0.0078  -1.0000i */
            12'hD58: dout <= {-10'sd6     , -10'sd512   }; /* W[1032] = -0.0117  -1.0000i */
            12'hD59: dout <= {-10'sd9     , -10'sd512   }; /* W[1035] = -0.0176  -1.0000i */
            12'hD5A: dout <= {-10'sd11    , -10'sd512   }; /* W[1038] = -0.0215  -1.0000i */
            12'hD5B: dout <= {-10'sd13    , -10'sd512   }; /* W[1041] = -0.0254  -1.0000i */
            12'hD5C: dout <= {-10'sd16    , -10'sd512   }; /* W[1044] = -0.0312  -1.0000i */
            12'hD5D: dout <= {-10'sd18    , -10'sd512   }; /* W[1047] = -0.0352  -1.0000i */
            12'hD5E: dout <= {-10'sd20    , -10'sd512   }; /* W[1050] = -0.0391  -1.0000i */
            12'hD5F: dout <= {-10'sd23    , -10'sd511   }; /* W[1053] = -0.0449  -0.9980i */
            12'hD60: dout <= {-10'sd25    , -10'sd511   }; /* W[1056] = -0.0488  -0.9980i */
            12'hD61: dout <= {-10'sd27    , -10'sd511   }; /* W[1059] = -0.0527  -0.9980i */
            12'hD62: dout <= {-10'sd30    , -10'sd511   }; /* W[1062] = -0.0586  -0.9980i */
            12'hD63: dout <= {-10'sd32    , -10'sd511   }; /* W[1065] = -0.0625  -0.9980i */
            12'hD64: dout <= {-10'sd35    , -10'sd511   }; /* W[1068] = -0.0684  -0.9980i */
            12'hD65: dout <= {-10'sd37    , -10'sd511   }; /* W[1071] = -0.0723  -0.9980i */
            12'hD66: dout <= {-10'sd39    , -10'sd510   }; /* W[1074] = -0.0762  -0.9961i */
            12'hD67: dout <= {-10'sd42    , -10'sd510   }; /* W[1077] = -0.0820  -0.9961i */
            12'hD68: dout <= {-10'sd44    , -10'sd510   }; /* W[1080] = -0.0859  -0.9961i */
            12'hD69: dout <= {-10'sd46    , -10'sd510   }; /* W[1083] = -0.0898  -0.9961i */
            12'hD6A: dout <= {-10'sd49    , -10'sd510   }; /* W[1086] = -0.0957  -0.9961i */
            12'hD6B: dout <= {-10'sd51    , -10'sd509   }; /* W[1089] = -0.0996  -0.9941i */
            12'hD6C: dout <= {-10'sd53    , -10'sd509   }; /* W[1092] = -0.1035  -0.9941i */
            12'hD6D: dout <= {-10'sd56    , -10'sd509   }; /* W[1095] = -0.1094  -0.9941i */
            12'hD6E: dout <= {-10'sd58    , -10'sd509   }; /* W[1098] = -0.1133  -0.9941i */
            12'hD6F: dout <= {-10'sd60    , -10'sd508   }; /* W[1101] = -0.1172  -0.9922i */
            12'hD70: dout <= {-10'sd63    , -10'sd508   }; /* W[1104] = -0.1230  -0.9922i */
            12'hD71: dout <= {-10'sd65    , -10'sd508   }; /* W[1107] = -0.1270  -0.9922i */
            12'hD72: dout <= {-10'sd67    , -10'sd508   }; /* W[1110] = -0.1309  -0.9922i */
            12'hD73: dout <= {-10'sd70    , -10'sd507   }; /* W[1113] = -0.1367  -0.9902i */
            12'hD74: dout <= {-10'sd72    , -10'sd507   }; /* W[1116] = -0.1406  -0.9902i */
            12'hD75: dout <= {-10'sd74    , -10'sd507   }; /* W[1119] = -0.1445  -0.9902i */
            12'hD76: dout <= {-10'sd77    , -10'sd506   }; /* W[1122] = -0.1504  -0.9883i */
            12'hD77: dout <= {-10'sd79    , -10'sd506   }; /* W[1125] = -0.1543  -0.9883i */
            12'hD78: dout <= {-10'sd81    , -10'sd505   }; /* W[1128] = -0.1582  -0.9863i */
            12'hD79: dout <= {-10'sd84    , -10'sd505   }; /* W[1131] = -0.1641  -0.9863i */
            12'hD7A: dout <= {-10'sd86    , -10'sd505   }; /* W[1134] = -0.1680  -0.9863i */
            12'hD7B: dout <= {-10'sd88    , -10'sd504   }; /* W[1137] = -0.1719  -0.9844i */
            12'hD7C: dout <= {-10'sd91    , -10'sd504   }; /* W[1140] = -0.1777  -0.9844i */
            12'hD7D: dout <= {-10'sd93    , -10'sd503   }; /* W[1143] = -0.1816  -0.9824i */
            12'hD7E: dout <= {-10'sd95    , -10'sd503   }; /* W[1146] = -0.1855  -0.9824i */
            12'hD7F: dout <= {-10'sd98    , -10'sd503   }; /* W[1149] = -0.1914  -0.9824i */
            12'hD80: dout <= {-10'sd100   , -10'sd502   }; /* W[1152] = -0.1953  -0.9805i */
            12'hD81: dout <= {-10'sd102   , -10'sd502   }; /* W[1155] = -0.1992  -0.9805i */
            12'hD82: dout <= {-10'sd105   , -10'sd501   }; /* W[1158] = -0.2051  -0.9785i */
            12'hD83: dout <= {-10'sd107   , -10'sd501   }; /* W[1161] = -0.2090  -0.9785i */
            12'hD84: dout <= {-10'sd109   , -10'sd500   }; /* W[1164] = -0.2129  -0.9766i */
            12'hD85: dout <= {-10'sd111   , -10'sd500   }; /* W[1167] = -0.2168  -0.9766i */
            12'hD86: dout <= {-10'sd114   , -10'sd499   }; /* W[1170] = -0.2227  -0.9746i */
            12'hD87: dout <= {-10'sd116   , -10'sd499   }; /* W[1173] = -0.2266  -0.9746i */
            12'hD88: dout <= {-10'sd118   , -10'sd498   }; /* W[1176] = -0.2305  -0.9727i */
            12'hD89: dout <= {-10'sd121   , -10'sd498   }; /* W[1179] = -0.2363  -0.9727i */
            12'hD8A: dout <= {-10'sd123   , -10'sd497   }; /* W[1182] = -0.2402  -0.9707i */
            12'hD8B: dout <= {-10'sd125   , -10'sd496   }; /* W[1185] = -0.2441  -0.9688i */
            12'hD8C: dout <= {-10'sd127   , -10'sd496   }; /* W[1188] = -0.2480  -0.9688i */
            12'hD8D: dout <= {-10'sd130   , -10'sd495   }; /* W[1191] = -0.2539  -0.9668i */
            12'hD8E: dout <= {-10'sd132   , -10'sd495   }; /* W[1194] = -0.2578  -0.9668i */
            12'hD8F: dout <= {-10'sd134   , -10'sd494   }; /* W[1197] = -0.2617  -0.9648i */
            12'hD90: dout <= {-10'sd137   , -10'sd493   }; /* W[1200] = -0.2676  -0.9629i */
            12'hD91: dout <= {-10'sd139   , -10'sd493   }; /* W[1203] = -0.2715  -0.9629i */
            12'hD92: dout <= {-10'sd141   , -10'sd492   }; /* W[1206] = -0.2754  -0.9609i */
            12'hD93: dout <= {-10'sd143   , -10'sd492   }; /* W[1209] = -0.2793  -0.9609i */
            12'hD94: dout <= {-10'sd146   , -10'sd491   }; /* W[1212] = -0.2852  -0.9590i */
            12'hD95: dout <= {-10'sd148   , -10'sd490   }; /* W[1215] = -0.2891  -0.9570i */
            12'hD96: dout <= {-10'sd150   , -10'sd489   }; /* W[1218] = -0.2930  -0.9551i */
            12'hD97: dout <= {-10'sd152   , -10'sd489   }; /* W[1221] = -0.2969  -0.9551i */
            12'hD98: dout <= {-10'sd155   , -10'sd488   }; /* W[1224] = -0.3027  -0.9531i */
            12'hD99: dout <= {-10'sd157   , -10'sd487   }; /* W[1227] = -0.3066  -0.9512i */
            12'hD9A: dout <= {-10'sd159   , -10'sd487   }; /* W[1230] = -0.3105  -0.9512i */
            12'hD9B: dout <= {-10'sd161   , -10'sd486   }; /* W[1233] = -0.3145  -0.9492i */
            12'hD9C: dout <= {-10'sd164   , -10'sd485   }; /* W[1236] = -0.3203  -0.9473i */
            12'hD9D: dout <= {-10'sd166   , -10'sd484   }; /* W[1239] = -0.3242  -0.9453i */
            12'hD9E: dout <= {-10'sd168   , -10'sd484   }; /* W[1242] = -0.3281  -0.9453i */
            12'hD9F: dout <= {-10'sd170   , -10'sd483   }; /* W[1245] = -0.3320  -0.9434i */
            12'hDA0: dout <= {-10'sd172   , -10'sd482   }; /* W[1248] = -0.3359  -0.9414i */
            12'hDA1: dout <= {-10'sd175   , -10'sd481   }; /* W[1251] = -0.3418  -0.9395i */
            12'hDA2: dout <= {-10'sd177   , -10'sd480   }; /* W[1254] = -0.3457  -0.9375i */
            12'hDA3: dout <= {-10'sd179   , -10'sd480   }; /* W[1257] = -0.3496  -0.9375i */
            12'hDA4: dout <= {-10'sd181   , -10'sd479   }; /* W[1260] = -0.3535  -0.9355i */
            12'hDA5: dout <= {-10'sd184   , -10'sd478   }; /* W[1263] = -0.3594  -0.9336i */
            12'hDA6: dout <= {-10'sd186   , -10'sd477   }; /* W[1266] = -0.3633  -0.9316i */
            12'hDA7: dout <= {-10'sd188   , -10'sd476   }; /* W[1269] = -0.3672  -0.9297i */
            12'hDA8: dout <= {-10'sd190   , -10'sd475   }; /* W[1272] = -0.3711  -0.9277i */
            12'hDA9: dout <= {-10'sd192   , -10'sd475   }; /* W[1275] = -0.3750  -0.9277i */
            12'hDAA: dout <= {-10'sd194   , -10'sd474   }; /* W[1278] = -0.3789  -0.9258i */
            12'hDAB: dout <= {-10'sd197   , -10'sd473   }; /* W[1281] = -0.3848  -0.9238i */
            12'hDAC: dout <= {-10'sd199   , -10'sd472   }; /* W[1284] = -0.3887  -0.9219i */
            12'hDAD: dout <= {-10'sd201   , -10'sd471   }; /* W[1287] = -0.3926  -0.9199i */
            12'hDAE: dout <= {-10'sd203   , -10'sd470   }; /* W[1290] = -0.3965  -0.9180i */
            12'hDAF: dout <= {-10'sd205   , -10'sd469   }; /* W[1293] = -0.4004  -0.9160i */
            12'hDB0: dout <= {-10'sd207   , -10'sd468   }; /* W[1296] = -0.4043  -0.9141i */
            12'hDB1: dout <= {-10'sd210   , -10'sd467   }; /* W[1299] = -0.4102  -0.9121i */
            12'hDB2: dout <= {-10'sd212   , -10'sd466   }; /* W[1302] = -0.4141  -0.9102i */
            12'hDB3: dout <= {-10'sd214   , -10'sd465   }; /* W[1305] = -0.4180  -0.9082i */
            12'hDB4: dout <= {-10'sd216   , -10'sd464   }; /* W[1308] = -0.4219  -0.9062i */
            12'hDB5: dout <= {-10'sd218   , -10'sd463   }; /* W[1311] = -0.4258  -0.9043i */
            12'hDB6: dout <= {-10'sd220   , -10'sd462   }; /* W[1314] = -0.4297  -0.9023i */
            12'hDB7: dout <= {-10'sd222   , -10'sd461   }; /* W[1317] = -0.4336  -0.9004i */
            12'hDB8: dout <= {-10'sd225   , -10'sd460   }; /* W[1320] = -0.4395  -0.8984i */
            12'hDB9: dout <= {-10'sd227   , -10'sd459   }; /* W[1323] = -0.4434  -0.8965i */
            12'hDBA: dout <= {-10'sd229   , -10'sd458   }; /* W[1326] = -0.4473  -0.8945i */
            12'hDBB: dout <= {-10'sd231   , -10'sd457   }; /* W[1329] = -0.4512  -0.8926i */
            12'hDBC: dout <= {-10'sd233   , -10'sd456   }; /* W[1332] = -0.4551  -0.8906i */
            12'hDBD: dout <= {-10'sd235   , -10'sd455   }; /* W[1335] = -0.4590  -0.8887i */
            12'hDBE: dout <= {-10'sd237   , -10'sd454   }; /* W[1338] = -0.4629  -0.8867i */
            12'hDBF: dout <= {-10'sd239   , -10'sd453   }; /* W[1341] = -0.4668  -0.8848i */
            12'hDC0: dout <= {-10'sd241   , -10'sd452   }; /* W[1344] = -0.4707  -0.8828i */
            12'hDC1: dout <= {-10'sd243   , -10'sd450   }; /* W[1347] = -0.4746  -0.8789i */
            12'hDC2: dout <= {-10'sd246   , -10'sd449   }; /* W[1350] = -0.4805  -0.8770i */
            12'hDC3: dout <= {-10'sd248   , -10'sd448   }; /* W[1353] = -0.4844  -0.8750i */
            12'hDC4: dout <= {-10'sd250   , -10'sd447   }; /* W[1356] = -0.4883  -0.8730i */
            12'hDC5: dout <= {-10'sd252   , -10'sd446   }; /* W[1359] = -0.4922  -0.8711i */
            12'hDC6: dout <= {-10'sd254   , -10'sd445   }; /* W[1362] = -0.4961  -0.8691i */
            12'hDC7: dout <= {-10'sd256   , -10'sd444   }; /* W[1365] = -0.5000  -0.8672i */
            12'hDC8: dout <= {-10'sd258   , -10'sd442   }; /* W[1368] = -0.5039  -0.8633i */
            12'hDC9: dout <= {-10'sd260   , -10'sd441   }; /* W[1371] = -0.5078  -0.8613i */
            12'hDCA: dout <= {-10'sd262   , -10'sd440   }; /* W[1374] = -0.5117  -0.8594i */
            12'hDCB: dout <= {-10'sd264   , -10'sd439   }; /* W[1377] = -0.5156  -0.8574i */
            12'hDCC: dout <= {-10'sd266   , -10'sd438   }; /* W[1380] = -0.5195  -0.8555i */
            12'hDCD: dout <= {-10'sd268   , -10'sd436   }; /* W[1383] = -0.5234  -0.8516i */
            12'hDCE: dout <= {-10'sd270   , -10'sd435   }; /* W[1386] = -0.5273  -0.8496i */
            12'hDCF: dout <= {-10'sd272   , -10'sd434   }; /* W[1389] = -0.5312  -0.8477i */
            12'hDD0: dout <= {-10'sd274   , -10'sd433   }; /* W[1392] = -0.5352  -0.8457i */
            12'hDD1: dout <= {-10'sd276   , -10'sd431   }; /* W[1395] = -0.5391  -0.8418i */
            12'hDD2: dout <= {-10'sd278   , -10'sd430   }; /* W[1398] = -0.5430  -0.8398i */
            12'hDD3: dout <= {-10'sd280   , -10'sd429   }; /* W[1401] = -0.5469  -0.8379i */
            12'hDD4: dout <= {-10'sd282   , -10'sd427   }; /* W[1404] = -0.5508  -0.8340i */
            12'hDD5: dout <= {-10'sd284   , -10'sd426   }; /* W[1407] = -0.5547  -0.8320i */
            12'hDD6: dout <= {-10'sd286   , -10'sd425   }; /* W[1410] = -0.5586  -0.8301i */
            12'hDD7: dout <= {-10'sd288   , -10'sd424   }; /* W[1413] = -0.5625  -0.8281i */
            12'hDD8: dout <= {-10'sd290   , -10'sd422   }; /* W[1416] = -0.5664  -0.8242i */
            12'hDD9: dout <= {-10'sd292   , -10'sd421   }; /* W[1419] = -0.5703  -0.8223i */
            12'hDDA: dout <= {-10'sd294   , -10'sd420   }; /* W[1422] = -0.5742  -0.8203i */
            12'hDDB: dout <= {-10'sd295   , -10'sd418   }; /* W[1425] = -0.5762  -0.8164i */
            12'hDDC: dout <= {-10'sd297   , -10'sd417   }; /* W[1428] = -0.5801  -0.8145i */
            12'hDDD: dout <= {-10'sd299   , -10'sd415   }; /* W[1431] = -0.5840  -0.8105i */
            12'hDDE: dout <= {-10'sd301   , -10'sd414   }; /* W[1434] = -0.5879  -0.8086i */
            12'hDDF: dout <= {-10'sd303   , -10'sd413   }; /* W[1437] = -0.5918  -0.8066i */
            12'hDE0: dout <= {-10'sd305   , -10'sd411   }; /* W[1440] = -0.5957  -0.8027i */
            12'hDE1: dout <= {-10'sd307   , -10'sd410   }; /* W[1443] = -0.5996  -0.8008i */
            12'hDE2: dout <= {-10'sd309   , -10'sd408   }; /* W[1446] = -0.6035  -0.7969i */
            12'hDE3: dout <= {-10'sd311   , -10'sd407   }; /* W[1449] = -0.6074  -0.7949i */
            12'hDE4: dout <= {-10'sd313   , -10'sd406   }; /* W[1452] = -0.6113  -0.7930i */
            12'hDE5: dout <= {-10'sd314   , -10'sd404   }; /* W[1455] = -0.6133  -0.7891i */
            12'hDE6: dout <= {-10'sd316   , -10'sd403   }; /* W[1458] = -0.6172  -0.7871i */
            12'hDE7: dout <= {-10'sd318   , -10'sd401   }; /* W[1461] = -0.6211  -0.7832i */
            12'hDE8: dout <= {-10'sd320   , -10'sd400   }; /* W[1464] = -0.6250  -0.7812i */
            12'hDE9: dout <= {-10'sd322   , -10'sd398   }; /* W[1467] = -0.6289  -0.7773i */
            12'hDEA: dout <= {-10'sd324   , -10'sd397   }; /* W[1470] = -0.6328  -0.7754i */
            12'hDEB: dout <= {-10'sd325   , -10'sd395   }; /* W[1473] = -0.6348  -0.7715i */
            12'hDEC: dout <= {-10'sd327   , -10'sd394   }; /* W[1476] = -0.6387  -0.7695i */
            12'hDED: dout <= {-10'sd329   , -10'sd392   }; /* W[1479] = -0.6426  -0.7656i */
            12'hDEE: dout <= {-10'sd331   , -10'sd391   }; /* W[1482] = -0.6465  -0.7637i */
            12'hDEF: dout <= {-10'sd333   , -10'sd389   }; /* W[1485] = -0.6504  -0.7598i */
            12'hDF0: dout <= {-10'sd334   , -10'sd388   }; /* W[1488] = -0.6523  -0.7578i */
            12'hDF1: dout <= {-10'sd336   , -10'sd386   }; /* W[1491] = -0.6562  -0.7539i */
            12'hDF2: dout <= {-10'sd338   , -10'sd385   }; /* W[1494] = -0.6602  -0.7520i */
            12'hDF3: dout <= {-10'sd340   , -10'sd383   }; /* W[1497] = -0.6641  -0.7480i */
            12'hDF4: dout <= {-10'sd342   , -10'sd381   }; /* W[1500] = -0.6680  -0.7441i */
            12'hDF5: dout <= {-10'sd343   , -10'sd380   }; /* W[1503] = -0.6699  -0.7422i */
            12'hDF6: dout <= {-10'sd345   , -10'sd378   }; /* W[1506] = -0.6738  -0.7383i */
            12'hDF7: dout <= {-10'sd347   , -10'sd377   }; /* W[1509] = -0.6777  -0.7363i */
            12'hDF8: dout <= {-10'sd348   , -10'sd375   }; /* W[1512] = -0.6797  -0.7324i */
            12'hDF9: dout <= {-10'sd350   , -10'sd374   }; /* W[1515] = -0.6836  -0.7305i */
            12'hDFA: dout <= {-10'sd352   , -10'sd372   }; /* W[1518] = -0.6875  -0.7266i */
            12'hDFB: dout <= {-10'sd354   , -10'sd370   }; /* W[1521] = -0.6914  -0.7227i */
            12'hDFC: dout <= {-10'sd355   , -10'sd369   }; /* W[1524] = -0.6934  -0.7207i */
            12'hDFD: dout <= {-10'sd357   , -10'sd367   }; /* W[1527] = -0.6973  -0.7168i */
            12'hDFE: dout <= {-10'sd359   , -10'sd365   }; /* W[1530] = -0.7012  -0.7129i */
            12'hDFF: dout <= {-10'sd360   , -10'sd364   }; /* W[1533] = -0.7031  -0.7109i */
            12'hE00: dout <= {-10'sd362   , -10'sd362   }; /* W[1536] = -0.7070  -0.7070i */
            12'hE01: dout <= {-10'sd364   , -10'sd360   }; /* W[1539] = -0.7109  -0.7031i */
            12'hE02: dout <= {-10'sd365   , -10'sd359   }; /* W[1542] = -0.7129  -0.7012i */
            12'hE03: dout <= {-10'sd367   , -10'sd357   }; /* W[1545] = -0.7168  -0.6973i */
            12'hE04: dout <= {-10'sd369   , -10'sd355   }; /* W[1548] = -0.7207  -0.6934i */
            12'hE05: dout <= {-10'sd370   , -10'sd354   }; /* W[1551] = -0.7227  -0.6914i */
            12'hE06: dout <= {-10'sd372   , -10'sd352   }; /* W[1554] = -0.7266  -0.6875i */
            12'hE07: dout <= {-10'sd374   , -10'sd350   }; /* W[1557] = -0.7305  -0.6836i */
            12'hE08: dout <= {-10'sd375   , -10'sd348   }; /* W[1560] = -0.7324  -0.6797i */
            12'hE09: dout <= {-10'sd377   , -10'sd347   }; /* W[1563] = -0.7363  -0.6777i */
            12'hE0A: dout <= {-10'sd378   , -10'sd345   }; /* W[1566] = -0.7383  -0.6738i */
            12'hE0B: dout <= {-10'sd380   , -10'sd343   }; /* W[1569] = -0.7422  -0.6699i */
            12'hE0C: dout <= {-10'sd381   , -10'sd342   }; /* W[1572] = -0.7441  -0.6680i */
            12'hE0D: dout <= {-10'sd383   , -10'sd340   }; /* W[1575] = -0.7480  -0.6641i */
            12'hE0E: dout <= {-10'sd385   , -10'sd338   }; /* W[1578] = -0.7520  -0.6602i */
            12'hE0F: dout <= {-10'sd386   , -10'sd336   }; /* W[1581] = -0.7539  -0.6562i */
            12'hE10: dout <= {-10'sd388   , -10'sd334   }; /* W[1584] = -0.7578  -0.6523i */
            12'hE11: dout <= {-10'sd389   , -10'sd333   }; /* W[1587] = -0.7598  -0.6504i */
            12'hE12: dout <= {-10'sd391   , -10'sd331   }; /* W[1590] = -0.7637  -0.6465i */
            12'hE13: dout <= {-10'sd392   , -10'sd329   }; /* W[1593] = -0.7656  -0.6426i */
            12'hE14: dout <= {-10'sd394   , -10'sd327   }; /* W[1596] = -0.7695  -0.6387i */
            12'hE15: dout <= {-10'sd395   , -10'sd325   }; /* W[1599] = -0.7715  -0.6348i */
            12'hE16: dout <= {-10'sd397   , -10'sd324   }; /* W[1602] = -0.7754  -0.6328i */
            12'hE17: dout <= {-10'sd398   , -10'sd322   }; /* W[1605] = -0.7773  -0.6289i */
            12'hE18: dout <= {-10'sd400   , -10'sd320   }; /* W[1608] = -0.7812  -0.6250i */
            12'hE19: dout <= {-10'sd401   , -10'sd318   }; /* W[1611] = -0.7832  -0.6211i */
            12'hE1A: dout <= {-10'sd403   , -10'sd316   }; /* W[1614] = -0.7871  -0.6172i */
            12'hE1B: dout <= {-10'sd404   , -10'sd314   }; /* W[1617] = -0.7891  -0.6133i */
            12'hE1C: dout <= {-10'sd406   , -10'sd313   }; /* W[1620] = -0.7930  -0.6113i */
            12'hE1D: dout <= {-10'sd407   , -10'sd311   }; /* W[1623] = -0.7949  -0.6074i */
            12'hE1E: dout <= {-10'sd408   , -10'sd309   }; /* W[1626] = -0.7969  -0.6035i */
            12'hE1F: dout <= {-10'sd410   , -10'sd307   }; /* W[1629] = -0.8008  -0.5996i */
            12'hE20: dout <= {-10'sd411   , -10'sd305   }; /* W[1632] = -0.8027  -0.5957i */
            12'hE21: dout <= {-10'sd413   , -10'sd303   }; /* W[1635] = -0.8066  -0.5918i */
            12'hE22: dout <= {-10'sd414   , -10'sd301   }; /* W[1638] = -0.8086  -0.5879i */
            12'hE23: dout <= {-10'sd415   , -10'sd299   }; /* W[1641] = -0.8105  -0.5840i */
            12'hE24: dout <= {-10'sd417   , -10'sd297   }; /* W[1644] = -0.8145  -0.5801i */
            12'hE25: dout <= {-10'sd418   , -10'sd295   }; /* W[1647] = -0.8164  -0.5762i */
            12'hE26: dout <= {-10'sd420   , -10'sd294   }; /* W[1650] = -0.8203  -0.5742i */
            12'hE27: dout <= {-10'sd421   , -10'sd292   }; /* W[1653] = -0.8223  -0.5703i */
            12'hE28: dout <= {-10'sd422   , -10'sd290   }; /* W[1656] = -0.8242  -0.5664i */
            12'hE29: dout <= {-10'sd424   , -10'sd288   }; /* W[1659] = -0.8281  -0.5625i */
            12'hE2A: dout <= {-10'sd425   , -10'sd286   }; /* W[1662] = -0.8301  -0.5586i */
            12'hE2B: dout <= {-10'sd426   , -10'sd284   }; /* W[1665] = -0.8320  -0.5547i */
            12'hE2C: dout <= {-10'sd427   , -10'sd282   }; /* W[1668] = -0.8340  -0.5508i */
            12'hE2D: dout <= {-10'sd429   , -10'sd280   }; /* W[1671] = -0.8379  -0.5469i */
            12'hE2E: dout <= {-10'sd430   , -10'sd278   }; /* W[1674] = -0.8398  -0.5430i */
            12'hE2F: dout <= {-10'sd431   , -10'sd276   }; /* W[1677] = -0.8418  -0.5391i */
            12'hE30: dout <= {-10'sd433   , -10'sd274   }; /* W[1680] = -0.8457  -0.5352i */
            12'hE31: dout <= {-10'sd434   , -10'sd272   }; /* W[1683] = -0.8477  -0.5312i */
            12'hE32: dout <= {-10'sd435   , -10'sd270   }; /* W[1686] = -0.8496  -0.5273i */
            12'hE33: dout <= {-10'sd436   , -10'sd268   }; /* W[1689] = -0.8516  -0.5234i */
            12'hE34: dout <= {-10'sd438   , -10'sd266   }; /* W[1692] = -0.8555  -0.5195i */
            12'hE35: dout <= {-10'sd439   , -10'sd264   }; /* W[1695] = -0.8574  -0.5156i */
            12'hE36: dout <= {-10'sd440   , -10'sd262   }; /* W[1698] = -0.8594  -0.5117i */
            12'hE37: dout <= {-10'sd441   , -10'sd260   }; /* W[1701] = -0.8613  -0.5078i */
            12'hE38: dout <= {-10'sd442   , -10'sd258   }; /* W[1704] = -0.8633  -0.5039i */
            12'hE39: dout <= {-10'sd444   , -10'sd256   }; /* W[1707] = -0.8672  -0.5000i */
            12'hE3A: dout <= {-10'sd445   , -10'sd254   }; /* W[1710] = -0.8691  -0.4961i */
            12'hE3B: dout <= {-10'sd446   , -10'sd252   }; /* W[1713] = -0.8711  -0.4922i */
            12'hE3C: dout <= {-10'sd447   , -10'sd250   }; /* W[1716] = -0.8730  -0.4883i */
            12'hE3D: dout <= {-10'sd448   , -10'sd248   }; /* W[1719] = -0.8750  -0.4844i */
            12'hE3E: dout <= {-10'sd449   , -10'sd246   }; /* W[1722] = -0.8770  -0.4805i */
            12'hE3F: dout <= {-10'sd450   , -10'sd243   }; /* W[1725] = -0.8789  -0.4746i */
            12'hE40: dout <= {-10'sd452   , -10'sd241   }; /* W[1728] = -0.8828  -0.4707i */
            12'hE41: dout <= {-10'sd453   , -10'sd239   }; /* W[1731] = -0.8848  -0.4668i */
            12'hE42: dout <= {-10'sd454   , -10'sd237   }; /* W[1734] = -0.8867  -0.4629i */
            12'hE43: dout <= {-10'sd455   , -10'sd235   }; /* W[1737] = -0.8887  -0.4590i */
            12'hE44: dout <= {-10'sd456   , -10'sd233   }; /* W[1740] = -0.8906  -0.4551i */
            12'hE45: dout <= {-10'sd457   , -10'sd231   }; /* W[1743] = -0.8926  -0.4512i */
            12'hE46: dout <= {-10'sd458   , -10'sd229   }; /* W[1746] = -0.8945  -0.4473i */
            12'hE47: dout <= {-10'sd459   , -10'sd227   }; /* W[1749] = -0.8965  -0.4434i */
            12'hE48: dout <= {-10'sd460   , -10'sd225   }; /* W[1752] = -0.8984  -0.4395i */
            12'hE49: dout <= {-10'sd461   , -10'sd222   }; /* W[1755] = -0.9004  -0.4336i */
            12'hE4A: dout <= {-10'sd462   , -10'sd220   }; /* W[1758] = -0.9023  -0.4297i */
            12'hE4B: dout <= {-10'sd463   , -10'sd218   }; /* W[1761] = -0.9043  -0.4258i */
            12'hE4C: dout <= {-10'sd464   , -10'sd216   }; /* W[1764] = -0.9062  -0.4219i */
            12'hE4D: dout <= {-10'sd465   , -10'sd214   }; /* W[1767] = -0.9082  -0.4180i */
            12'hE4E: dout <= {-10'sd466   , -10'sd212   }; /* W[1770] = -0.9102  -0.4141i */
            12'hE4F: dout <= {-10'sd467   , -10'sd210   }; /* W[1773] = -0.9121  -0.4102i */
            12'hE50: dout <= {-10'sd468   , -10'sd207   }; /* W[1776] = -0.9141  -0.4043i */
            12'hE51: dout <= {-10'sd469   , -10'sd205   }; /* W[1779] = -0.9160  -0.4004i */
            12'hE52: dout <= {-10'sd470   , -10'sd203   }; /* W[1782] = -0.9180  -0.3965i */
            12'hE53: dout <= {-10'sd471   , -10'sd201   }; /* W[1785] = -0.9199  -0.3926i */
            12'hE54: dout <= {-10'sd472   , -10'sd199   }; /* W[1788] = -0.9219  -0.3887i */
            12'hE55: dout <= {-10'sd473   , -10'sd197   }; /* W[1791] = -0.9238  -0.3848i */
            12'hE56: dout <= {-10'sd474   , -10'sd194   }; /* W[1794] = -0.9258  -0.3789i */
            12'hE57: dout <= {-10'sd475   , -10'sd192   }; /* W[1797] = -0.9277  -0.3750i */
            12'hE58: dout <= {-10'sd475   , -10'sd190   }; /* W[1800] = -0.9277  -0.3711i */
            12'hE59: dout <= {-10'sd476   , -10'sd188   }; /* W[1803] = -0.9297  -0.3672i */
            12'hE5A: dout <= {-10'sd477   , -10'sd186   }; /* W[1806] = -0.9316  -0.3633i */
            12'hE5B: dout <= {-10'sd478   , -10'sd184   }; /* W[1809] = -0.9336  -0.3594i */
            12'hE5C: dout <= {-10'sd479   , -10'sd181   }; /* W[1812] = -0.9355  -0.3535i */
            12'hE5D: dout <= {-10'sd480   , -10'sd179   }; /* W[1815] = -0.9375  -0.3496i */
            12'hE5E: dout <= {-10'sd480   , -10'sd177   }; /* W[1818] = -0.9375  -0.3457i */
            12'hE5F: dout <= {-10'sd481   , -10'sd175   }; /* W[1821] = -0.9395  -0.3418i */
            12'hE60: dout <= {-10'sd482   , -10'sd172   }; /* W[1824] = -0.9414  -0.3359i */
            12'hE61: dout <= {-10'sd483   , -10'sd170   }; /* W[1827] = -0.9434  -0.3320i */
            12'hE62: dout <= {-10'sd484   , -10'sd168   }; /* W[1830] = -0.9453  -0.3281i */
            12'hE63: dout <= {-10'sd484   , -10'sd166   }; /* W[1833] = -0.9453  -0.3242i */
            12'hE64: dout <= {-10'sd485   , -10'sd164   }; /* W[1836] = -0.9473  -0.3203i */
            12'hE65: dout <= {-10'sd486   , -10'sd161   }; /* W[1839] = -0.9492  -0.3145i */
            12'hE66: dout <= {-10'sd487   , -10'sd159   }; /* W[1842] = -0.9512  -0.3105i */
            12'hE67: dout <= {-10'sd487   , -10'sd157   }; /* W[1845] = -0.9512  -0.3066i */
            12'hE68: dout <= {-10'sd488   , -10'sd155   }; /* W[1848] = -0.9531  -0.3027i */
            12'hE69: dout <= {-10'sd489   , -10'sd152   }; /* W[1851] = -0.9551  -0.2969i */
            12'hE6A: dout <= {-10'sd489   , -10'sd150   }; /* W[1854] = -0.9551  -0.2930i */
            12'hE6B: dout <= {-10'sd490   , -10'sd148   }; /* W[1857] = -0.9570  -0.2891i */
            12'hE6C: dout <= {-10'sd491   , -10'sd146   }; /* W[1860] = -0.9590  -0.2852i */
            12'hE6D: dout <= {-10'sd492   , -10'sd143   }; /* W[1863] = -0.9609  -0.2793i */
            12'hE6E: dout <= {-10'sd492   , -10'sd141   }; /* W[1866] = -0.9609  -0.2754i */
            12'hE6F: dout <= {-10'sd493   , -10'sd139   }; /* W[1869] = -0.9629  -0.2715i */
            12'hE70: dout <= {-10'sd493   , -10'sd137   }; /* W[1872] = -0.9629  -0.2676i */
            12'hE71: dout <= {-10'sd494   , -10'sd134   }; /* W[1875] = -0.9648  -0.2617i */
            12'hE72: dout <= {-10'sd495   , -10'sd132   }; /* W[1878] = -0.9668  -0.2578i */
            12'hE73: dout <= {-10'sd495   , -10'sd130   }; /* W[1881] = -0.9668  -0.2539i */
            12'hE74: dout <= {-10'sd496   , -10'sd127   }; /* W[1884] = -0.9688  -0.2480i */
            12'hE75: dout <= {-10'sd496   , -10'sd125   }; /* W[1887] = -0.9688  -0.2441i */
            12'hE76: dout <= {-10'sd497   , -10'sd123   }; /* W[1890] = -0.9707  -0.2402i */
            12'hE77: dout <= {-10'sd498   , -10'sd121   }; /* W[1893] = -0.9727  -0.2363i */
            12'hE78: dout <= {-10'sd498   , -10'sd118   }; /* W[1896] = -0.9727  -0.2305i */
            12'hE79: dout <= {-10'sd499   , -10'sd116   }; /* W[1899] = -0.9746  -0.2266i */
            12'hE7A: dout <= {-10'sd499   , -10'sd114   }; /* W[1902] = -0.9746  -0.2227i */
            12'hE7B: dout <= {-10'sd500   , -10'sd111   }; /* W[1905] = -0.9766  -0.2168i */
            12'hE7C: dout <= {-10'sd500   , -10'sd109   }; /* W[1908] = -0.9766  -0.2129i */
            12'hE7D: dout <= {-10'sd501   , -10'sd107   }; /* W[1911] = -0.9785  -0.2090i */
            12'hE7E: dout <= {-10'sd501   , -10'sd105   }; /* W[1914] = -0.9785  -0.2051i */
            12'hE7F: dout <= {-10'sd502   , -10'sd102   }; /* W[1917] = -0.9805  -0.1992i */
            12'hE80: dout <= {-10'sd502   , -10'sd100   }; /* W[1920] = -0.9805  -0.1953i */
            12'hE81: dout <= {-10'sd503   , -10'sd98    }; /* W[1923] = -0.9824  -0.1914i */
            12'hE82: dout <= {-10'sd503   , -10'sd95    }; /* W[1926] = -0.9824  -0.1855i */
            12'hE83: dout <= {-10'sd503   , -10'sd93    }; /* W[1929] = -0.9824  -0.1816i */
            12'hE84: dout <= {-10'sd504   , -10'sd91    }; /* W[1932] = -0.9844  -0.1777i */
            12'hE85: dout <= {-10'sd504   , -10'sd88    }; /* W[1935] = -0.9844  -0.1719i */
            12'hE86: dout <= {-10'sd505   , -10'sd86    }; /* W[1938] = -0.9863  -0.1680i */
            12'hE87: dout <= {-10'sd505   , -10'sd84    }; /* W[1941] = -0.9863  -0.1641i */
            12'hE88: dout <= {-10'sd505   , -10'sd81    }; /* W[1944] = -0.9863  -0.1582i */
            12'hE89: dout <= {-10'sd506   , -10'sd79    }; /* W[1947] = -0.9883  -0.1543i */
            12'hE8A: dout <= {-10'sd506   , -10'sd77    }; /* W[1950] = -0.9883  -0.1504i */
            12'hE8B: dout <= {-10'sd507   , -10'sd74    }; /* W[1953] = -0.9902  -0.1445i */
            12'hE8C: dout <= {-10'sd507   , -10'sd72    }; /* W[1956] = -0.9902  -0.1406i */
            12'hE8D: dout <= {-10'sd507   , -10'sd70    }; /* W[1959] = -0.9902  -0.1367i */
            12'hE8E: dout <= {-10'sd508   , -10'sd67    }; /* W[1962] = -0.9922  -0.1309i */
            12'hE8F: dout <= {-10'sd508   , -10'sd65    }; /* W[1965] = -0.9922  -0.1270i */
            12'hE90: dout <= {-10'sd508   , -10'sd63    }; /* W[1968] = -0.9922  -0.1230i */
            12'hE91: dout <= {-10'sd508   , -10'sd60    }; /* W[1971] = -0.9922  -0.1172i */
            12'hE92: dout <= {-10'sd509   , -10'sd58    }; /* W[1974] = -0.9941  -0.1133i */
            12'hE93: dout <= {-10'sd509   , -10'sd56    }; /* W[1977] = -0.9941  -0.1094i */
            12'hE94: dout <= {-10'sd509   , -10'sd53    }; /* W[1980] = -0.9941  -0.1035i */
            12'hE95: dout <= {-10'sd509   , -10'sd51    }; /* W[1983] = -0.9941  -0.0996i */
            12'hE96: dout <= {-10'sd510   , -10'sd49    }; /* W[1986] = -0.9961  -0.0957i */
            12'hE97: dout <= {-10'sd510   , -10'sd46    }; /* W[1989] = -0.9961  -0.0898i */
            12'hE98: dout <= {-10'sd510   , -10'sd44    }; /* W[1992] = -0.9961  -0.0859i */
            12'hE99: dout <= {-10'sd510   , -10'sd42    }; /* W[1995] = -0.9961  -0.0820i */
            12'hE9A: dout <= {-10'sd510   , -10'sd39    }; /* W[1998] = -0.9961  -0.0762i */
            12'hE9B: dout <= {-10'sd511   , -10'sd37    }; /* W[2001] = -0.9980  -0.0723i */
            12'hE9C: dout <= {-10'sd511   , -10'sd35    }; /* W[2004] = -0.9980  -0.0684i */
            12'hE9D: dout <= {-10'sd511   , -10'sd32    }; /* W[2007] = -0.9980  -0.0625i */
            12'hE9E: dout <= {-10'sd511   , -10'sd30    }; /* W[2010] = -0.9980  -0.0586i */
            12'hE9F: dout <= {-10'sd511   , -10'sd27    }; /* W[2013] = -0.9980  -0.0527i */
            12'hEA0: dout <= {-10'sd511   , -10'sd25    }; /* W[2016] = -0.9980  -0.0488i */
            12'hEA1: dout <= {-10'sd511   , -10'sd23    }; /* W[2019] = -0.9980  -0.0449i */
            12'hEA2: dout <= {-10'sd512   , -10'sd20    }; /* W[2022] = -1.0000  -0.0391i */
            12'hEA3: dout <= {-10'sd512   , -10'sd18    }; /* W[2025] = -1.0000  -0.0352i */
            12'hEA4: dout <= {-10'sd512   , -10'sd16    }; /* W[2028] = -1.0000  -0.0312i */
            12'hEA5: dout <= {-10'sd512   , -10'sd13    }; /* W[2031] = -1.0000  -0.0254i */
            12'hEA6: dout <= {-10'sd512   , -10'sd11    }; /* W[2034] = -1.0000  -0.0215i */
            12'hEA7: dout <= {-10'sd512   , -10'sd9     }; /* W[2037] = -1.0000  -0.0176i */
            12'hEA8: dout <= {-10'sd512   , -10'sd6     }; /* W[2040] = -1.0000  -0.0117i */
            12'hEA9: dout <= {-10'sd512   , -10'sd4     }; /* W[2043] = -1.0000  -0.0078i */
            12'hEAA: dout <= {-10'sd512   , -10'sd2     }; /* W[2046] = -1.0000  -0.0039i */
            12'hEAB: dout <= {-10'sd512   ,  10'sd1     }; /* W[2049] = -1.0000   0.0020i */
            12'hEAC: dout <= {-10'sd512   ,  10'sd3     }; /* W[2052] = -1.0000   0.0059i */
            12'hEAD: dout <= {-10'sd512   ,  10'sd5     }; /* W[2055] = -1.0000   0.0098i */
            12'hEAE: dout <= {-10'sd512   ,  10'sd8     }; /* W[2058] = -1.0000   0.0156i */
            12'hEAF: dout <= {-10'sd512   ,  10'sd10    }; /* W[2061] = -1.0000   0.0195i */
            12'hEB0: dout <= {-10'sd512   ,  10'sd13    }; /* W[2064] = -1.0000   0.0254i */
            12'hEB1: dout <= {-10'sd512   ,  10'sd15    }; /* W[2067] = -1.0000   0.0293i */
            12'hEB2: dout <= {-10'sd512   ,  10'sd17    }; /* W[2070] = -1.0000   0.0332i */
            12'hEB3: dout <= {-10'sd512   ,  10'sd20    }; /* W[2073] = -1.0000   0.0391i */
            12'hEB4: dout <= {-10'sd512   ,  10'sd22    }; /* W[2076] = -1.0000   0.0430i */
            12'hEB5: dout <= {-10'sd511   ,  10'sd24    }; /* W[2079] = -0.9980   0.0469i */
            12'hEB6: dout <= {-10'sd511   ,  10'sd27    }; /* W[2082] = -0.9980   0.0527i */
            12'hEB7: dout <= {-10'sd511   ,  10'sd29    }; /* W[2085] = -0.9980   0.0566i */
            12'hEB8: dout <= {-10'sd511   ,  10'sd31    }; /* W[2088] = -0.9980   0.0605i */
            12'hEB9: dout <= {-10'sd511   ,  10'sd34    }; /* W[2091] = -0.9980   0.0664i */
            12'hEBA: dout <= {-10'sd511   ,  10'sd36    }; /* W[2094] = -0.9980   0.0703i */
            12'hEBB: dout <= {-10'sd511   ,  10'sd38    }; /* W[2097] = -0.9980   0.0742i */
            12'hEBC: dout <= {-10'sd510   ,  10'sd41    }; /* W[2100] = -0.9961   0.0801i */
            12'hEBD: dout <= {-10'sd510   ,  10'sd43    }; /* W[2103] = -0.9961   0.0840i */
            12'hEBE: dout <= {-10'sd510   ,  10'sd45    }; /* W[2106] = -0.9961   0.0879i */
            12'hEBF: dout <= {-10'sd510   ,  10'sd48    }; /* W[2109] = -0.9961   0.0938i */
            12'hEC0: dout <= {-10'sd510   ,  10'sd50    }; /* W[2112] = -0.9961   0.0977i */
            12'hEC1: dout <= {-10'sd509   ,  10'sd53    }; /* W[2115] = -0.9941   0.1035i */
            12'hEC2: dout <= {-10'sd509   ,  10'sd55    }; /* W[2118] = -0.9941   0.1074i */
            12'hEC3: dout <= {-10'sd509   ,  10'sd57    }; /* W[2121] = -0.9941   0.1113i */
            12'hEC4: dout <= {-10'sd509   ,  10'sd60    }; /* W[2124] = -0.9941   0.1172i */
            12'hEC5: dout <= {-10'sd508   ,  10'sd62    }; /* W[2127] = -0.9922   0.1211i */
            12'hEC6: dout <= {-10'sd508   ,  10'sd64    }; /* W[2130] = -0.9922   0.1250i */
            12'hEC7: dout <= {-10'sd508   ,  10'sd67    }; /* W[2133] = -0.9922   0.1309i */
            12'hEC8: dout <= {-10'sd507   ,  10'sd69    }; /* W[2136] = -0.9902   0.1348i */
            12'hEC9: dout <= {-10'sd507   ,  10'sd71    }; /* W[2139] = -0.9902   0.1387i */
            12'hECA: dout <= {-10'sd507   ,  10'sd74    }; /* W[2142] = -0.9902   0.1445i */
            12'hECB: dout <= {-10'sd506   ,  10'sd76    }; /* W[2145] = -0.9883   0.1484i */
            12'hECC: dout <= {-10'sd506   ,  10'sd78    }; /* W[2148] = -0.9883   0.1523i */
            12'hECD: dout <= {-10'sd506   ,  10'sd81    }; /* W[2151] = -0.9883   0.1582i */
            12'hECE: dout <= {-10'sd505   ,  10'sd83    }; /* W[2154] = -0.9863   0.1621i */
            12'hECF: dout <= {-10'sd505   ,  10'sd85    }; /* W[2157] = -0.9863   0.1660i */
            12'hED0: dout <= {-10'sd504   ,  10'sd88    }; /* W[2160] = -0.9844   0.1719i */
            12'hED1: dout <= {-10'sd504   ,  10'sd90    }; /* W[2163] = -0.9844   0.1758i */
            12'hED2: dout <= {-10'sd504   ,  10'sd92    }; /* W[2166] = -0.9844   0.1797i */
            12'hED3: dout <= {-10'sd503   ,  10'sd94    }; /* W[2169] = -0.9824   0.1836i */
            12'hED4: dout <= {-10'sd503   ,  10'sd97    }; /* W[2172] = -0.9824   0.1895i */
            12'hED5: dout <= {-10'sd502   ,  10'sd99    }; /* W[2175] = -0.9805   0.1934i */
            12'hED6: dout <= {-10'sd502   ,  10'sd101   }; /* W[2178] = -0.9805   0.1973i */
            12'hED7: dout <= {-10'sd501   ,  10'sd104   }; /* W[2181] = -0.9785   0.2031i */
            12'hED8: dout <= {-10'sd501   ,  10'sd106   }; /* W[2184] = -0.9785   0.2070i */
            12'hED9: dout <= {-10'sd500   ,  10'sd108   }; /* W[2187] = -0.9766   0.2109i */
            12'hEDA: dout <= {-10'sd500   ,  10'sd111   }; /* W[2190] = -0.9766   0.2168i */
            12'hEDB: dout <= {-10'sd499   ,  10'sd113   }; /* W[2193] = -0.9746   0.2207i */
            12'hEDC: dout <= {-10'sd499   ,  10'sd115   }; /* W[2196] = -0.9746   0.2246i */
            12'hEDD: dout <= {-10'sd498   ,  10'sd118   }; /* W[2199] = -0.9727   0.2305i */
            12'hEDE: dout <= {-10'sd498   ,  10'sd120   }; /* W[2202] = -0.9727   0.2344i */
            12'hEDF: dout <= {-10'sd497   ,  10'sd122   }; /* W[2205] = -0.9707   0.2383i */
            12'hEE0: dout <= {-10'sd497   ,  10'sd124   }; /* W[2208] = -0.9707   0.2422i */
            12'hEE1: dout <= {-10'sd496   ,  10'sd127   }; /* W[2211] = -0.9688   0.2480i */
            12'hEE2: dout <= {-10'sd495   ,  10'sd129   }; /* W[2214] = -0.9668   0.2520i */
            12'hEE3: dout <= {-10'sd495   ,  10'sd131   }; /* W[2217] = -0.9668   0.2559i */
            12'hEE4: dout <= {-10'sd494   ,  10'sd134   }; /* W[2220] = -0.9648   0.2617i */
            12'hEE5: dout <= {-10'sd494   ,  10'sd136   }; /* W[2223] = -0.9648   0.2656i */
            12'hEE6: dout <= {-10'sd493   ,  10'sd138   }; /* W[2226] = -0.9629   0.2695i */
            12'hEE7: dout <= {-10'sd492   ,  10'sd140   }; /* W[2229] = -0.9609   0.2734i */
            12'hEE8: dout <= {-10'sd492   ,  10'sd143   }; /* W[2232] = -0.9609   0.2793i */
            12'hEE9: dout <= {-10'sd491   ,  10'sd145   }; /* W[2235] = -0.9590   0.2832i */
            12'hEEA: dout <= {-10'sd490   ,  10'sd147   }; /* W[2238] = -0.9570   0.2871i */
            12'hEEB: dout <= {-10'sd490   ,  10'sd149   }; /* W[2241] = -0.9570   0.2910i */
            12'hEEC: dout <= {-10'sd489   ,  10'sd152   }; /* W[2244] = -0.9551   0.2969i */
            12'hEED: dout <= {-10'sd488   ,  10'sd154   }; /* W[2247] = -0.9531   0.3008i */
            12'hEEE: dout <= {-10'sd488   ,  10'sd156   }; /* W[2250] = -0.9531   0.3047i */
            12'hEEF: dout <= {-10'sd487   ,  10'sd158   }; /* W[2253] = -0.9512   0.3086i */
            12'hEF0: dout <= {-10'sd486   ,  10'sd161   }; /* W[2256] = -0.9492   0.3145i */
            12'hEF1: dout <= {-10'sd485   ,  10'sd163   }; /* W[2259] = -0.9473   0.3184i */
            12'hEF2: dout <= {-10'sd485   ,  10'sd165   }; /* W[2262] = -0.9473   0.3223i */
            12'hEF3: dout <= {-10'sd484   ,  10'sd167   }; /* W[2265] = -0.9453   0.3262i */
            12'hEF4: dout <= {-10'sd483   ,  10'sd170   }; /* W[2268] = -0.9434   0.3320i */
            12'hEF5: dout <= {-10'sd482   ,  10'sd172   }; /* W[2271] = -0.9414   0.3359i */
            12'hEF6: dout <= {-10'sd482   ,  10'sd174   }; /* W[2274] = -0.9414   0.3398i */
            12'hEF7: dout <= {-10'sd481   ,  10'sd176   }; /* W[2277] = -0.9395   0.3438i */
            12'hEF8: dout <= {-10'sd480   ,  10'sd178   }; /* W[2280] = -0.9375   0.3477i */
            12'hEF9: dout <= {-10'sd479   ,  10'sd181   }; /* W[2283] = -0.9355   0.3535i */
            12'hEFA: dout <= {-10'sd478   ,  10'sd183   }; /* W[2286] = -0.9336   0.3574i */
            12'hEFB: dout <= {-10'sd477   ,  10'sd185   }; /* W[2289] = -0.9316   0.3613i */
            12'hEFC: dout <= {-10'sd477   ,  10'sd187   }; /* W[2292] = -0.9316   0.3652i */
            12'hEFD: dout <= {-10'sd476   ,  10'sd189   }; /* W[2295] = -0.9297   0.3691i */
            12'hEFE: dout <= {-10'sd475   ,  10'sd192   }; /* W[2298] = -0.9277   0.3750i */
            12'hEFF: dout <= {-10'sd474   ,  10'sd194   }; /* W[2301] = -0.9258   0.3789i */
            12'hF00: dout <= {-10'sd473   ,  10'sd196   }; /* W[2304] = -0.9238   0.3828i */
            12'hF01: dout <= {-10'sd472   ,  10'sd198   }; /* W[2307] = -0.9219   0.3867i */
            12'hF02: dout <= {-10'sd471   ,  10'sd200   }; /* W[2310] = -0.9199   0.3906i */
            12'hF03: dout <= {-10'sd470   ,  10'sd202   }; /* W[2313] = -0.9180   0.3945i */
            12'hF04: dout <= {-10'sd469   ,  10'sd205   }; /* W[2316] = -0.9160   0.4004i */
            12'hF05: dout <= {-10'sd468   ,  10'sd207   }; /* W[2319] = -0.9141   0.4043i */
            12'hF06: dout <= {-10'sd467   ,  10'sd209   }; /* W[2322] = -0.9121   0.4082i */
            12'hF07: dout <= {-10'sd466   ,  10'sd211   }; /* W[2325] = -0.9102   0.4121i */
            12'hF08: dout <= {-10'sd465   ,  10'sd213   }; /* W[2328] = -0.9082   0.4160i */
            12'hF09: dout <= {-10'sd465   ,  10'sd215   }; /* W[2331] = -0.9082   0.4199i */
            12'hF0A: dout <= {-10'sd464   ,  10'sd217   }; /* W[2334] = -0.9062   0.4238i */
            12'hF0B: dout <= {-10'sd463   ,  10'sd220   }; /* W[2337] = -0.9043   0.4297i */
            12'hF0C: dout <= {-10'sd461   ,  10'sd222   }; /* W[2340] = -0.9004   0.4336i */
            12'hF0D: dout <= {-10'sd460   ,  10'sd224   }; /* W[2343] = -0.8984   0.4375i */
            12'hF0E: dout <= {-10'sd459   ,  10'sd226   }; /* W[2346] = -0.8965   0.4414i */
            12'hF0F: dout <= {-10'sd458   ,  10'sd228   }; /* W[2349] = -0.8945   0.4453i */
            12'hF10: dout <= {-10'sd457   ,  10'sd230   }; /* W[2352] = -0.8926   0.4492i */
            12'hF11: dout <= {-10'sd456   ,  10'sd232   }; /* W[2355] = -0.8906   0.4531i */
            12'hF12: dout <= {-10'sd455   ,  10'sd234   }; /* W[2358] = -0.8887   0.4570i */
            12'hF13: dout <= {-10'sd454   ,  10'sd236   }; /* W[2361] = -0.8867   0.4609i */
            12'hF14: dout <= {-10'sd453   ,  10'sd239   }; /* W[2364] = -0.8848   0.4668i */
            12'hF15: dout <= {-10'sd452   ,  10'sd241   }; /* W[2367] = -0.8828   0.4707i */
            12'hF16: dout <= {-10'sd451   ,  10'sd243   }; /* W[2370] = -0.8809   0.4746i */
            12'hF17: dout <= {-10'sd450   ,  10'sd245   }; /* W[2373] = -0.8789   0.4785i */
            12'hF18: dout <= {-10'sd449   ,  10'sd247   }; /* W[2376] = -0.8770   0.4824i */
            12'hF19: dout <= {-10'sd447   ,  10'sd249   }; /* W[2379] = -0.8730   0.4863i */
            12'hF1A: dout <= {-10'sd446   ,  10'sd251   }; /* W[2382] = -0.8711   0.4902i */
            12'hF1B: dout <= {-10'sd445   ,  10'sd253   }; /* W[2385] = -0.8691   0.4941i */
            12'hF1C: dout <= {-10'sd444   ,  10'sd255   }; /* W[2388] = -0.8672   0.4980i */
            12'hF1D: dout <= {-10'sd443   ,  10'sd257   }; /* W[2391] = -0.8652   0.5020i */
            12'hF1E: dout <= {-10'sd442   ,  10'sd259   }; /* W[2394] = -0.8633   0.5059i */
            12'hF1F: dout <= {-10'sd440   ,  10'sd261   }; /* W[2397] = -0.8594   0.5098i */
            12'hF20: dout <= {-10'sd439   ,  10'sd263   }; /* W[2400] = -0.8574   0.5137i */
            12'hF21: dout <= {-10'sd438   ,  10'sd265   }; /* W[2403] = -0.8555   0.5176i */
            12'hF22: dout <= {-10'sd437   ,  10'sd267   }; /* W[2406] = -0.8535   0.5215i */
            12'hF23: dout <= {-10'sd435   ,  10'sd269   }; /* W[2409] = -0.8496   0.5254i */
            12'hF24: dout <= {-10'sd434   ,  10'sd271   }; /* W[2412] = -0.8477   0.5293i */
            12'hF25: dout <= {-10'sd433   ,  10'sd273   }; /* W[2415] = -0.8457   0.5332i */
            12'hF26: dout <= {-10'sd432   ,  10'sd275   }; /* W[2418] = -0.8438   0.5371i */
            12'hF27: dout <= {-10'sd430   ,  10'sd277   }; /* W[2421] = -0.8398   0.5410i */
            12'hF28: dout <= {-10'sd429   ,  10'sd279   }; /* W[2424] = -0.8379   0.5449i */
            12'hF29: dout <= {-10'sd428   ,  10'sd281   }; /* W[2427] = -0.8359   0.5488i */
            12'hF2A: dout <= {-10'sd427   ,  10'sd283   }; /* W[2430] = -0.8340   0.5527i */
            12'hF2B: dout <= {-10'sd425   ,  10'sd285   }; /* W[2433] = -0.8301   0.5566i */
            12'hF2C: dout <= {-10'sd424   ,  10'sd287   }; /* W[2436] = -0.8281   0.5605i */
            12'hF2D: dout <= {-10'sd423   ,  10'sd289   }; /* W[2439] = -0.8262   0.5645i */
            12'hF2E: dout <= {-10'sd421   ,  10'sd291   }; /* W[2442] = -0.8223   0.5684i */
            12'hF2F: dout <= {-10'sd420   ,  10'sd293   }; /* W[2445] = -0.8203   0.5723i */
            12'hF30: dout <= {-10'sd419   ,  10'sd295   }; /* W[2448] = -0.8184   0.5762i */
            12'hF31: dout <= {-10'sd417   ,  10'sd297   }; /* W[2451] = -0.8145   0.5801i */
            12'hF32: dout <= {-10'sd416   ,  10'sd299   }; /* W[2454] = -0.8125   0.5840i */
            12'hF33: dout <= {-10'sd414   ,  10'sd301   }; /* W[2457] = -0.8086   0.5879i */
            12'hF34: dout <= {-10'sd413   ,  10'sd302   }; /* W[2460] = -0.8066   0.5898i */
            12'hF35: dout <= {-10'sd412   ,  10'sd304   }; /* W[2463] = -0.8047   0.5938i */
            12'hF36: dout <= {-10'sd410   ,  10'sd306   }; /* W[2466] = -0.8008   0.5977i */
            12'hF37: dout <= {-10'sd409   ,  10'sd308   }; /* W[2469] = -0.7988   0.6016i */
            12'hF38: dout <= {-10'sd407   ,  10'sd310   }; /* W[2472] = -0.7949   0.6055i */
            12'hF39: dout <= {-10'sd406   ,  10'sd312   }; /* W[2475] = -0.7930   0.6094i */
            12'hF3A: dout <= {-10'sd405   ,  10'sd314   }; /* W[2478] = -0.7910   0.6133i */
            12'hF3B: dout <= {-10'sd403   ,  10'sd316   }; /* W[2481] = -0.7871   0.6172i */
            12'hF3C: dout <= {-10'sd402   ,  10'sd317   }; /* W[2484] = -0.7852   0.6191i */
            12'hF3D: dout <= {-10'sd400   ,  10'sd319   }; /* W[2487] = -0.7812   0.6230i */
            12'hF3E: dout <= {-10'sd399   ,  10'sd321   }; /* W[2490] = -0.7793   0.6270i */
            12'hF3F: dout <= {-10'sd397   ,  10'sd323   }; /* W[2493] = -0.7754   0.6309i */
            12'hF40: dout <= {-10'sd396   ,  10'sd325   }; /* W[2496] = -0.7734   0.6348i */
            12'hF41: dout <= {-10'sd394   ,  10'sd327   }; /* W[2499] = -0.7695   0.6387i */
            12'hF42: dout <= {-10'sd393   ,  10'sd328   }; /* W[2502] = -0.7676   0.6406i */
            12'hF43: dout <= {-10'sd391   ,  10'sd330   }; /* W[2505] = -0.7637   0.6445i */
            12'hF44: dout <= {-10'sd390   ,  10'sd332   }; /* W[2508] = -0.7617   0.6484i */
            12'hF45: dout <= {-10'sd388   ,  10'sd334   }; /* W[2511] = -0.7578   0.6523i */
            12'hF46: dout <= {-10'sd387   ,  10'sd336   }; /* W[2514] = -0.7559   0.6562i */
            12'hF47: dout <= {-10'sd385   ,  10'sd337   }; /* W[2517] = -0.7520   0.6582i */
            12'hF48: dout <= {-10'sd384   ,  10'sd339   }; /* W[2520] = -0.7500   0.6621i */
            12'hF49: dout <= {-10'sd382   ,  10'sd341   }; /* W[2523] = -0.7461   0.6660i */
            12'hF4A: dout <= {-10'sd380   ,  10'sd343   }; /* W[2526] = -0.7422   0.6699i */
            12'hF4B: dout <= {-10'sd379   ,  10'sd344   }; /* W[2529] = -0.7402   0.6719i */
            12'hF4C: dout <= {-10'sd377   ,  10'sd346   }; /* W[2532] = -0.7363   0.6758i */
            12'hF4D: dout <= {-10'sd376   ,  10'sd348   }; /* W[2535] = -0.7344   0.6797i */
            12'hF4E: dout <= {-10'sd374   ,  10'sd350   }; /* W[2538] = -0.7305   0.6836i */
            12'hF4F: dout <= {-10'sd372   ,  10'sd351   }; /* W[2541] = -0.7266   0.6855i */
            12'hF50: dout <= {-10'sd371   ,  10'sd353   }; /* W[2544] = -0.7246   0.6895i */
            12'hF51: dout <= {-10'sd369   ,  10'sd355   }; /* W[2547] = -0.7207   0.6934i */
            12'hF52: dout <= {-10'sd368   ,  10'sd356   }; /* W[2550] = -0.7188   0.6953i */
            12'hF53: dout <= {-10'sd366   ,  10'sd358   }; /* W[2553] = -0.7148   0.6992i */
            12'hF54: dout <= {-10'sd364   ,  10'sd360   }; /* W[2556] = -0.7109   0.7031i */
            12'hF55: dout <= {-10'sd363   ,  10'sd361   }; /* W[2559] = -0.7090   0.7051i */
            12'hF56: dout <= {-10'sd361   ,  10'sd363   }; /* W[2562] = -0.7051   0.7090i */
            12'hF57: dout <= {-10'sd359   ,  10'sd365   }; /* W[2565] = -0.7012   0.7129i */
            12'hF58: dout <= {-10'sd358   ,  10'sd366   }; /* W[2568] = -0.6992   0.7148i */
            12'hF59: dout <= {-10'sd356   ,  10'sd368   }; /* W[2571] = -0.6953   0.7188i */
            12'hF5A: dout <= {-10'sd354   ,  10'sd370   }; /* W[2574] = -0.6914   0.7227i */
            12'hF5B: dout <= {-10'sd352   ,  10'sd371   }; /* W[2577] = -0.6875   0.7246i */
            12'hF5C: dout <= {-10'sd351   ,  10'sd373   }; /* W[2580] = -0.6855   0.7285i */
            12'hF5D: dout <= {-10'sd349   ,  10'sd375   }; /* W[2583] = -0.6816   0.7324i */
            12'hF5E: dout <= {-10'sd347   ,  10'sd376   }; /* W[2586] = -0.6777   0.7344i */
            12'hF5F: dout <= {-10'sd346   ,  10'sd378   }; /* W[2589] = -0.6758   0.7383i */
            12'hF60: dout <= {-10'sd344   ,  10'sd379   }; /* W[2592] = -0.6719   0.7402i */
            12'hF61: dout <= {-10'sd342   ,  10'sd381   }; /* W[2595] = -0.6680   0.7441i */
            12'hF62: dout <= {-10'sd340   ,  10'sd383   }; /* W[2598] = -0.6641   0.7480i */
            12'hF63: dout <= {-10'sd339   ,  10'sd384   }; /* W[2601] = -0.6621   0.7500i */
            12'hF64: dout <= {-10'sd337   ,  10'sd386   }; /* W[2604] = -0.6582   0.7539i */
            12'hF65: dout <= {-10'sd335   ,  10'sd387   }; /* W[2607] = -0.6543   0.7559i */
            12'hF66: dout <= {-10'sd333   ,  10'sd389   }; /* W[2610] = -0.6504   0.7598i */
            12'hF67: dout <= {-10'sd331   ,  10'sd390   }; /* W[2613] = -0.6465   0.7617i */
            12'hF68: dout <= {-10'sd330   ,  10'sd392   }; /* W[2616] = -0.6445   0.7656i */
            12'hF69: dout <= {-10'sd328   ,  10'sd393   }; /* W[2619] = -0.6406   0.7676i */
            12'hF6A: dout <= {-10'sd326   ,  10'sd395   }; /* W[2622] = -0.6367   0.7715i */
            12'hF6B: dout <= {-10'sd324   ,  10'sd396   }; /* W[2625] = -0.6328   0.7734i */
            12'hF6C: dout <= {-10'sd322   ,  10'sd398   }; /* W[2628] = -0.6289   0.7773i */
            12'hF6D: dout <= {-10'sd321   ,  10'sd399   }; /* W[2631] = -0.6270   0.7793i */
            12'hF6E: dout <= {-10'sd319   ,  10'sd401   }; /* W[2634] = -0.6230   0.7832i */
            12'hF6F: dout <= {-10'sd317   ,  10'sd402   }; /* W[2637] = -0.6191   0.7852i */
            12'hF70: dout <= {-10'sd315   ,  10'sd404   }; /* W[2640] = -0.6152   0.7891i */
            12'hF71: dout <= {-10'sd313   ,  10'sd405   }; /* W[2643] = -0.6113   0.7910i */
            12'hF72: dout <= {-10'sd311   ,  10'sd407   }; /* W[2646] = -0.6074   0.7949i */
            12'hF73: dout <= {-10'sd309   ,  10'sd408   }; /* W[2649] = -0.6035   0.7969i */
            12'hF74: dout <= {-10'sd308   ,  10'sd409   }; /* W[2652] = -0.6016   0.7988i */
            12'hF75: dout <= {-10'sd306   ,  10'sd411   }; /* W[2655] = -0.5977   0.8027i */
            12'hF76: dout <= {-10'sd304   ,  10'sd412   }; /* W[2658] = -0.5938   0.8047i */
            12'hF77: dout <= {-10'sd302   ,  10'sd414   }; /* W[2661] = -0.5898   0.8086i */
            12'hF78: dout <= {-10'sd300   ,  10'sd415   }; /* W[2664] = -0.5859   0.8105i */
            12'hF79: dout <= {-10'sd298   ,  10'sd416   }; /* W[2667] = -0.5820   0.8125i */
            12'hF7A: dout <= {-10'sd296   ,  10'sd418   }; /* W[2670] = -0.5781   0.8164i */
            12'hF7B: dout <= {-10'sd294   ,  10'sd419   }; /* W[2673] = -0.5742   0.8184i */
            12'hF7C: dout <= {-10'sd292   ,  10'sd420   }; /* W[2676] = -0.5703   0.8203i */
            12'hF7D: dout <= {-10'sd290   ,  10'sd422   }; /* W[2679] = -0.5664   0.8242i */
            12'hF7E: dout <= {-10'sd288   ,  10'sd423   }; /* W[2682] = -0.5625   0.8262i */
            12'hF7F: dout <= {-10'sd286   ,  10'sd424   }; /* W[2685] = -0.5586   0.8281i */
            12'hF80: dout <= {-10'sd284   ,  10'sd426   }; /* W[2688] = -0.5547   0.8320i */
            12'hF81: dout <= {-10'sd282   ,  10'sd427   }; /* W[2691] = -0.5508   0.8340i */
            12'hF82: dout <= {-10'sd281   ,  10'sd428   }; /* W[2694] = -0.5488   0.8359i */
            12'hF83: dout <= {-10'sd279   ,  10'sd430   }; /* W[2697] = -0.5449   0.8398i */
            12'hF84: dout <= {-10'sd277   ,  10'sd431   }; /* W[2700] = -0.5410   0.8418i */
            12'hF85: dout <= {-10'sd275   ,  10'sd432   }; /* W[2703] = -0.5371   0.8438i */
            12'hF86: dout <= {-10'sd273   ,  10'sd433   }; /* W[2706] = -0.5332   0.8457i */
            12'hF87: dout <= {-10'sd271   ,  10'sd435   }; /* W[2709] = -0.5293   0.8496i */
            12'hF88: dout <= {-10'sd269   ,  10'sd436   }; /* W[2712] = -0.5254   0.8516i */
            12'hF89: dout <= {-10'sd267   ,  10'sd437   }; /* W[2715] = -0.5215   0.8535i */
            12'hF8A: dout <= {-10'sd265   ,  10'sd438   }; /* W[2718] = -0.5176   0.8555i */
            12'hF8B: dout <= {-10'sd263   ,  10'sd440   }; /* W[2721] = -0.5137   0.8594i */
            12'hF8C: dout <= {-10'sd261   ,  10'sd441   }; /* W[2724] = -0.5098   0.8613i */
            12'hF8D: dout <= {-10'sd258   ,  10'sd442   }; /* W[2727] = -0.5039   0.8633i */
            12'hF8E: dout <= {-10'sd256   ,  10'sd443   }; /* W[2730] = -0.5000   0.8652i */
            12'hF8F: dout <= {-10'sd254   ,  10'sd444   }; /* W[2733] = -0.4961   0.8672i */
            12'hF90: dout <= {-10'sd252   ,  10'sd445   }; /* W[2736] = -0.4922   0.8691i */
            12'hF91: dout <= {-10'sd250   ,  10'sd447   }; /* W[2739] = -0.4883   0.8730i */
            12'hF92: dout <= {-10'sd248   ,  10'sd448   }; /* W[2742] = -0.4844   0.8750i */
            12'hF93: dout <= {-10'sd246   ,  10'sd449   }; /* W[2745] = -0.4805   0.8770i */
            12'hF94: dout <= {-10'sd244   ,  10'sd450   }; /* W[2748] = -0.4766   0.8789i */
            12'hF95: dout <= {-10'sd242   ,  10'sd451   }; /* W[2751] = -0.4727   0.8809i */
            12'hF96: dout <= {-10'sd240   ,  10'sd452   }; /* W[2754] = -0.4688   0.8828i */
            12'hF97: dout <= {-10'sd238   ,  10'sd453   }; /* W[2757] = -0.4648   0.8848i */
            12'hF98: dout <= {-10'sd236   ,  10'sd454   }; /* W[2760] = -0.4609   0.8867i */
            12'hF99: dout <= {-10'sd234   ,  10'sd456   }; /* W[2763] = -0.4570   0.8906i */
            12'hF9A: dout <= {-10'sd232   ,  10'sd457   }; /* W[2766] = -0.4531   0.8926i */
            12'hF9B: dout <= {-10'sd229   ,  10'sd458   }; /* W[2769] = -0.4473   0.8945i */
            12'hF9C: dout <= {-10'sd227   ,  10'sd459   }; /* W[2772] = -0.4434   0.8965i */
            12'hF9D: dout <= {-10'sd225   ,  10'sd460   }; /* W[2775] = -0.4395   0.8984i */
            12'hF9E: dout <= {-10'sd223   ,  10'sd461   }; /* W[2778] = -0.4355   0.9004i */
            12'hF9F: dout <= {-10'sd221   ,  10'sd462   }; /* W[2781] = -0.4316   0.9023i */
            12'hFA0: dout <= {-10'sd219   ,  10'sd463   }; /* W[2784] = -0.4277   0.9043i */
            12'hFA1: dout <= {-10'sd217   ,  10'sd464   }; /* W[2787] = -0.4238   0.9062i */
            12'hFA2: dout <= {-10'sd215   ,  10'sd465   }; /* W[2790] = -0.4199   0.9082i */
            12'hFA3: dout <= {-10'sd212   ,  10'sd466   }; /* W[2793] = -0.4141   0.9102i */
            12'hFA4: dout <= {-10'sd210   ,  10'sd467   }; /* W[2796] = -0.4102   0.9121i */
            12'hFA5: dout <= {-10'sd208   ,  10'sd468   }; /* W[2799] = -0.4062   0.9141i */
            12'hFA6: dout <= {-10'sd206   ,  10'sd469   }; /* W[2802] = -0.4023   0.9160i */
            12'hFA7: dout <= {-10'sd204   ,  10'sd470   }; /* W[2805] = -0.3984   0.9180i */
            12'hFA8: dout <= {-10'sd202   ,  10'sd471   }; /* W[2808] = -0.3945   0.9199i */
            12'hFA9: dout <= {-10'sd200   ,  10'sd472   }; /* W[2811] = -0.3906   0.9219i */
            12'hFAA: dout <= {-10'sd197   ,  10'sd472   }; /* W[2814] = -0.3848   0.9219i */
            12'hFAB: dout <= {-10'sd195   ,  10'sd473   }; /* W[2817] = -0.3809   0.9238i */
            12'hFAC: dout <= {-10'sd193   ,  10'sd474   }; /* W[2820] = -0.3770   0.9258i */
            12'hFAD: dout <= {-10'sd191   ,  10'sd475   }; /* W[2823] = -0.3730   0.9277i */
            12'hFAE: dout <= {-10'sd189   ,  10'sd476   }; /* W[2826] = -0.3691   0.9297i */
            12'hFAF: dout <= {-10'sd186   ,  10'sd477   }; /* W[2829] = -0.3633   0.9316i */
            12'hFB0: dout <= {-10'sd184   ,  10'sd478   }; /* W[2832] = -0.3594   0.9336i */
            12'hFB1: dout <= {-10'sd182   ,  10'sd479   }; /* W[2835] = -0.3555   0.9355i */
            12'hFB2: dout <= {-10'sd180   ,  10'sd479   }; /* W[2838] = -0.3516   0.9355i */
            12'hFB3: dout <= {-10'sd178   ,  10'sd480   }; /* W[2841] = -0.3477   0.9375i */
            12'hFB4: dout <= {-10'sd175   ,  10'sd481   }; /* W[2844] = -0.3418   0.9395i */
            12'hFB5: dout <= {-10'sd173   ,  10'sd482   }; /* W[2847] = -0.3379   0.9414i */
            12'hFB6: dout <= {-10'sd171   ,  10'sd483   }; /* W[2850] = -0.3340   0.9434i */
            12'hFB7: dout <= {-10'sd169   ,  10'sd483   }; /* W[2853] = -0.3301   0.9434i */
            12'hFB8: dout <= {-10'sd167   ,  10'sd484   }; /* W[2856] = -0.3262   0.9453i */
            12'hFB9: dout <= {-10'sd164   ,  10'sd485   }; /* W[2859] = -0.3203   0.9473i */
            12'hFBA: dout <= {-10'sd162   ,  10'sd486   }; /* W[2862] = -0.3164   0.9492i */
            12'hFBB: dout <= {-10'sd160   ,  10'sd486   }; /* W[2865] = -0.3125   0.9492i */
            12'hFBC: dout <= {-10'sd158   ,  10'sd487   }; /* W[2868] = -0.3086   0.9512i */
            12'hFBD: dout <= {-10'sd155   ,  10'sd488   }; /* W[2871] = -0.3027   0.9531i */
            12'hFBE: dout <= {-10'sd153   ,  10'sd489   }; /* W[2874] = -0.2988   0.9551i */
            12'hFBF: dout <= {-10'sd151   ,  10'sd489   }; /* W[2877] = -0.2949   0.9551i */
            12'hFC0: dout <= {-10'sd149   ,  10'sd490   }; /* W[2880] = -0.2910   0.9570i */
            12'hFC1: dout <= {-10'sd146   ,  10'sd491   }; /* W[2883] = -0.2852   0.9590i */
            12'hFC2: dout <= {-10'sd144   ,  10'sd491   }; /* W[2886] = -0.2812   0.9590i */
            12'hFC3: dout <= {-10'sd142   ,  10'sd492   }; /* W[2889] = -0.2773   0.9609i */
            12'hFC4: dout <= {-10'sd140   ,  10'sd493   }; /* W[2892] = -0.2734   0.9629i */
            12'hFC5: dout <= {-10'sd137   ,  10'sd493   }; /* W[2895] = -0.2676   0.9629i */
            12'hFC6: dout <= {-10'sd135   ,  10'sd494   }; /* W[2898] = -0.2637   0.9648i */
            12'hFC7: dout <= {-10'sd133   ,  10'sd494   }; /* W[2901] = -0.2598   0.9648i */
            12'hFC8: dout <= {-10'sd130   ,  10'sd495   }; /* W[2904] = -0.2539   0.9668i */
            12'hFC9: dout <= {-10'sd128   ,  10'sd496   }; /* W[2907] = -0.2500   0.9688i */
            12'hFCA: dout <= {-10'sd126   ,  10'sd496   }; /* W[2910] = -0.2461   0.9688i */
            12'hFCB: dout <= {-10'sd124   ,  10'sd497   }; /* W[2913] = -0.2422   0.9707i */
            12'hFCC: dout <= {-10'sd121   ,  10'sd497   }; /* W[2916] = -0.2363   0.9707i */
            12'hFCD: dout <= {-10'sd119   ,  10'sd498   }; /* W[2919] = -0.2324   0.9727i */
            12'hFCE: dout <= {-10'sd117   ,  10'sd499   }; /* W[2922] = -0.2285   0.9746i */
            12'hFCF: dout <= {-10'sd114   ,  10'sd499   }; /* W[2925] = -0.2227   0.9746i */
            12'hFD0: dout <= {-10'sd112   ,  10'sd500   }; /* W[2928] = -0.2188   0.9766i */
            12'hFD1: dout <= {-10'sd110   ,  10'sd500   }; /* W[2931] = -0.2148   0.9766i */
            12'hFD2: dout <= {-10'sd108   ,  10'sd501   }; /* W[2934] = -0.2109   0.9785i */
            12'hFD3: dout <= {-10'sd105   ,  10'sd501   }; /* W[2937] = -0.2051   0.9785i */
            12'hFD4: dout <= {-10'sd103   ,  10'sd502   }; /* W[2940] = -0.2012   0.9805i */
            12'hFD5: dout <= {-10'sd101   ,  10'sd502   }; /* W[2943] = -0.1973   0.9805i */
            12'hFD6: dout <= {-10'sd98    ,  10'sd502   }; /* W[2946] = -0.1914   0.9805i */
            12'hFD7: dout <= {-10'sd96    ,  10'sd503   }; /* W[2949] = -0.1875   0.9824i */
            12'hFD8: dout <= {-10'sd94    ,  10'sd503   }; /* W[2952] = -0.1836   0.9824i */
            12'hFD9: dout <= {-10'sd91    ,  10'sd504   }; /* W[2955] = -0.1777   0.9844i */
            12'hFDA: dout <= {-10'sd89    ,  10'sd504   }; /* W[2958] = -0.1738   0.9844i */
            12'hFDB: dout <= {-10'sd87    ,  10'sd505   }; /* W[2961] = -0.1699   0.9863i */
            12'hFDC: dout <= {-10'sd84    ,  10'sd505   }; /* W[2964] = -0.1641   0.9863i */
            12'hFDD: dout <= {-10'sd82    ,  10'sd505   }; /* W[2967] = -0.1602   0.9863i */
            12'hFDE: dout <= {-10'sd80    ,  10'sd506   }; /* W[2970] = -0.1562   0.9883i */
            12'hFDF: dout <= {-10'sd77    ,  10'sd506   }; /* W[2973] = -0.1504   0.9883i */
            12'hFE0: dout <= {-10'sd75    ,  10'sd506   }; /* W[2976] = -0.1465   0.9883i */
            12'hFE1: dout <= {-10'sd73    ,  10'sd507   }; /* W[2979] = -0.1426   0.9902i */
            12'hFE2: dout <= {-10'sd70    ,  10'sd507   }; /* W[2982] = -0.1367   0.9902i */
            12'hFE3: dout <= {-10'sd68    ,  10'sd507   }; /* W[2985] = -0.1328   0.9902i */
            12'hFE4: dout <= {-10'sd66    ,  10'sd508   }; /* W[2988] = -0.1289   0.9922i */
            12'hFE5: dout <= {-10'sd63    ,  10'sd508   }; /* W[2991] = -0.1230   0.9922i */
            12'hFE6: dout <= {-10'sd61    ,  10'sd508   }; /* W[2994] = -0.1191   0.9922i */
            12'hFE7: dout <= {-10'sd59    ,  10'sd509   }; /* W[2997] = -0.1152   0.9941i */
            12'hFE8: dout <= {-10'sd56    ,  10'sd509   }; /* W[3000] = -0.1094   0.9941i */
            12'hFE9: dout <= {-10'sd54    ,  10'sd509   }; /* W[3003] = -0.1055   0.9941i */
            12'hFEA: dout <= {-10'sd52    ,  10'sd509   }; /* W[3006] = -0.1016   0.9941i */
            12'hFEB: dout <= {-10'sd49    ,  10'sd510   }; /* W[3009] = -0.0957   0.9961i */
            12'hFEC: dout <= {-10'sd47    ,  10'sd510   }; /* W[3012] = -0.0918   0.9961i */
            12'hFED: dout <= {-10'sd45    ,  10'sd510   }; /* W[3015] = -0.0879   0.9961i */
            12'hFEE: dout <= {-10'sd42    ,  10'sd510   }; /* W[3018] = -0.0820   0.9961i */
            12'hFEF: dout <= {-10'sd40    ,  10'sd510   }; /* W[3021] = -0.0781   0.9961i */
            12'hFF0: dout <= {-10'sd38    ,  10'sd511   }; /* W[3024] = -0.0742   0.9980i */
            12'hFF1: dout <= {-10'sd35    ,  10'sd511   }; /* W[3027] = -0.0684   0.9980i */
            12'hFF2: dout <= {-10'sd33    ,  10'sd511   }; /* W[3030] = -0.0645   0.9980i */
            12'hFF3: dout <= {-10'sd31    ,  10'sd511   }; /* W[3033] = -0.0605   0.9980i */
            12'hFF4: dout <= {-10'sd28    ,  10'sd511   }; /* W[3036] = -0.0547   0.9980i */
            12'hFF5: dout <= {-10'sd26    ,  10'sd511   }; /* W[3039] = -0.0508   0.9980i */
            12'hFF6: dout <= {-10'sd24    ,  10'sd511   }; /* W[3042] = -0.0469   0.9980i */
            12'hFF7: dout <= {-10'sd21    ,  10'sd511   }; /* W[3045] = -0.0410   0.9980i */
            12'hFF8: dout <= {-10'sd19    ,  10'sd511   }; /* W[3048] = -0.0371   0.9980i */
            12'hFF9: dout <= {-10'sd16    ,  10'sd511   }; /* W[3051] = -0.0312   0.9980i */
            12'hFFA: dout <= {-10'sd14    ,  10'sd511   }; /* W[3054] = -0.0273   0.9980i */
            12'hFFB: dout <= {-10'sd12    ,  10'sd511   }; /* W[3057] = -0.0234   0.9980i */
            12'hFFC: dout <= {-10'sd9     ,  10'sd511   }; /* W[3060] = -0.0176   0.9980i */
            12'hFFD: dout <= {-10'sd7     ,  10'sd511   }; /* W[3063] = -0.0137   0.9980i */
            12'hFFE: dout <= {-10'sd5     ,  10'sd511   }; /* W[3066] = -0.0098   0.9980i */
            12'hFFF: dout <= {-10'sd2     ,  10'sd511   }; /* W[3069] = -0.0039   0.9980i */
            default:
              begin
                dout <= 20'd0;
              end
         endcase
      end
  end
endmodule

/** @} */ /* End of addtogroup ModMiscIpDspFftR22Sdc */
/* END OF FILE */
